#!/usr/bin/perl -w
# mirror_capabilities.pl
#  Generate a Perl module that captures mirror capabilities
#
# EXPL
#  That module is MirrorCapabilities.pm.  I can install it into the
# Apache:: mod_perl space and not have to hit the disk at all to 
# get mirror information.
# 
# 2000-Dec-05 Jim Hefferon jim@joshua.smcvt.edu
#
$mirror_list = "/home/httpd/cron-scripts/check-mirrors/responding_mirrors.txt";
open IN, "$mirror_list" 
    or die "$0: cannot open $mirror_list: $!\n";

$module_file = "/home/httpd/cron-scripts/check-mirrors/MirrorCapabilities.pm";
open OUT, ">$module_file"
    or die "$0: cannot open $module_file: $!\n";

$mirror_array = "";  # for when you want them in order
$mirror_hash = "";  # for when you want per-mirror info
$mirror_popup_labels = ""; # for displaying in a pop-up menu

while ($line = <IN>) { # expects: mirror_name path (geography) services
    ($mirror,$path,$geo_and_rest) = split ' ', $line, 3;
    $mirror_str = "\"$mirror\"";
    $path_str = "\"$path\"";
    $geo_and_rest =~ /\s*\(([^\)]*)\)(.*)/;
    $geo = $1;
    $geo_str = "\"$geo\"" || "";
    $rest = $2 || "";
    if (!($mirror_array)) {
	$mirror_array = $mirror_array."$mirror_str";
    } else {
	$mirror_array = $mirror_array.",\n   $mirror_str";
    }
    @fields = split ' ', $rest;
    $field_strs = "";
    foreach $field (@fields) {
	if (!($field_strs)) {
	    $field_strs = "\"$field\"";
	}else {
	    $field_strs = $field_strs.", \"$field\"";
	}
    }
    # contents of fields are under my control; no chars Perl won't like
    if (!($mirror_hash)) {
	$mirror_hash = $mirror_hash."$mirror_str => [$path_str, $geo_str, [ $field_strs ] ]";
    } else {
	$mirror_hash = $mirror_hash.",\n    $mirror_str => [$path_str, $geo_str, [ $field_strs ] ]";
    }
    if (!($mirror_popup_labels)) {
	$mirror_popup_labels = "$mirror_str => \"$mirror ($geo) $rest\"";
    } else {
	$mirror_popup_labels = $mirror_popup_labels.",\n    $mirror_str => \"$mirror ($geo) $rest\"";
    }
}


print OUT <<END_of_Module_Header;
package Apache::MirrorCapabilities;
# file Apache/MirrorCapabilities.pm 
#  capacities of CTAN mirrors 
#  generated from mirror_capabilities.pl 
use Exporter;
\@ISA = (\'Exporter\');
\@EXPORT = qw(\@mirrors 
	      \%mirror_data 
	      \$mirror_popup_labels
	      \&mirror_FTP_path \&mirror_geo \&mirror_services \&mirror_offers);

END_of_Module_Header


$mirror_array = "\@mirrors = ($mirror_array);";
$mirror_hash = "\%mirror_data = ($mirror_hash);";
$mirror_popup_labels = "\$mirror_popup_labels = {\n$mirror_popup_labels\n};";
print OUT $mirror_array,"\n\n";
print OUT $mirror_hash,"\n\n";
print OUT $mirror_popup_labels,"\n\n"; # must be anon hash for CGI.pm -labels


print OUT <<END_of_Module_Remainder;
# Functions using that data

# mirror_FTP_path from the mirror, get the path to the top of the FTP TeX tree
sub mirror_FTP_path {
    my \$mirror = shift();

    if (exists(\$mirror_data{\$mirror})) {
	return \$mirror_data{\$mirror}[0];
    } else {
	return undef;
    }
}

# mirror_geo from the mirror, get its geographic info
sub mirror_geo {
    my \$mirror = shift();

    if (exists(\$mirror_data{\$mirror})) {
	return \$mirror_data{\$mirror}[1];
    } else {
	return undef;
    }
}


# Mirror_offers:  predicate, given mirror and string, return 1 or 0
sub mirror_offers {
    my (\$mirror,\$desired_service) = \@_;

    my \@services = ();
    if (defined (\@services = mirror_services(\$mirror))) {
        foreach \$service (\@services) {
	    if (\$service eq \$desired_service) {
		return 1;
	    }
	}
	return 0;
    } else {
	return 0; # not even any such mirror
    }
}


# mirror_services: give a list of services offered 
sub mirror_services {
    my \$mirror = shift();

    if (exists(\$mirror_data{\$mirror})) {
	return \@{\$mirror_data{\$mirror}[2]};
    } else {
	return ();
    }
}


1;
END_of_Module_Remainder



# Tester.
# I used the below script to test this script.
#!/usr/bin/perl
#use MirrorCapabilities;
#
#foreach $mirror (@mirrors) {
#    print "mirror is $mirror\n";
#    print "   path to FTP is ",mirror_FTP_path($mirror),"\n";
#    print "   geographical location is ",mirror_geo($mirror),"\n";
#    print "   services: ",mirror_services($mirror);
#    print "   ?zip ",mirror_offers($mirror,"zip");
#    print "   ?tar.gz ",mirror_offers($mirror,"tar.gz"),"\n";
#}
