# mirrors_to_check.awk
#  Give a list of CTAN mirrors along with the path to their archive.
#
# Copyright 1999 Jim Hefferon
#  This program can redistributed and/or modified under the terms
#   of the LaTeX Project Public License Distributed from CTAN
#   archives in directory macros/latex/base/lppl.txt; either
#   version 1 of the License, or (at your option) any later version.
#
# IMPLEMENTATION
# Briefly, look at CTAN.sites: 
#   * ignore the preliminary lines
#   * print the known mirrors (except that this site is printed first)
#     by saving them in the array `lines' and printing with the END
#   * ignore the partial mirrors
#   * print the primary CTANs (if this site is a primary, I don't print
#     it first, thinking that this is a way to encourage the mirrors)
# 
# 1999-Mar-17 Jim Hefferon jim@joshua.smcvt.edu Written.  Installable (all
#               the SEARCH_* strings).
# 2000-Nov-08 JH Adjusted mirrors.awk to output mirrors and a path to archive.
#

function getpathname(hostgeopath) {
  firstslash=index(hostgeopath,"/");
  paths=substr(hostgeopath,firstslash);
  firstparen=index(paths,"(");  # ? some sites have alternate dirs listed
  if (firstslash) {
    if (firstparen) {
      return substr(paths,0,firstparen-1);
    } else {
      return paths;
    }
  } else {
    return hostgeopath;
  }
}


function getgeo(hostgeopath) {
  openparen=index(hostgeopath,"(");
  closeparen=index(hostgeopath,")");
  if (closeparen) {
    return substr(hostgeopath,openparen,closeparen+1-openparen);
  } else {
    return "";
  }
}                                                                               


BEGIN                    {i=0;           # index for lines array
                          skip=0;        # flag: skip this line?
                          primary=0;     # flag: now in primary site section?
                          primarysite=0} # flag: now making up a primary site?
/In order to reduce network load/,/Known mirrors of the CTAN reside/ {skip=1}
$0==""                                                    {skip=1}
/Known partial mirrors of the CTAN/,/Please send updates/ {skip=1}
/The participating hosts/                                 {primary=1}
# main line: the *only* keeps me out of places that don't want me.
(skip==0) && (primary==0) && ($0 !~ /\*only\*/) {printf("%s  %s  %s\n",$1,getpathname($0),getgeo($0))}
(primary==1) && $1 ~ /^[A-Za-z]*\./ {primaryname=$1
				     selected="";
                                     $1=""; primarygeo=$0; } 
(primary==1) && /-- anonymous ftp/ {printf("%s  %s  %s\n",primaryname,$4,primarygeo)}
  {skip=0}



