package Apache::CTAN;
# file: Apache/CTAN.pm
use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(COOKIE_MIRROR_KEY PARAM_MIRROR_KEY PARAM_FILENAME_KEY PARAM_CATSTRING_KEY PARAM_ACTION_KEY PARAM_GOTO_GETMIRROR PARAM_NEWMIRRORFLAG_KEY
	     META_KEYWORDS
	     THIS_SITE_WEB THIS_SITE_FTP WEB_ROOT CGI TOPINDEX_PAGE GETMIRROR_PAGE GETFILE_PAGE SEARCH_PAGE INSTALLATIONADVICE_PAGE REGEXEXPLAIN_PAGE STARTER_PAGE CONTACTS_PAGE UPLOAD_PAGE FTPBROWSING_PAGE FTP_ROOT WEBFTP_ROOT FTPROOTINDEX_PAGE CATALOGUEINDEX_PAGE INTERNAL_FTP_PATH 
	     &clear_cookie_data &clear_param_data
	     &determine_mirror &CTAN_header &determine_action &params_as_hiddenfields &params_as_URLfields &end_CTAN_page
	     &mirror_explanation &regex_explanation &installation_advice
	     &trim &debug_info 
	     $cookie
	     );

#use strict;
#use Apache::Constants qw(:common);
use CGI qw(:all escapeHTML);
use Apache::MirrorCapabilities;
use Apache::Log;


# constants
# The URL's specified in perl.conf
use constant THIS_SITE_WEB => "www.ctan.org"; # "alan.smcvt.edu"; # "www.ctan.org";
use constant THIS_SITE_FTP => "tug.ctan.org"; # "alan.smcvt.edu"; # "tug.ctan.org";
use constant WEB_ROOT => "/";
use constant CGI => "/tools/"; # as alaised in perl.conf 
use constant TOPINDEX_PAGE => WEB_ROOT()."index.html";
use constant GETMIRROR_PAGE => WEB_ROOT()."getmirror/";
use constant GETFILE_PAGE => WEB_ROOT()."getfile/";
use constant SEARCH_PAGE => WEB_ROOT()."search/";
use constant INSTALLATIONADVICE_PAGE => WEB_ROOT()."installationadvice/";
use constant REGEXEXPLAIN_PAGE => WEB_ROOT()."regexexplanation/";
use constant STARTER_PAGE => WEB_ROOT()."starter/";
use constant CONTACTS_PAGE => WEB_ROOT()."contacts/";
use constant UPLOAD_PAGE => WEB_ROOT()."upload/";
use constant FTPBROWSING_PAGE => WEB_ROOT()."ftpbrowsing/";
use constant FTP_ROOT => "/tex-archive/";    # must soft-link to under WEB_ROOT
use constant WEBFTP_ROOT => "/tex-archive/"; # ... as here
use constant FTPROOTINDEX_PAGE => WEBFTP_ROOT()."index.html";
use constant CATALOGUEINDEX_PAGE => WEBFTP_ROOT()."help/Catalogue/catalogue.html";
use constant INTERNAL_FTP_PATH => "/home/ftp/pub/tex-archive"; # no closing /
use constant THISSITE => "tug.ctan.org"; # default name for mirror
use constant COOKIE_DOMAIN => ".ctan.org"; # !!if partial, MUST start with a . 
# actions 
my %legal_actions = (
		     "getmirror/" => 1,
		     "search/" => 1,
		     "getfile/" => 1,
		     "" => 1,
		     "tex-archive/" => 1
		     );                # URI's where we could be sent

# first, the keys used in key-value pairs (e.g., for cookies, or CGI parameters
use constant COOKIE_MIRROR_KEY => "preferredCTAN"; # Cookie's key
use constant PARAM_MIRROR_KEY => "preferredCTAN";  #  and similar parameter key
use constant PARAM_FILENAME_KEY => "filename";  # What filename of interest?
use constant PARAM_CATSTRING_KEY => "catstring";  # String for the catalogue?
use constant PARAM_ACTION_KEY => "action";  # What program using?
use constant PARAM_GOTO_GETMIRROR => "getmirror";  # Should get new mirror?
use constant PARAM_NEWMIRRORFLAG_KEY => "newmirror"; # This a new mirror?  
                                            # e.g., should we send a cookie?

# misc constants
use constant META_KEYWORDS => "TeX LaTeX typesetting mathematics"; # META tags
# data
# 2000-Nov-30 JH the construct CONSTANT() => value is from 
#  http://www.perldoc.com/perl5.6/lib/constant.html and is just some Perl thing
use vars qw(%cookie_data %param_data);
#%cookie_data = ();  # data collected from cookies 
my %cookie_keys = (                        
		   COOKIE_MIRROR_KEY() => 1
		   );                 # keys allowed in %cookie_data 
#%param_data=();  # data collected from CGI parameters
my %param_keys=(
		PARAM_MIRROR_KEY() => 1,
		PARAM_FILENAME_KEY() => 1,
		PARAM_CATSTRING_KEY() => 1,
		PARAM_NEWMIRRORFLAG_KEY() => 1,
                PARAM_ACTION_KEY() => 1
		);                    # keys allowed in %param_data

use vars qw($cookie);


#========================= subroutines =============================
                                                             
# determine_mirror                                                             
#   decide what mirror to use               
#                                                             
# ARGS                                                        
#  $cookie_data_ref  reference to hash of cookie data returned in CGI request
#  $param_data_ref  reference to CGI parameter data           
#                                                             
# RETURNS                                                     
#  A string, giving the URI to the top of the TeX directory tree.   If the 
# string is empty, user procedure must handle, either with a call to the
# get_a_mirror page, or with a default.    
#                                                             
# LOGIC
#   There are two inputs, and so there are 2^2 cases.
#
#  cookie received?  parameter?        What to do?  (why)
#  ===============   ==============    ==================
#  yes               yes               use parameter (user may have rejected
#                                       changed cookie)
#  yes               no                use cookie (and insert a parameter)
#                                                             
#  no                yes               use parameter          
#                                                             
#  no                no                return a value flagging to query user,
#                                        or to use a default).       
#                                                             
sub determine_mirror {
    my ($cookie_data_ref, $param_data_ref) = @_;

    my $cookie_mirror = $cookie_data_ref->{COOKIE_MIRROR_KEY()};
    my $param_mirror = $param_data_ref->{PARAM_MIRROR_KEY()};
    my $no_mirror=""; # evaluates to false

    if ($param_mirror) {
	return newstyle_mirror_key($param_mirror);
    } elsif ($cookie_mirror) {
	$cookie_mirror = newstyle_mirror_key($cookie_mirror);
	$param_data_ref->{PARAM_MIRROR_KEY()} = $cookie_mirror;
	return $cookie_mirror;
    } else {
	return $no_mirror;
    }
}


# newstyle_mirror_key:  prefer keys of form joshua.smcvt.edu over .../pub/tex-archive
sub newstyle_mirror_key {
    my $mirror = shift();

    my $pos = -1;

    if (($pos = index($mirror,'/')) > -1) {
	return substr($mirror,0,$pos);
    } else {
	return $mirror;
    }
}





sub clear_cookie_data {
    my $cookie_data_ref = shift();
    my $k="";
    my $no_cookie_value = ""; # evaluates to false

    foreach $k (keys %cookie_keys) {
	$cookie_data_ref->{$k} = $no_cookie_value;
    }
    return 1;
}


sub get_cookie_data {
    my $cookie_data_ref = shift();
    my $k="";
    my $no_cookie_value = ""; # evaluates to false

    foreach $k (keys %cookie_keys) {
	if ((!($cookie_data_ref->{$k})) && (defined cookie($k))) {
	    $cookie_data_ref->{$k} = cookie($k);
	} else {
	  #  $cookie_data_ref->{$k} = $no_cookie_value;
	}
    }
    return 1;
}


sub clear_param_data {
    my $param_data_ref = shift();
    my $k="";
    my $no_param_value = ""; # evaluates to false

    foreach $k (keys %param_keys) {
	$param_data_ref->{$k} = $no_param_value; 
    }
    return 1;
}

sub get_param_data {
    my $param_data_ref = shift();
    my $k="";
    my $no_param_value = ""; # evaluates to false

    foreach $k (keys %param_keys) {
	if ((!($param_data_ref->{$k})) && (defined param($k))) {
	    $param_data_ref->{$k} = param($k);
	} else {
	  #  $param_data_ref->{$k} = $no_param_value; 
	}
    }
    return 1;
}





# determine_action
#  decide what page to send the user to (probably the page they came from)
# ARGS 
#  $CGI_param  The action that was passed as part of the CGI request.
#     I don't trust it, so I check the prefix against sane prefixes.
#  $default  The caller's default action.
# 
# RETURNS
#  A string that indicates the action.
#sub determine_action {
#    my ($CGI_param,$default) = @_;
#    # is the CGI parameter that was passed OK?
#    foreach $prefix (keys(%legal_actions)) {
#	if ($CGI_param =~ m!^$prefix(.*)!) {
#	    return $CGI_param;
#	}
#    }
#    # if not, send them to the default for the caller routine
#    foreach $prefix (keys(%legal_actions)) {
#	if ($default =~ m!^$prefix(.*)!) {
#	    return $default;
#	}
#    }
#    # else, do something desparate
#    return "/ctan/";
#}
sub determine_action {
    my ($CGI_param,$default) = @_;
    return $CGI_param;
}



# params_as_hiddenfields
# Arguments: 
#  %params   a hash of the CGI parameters
sub params_as_hiddenfields {
    my %params = @_; # hash of CGI params
    my $k = "";
    my $v = "";
    my $result="";
    
    while (($k,$v) = each(%params)) {
	$result = $result.hidden(-name => $k,
				 -value => $v)."\n";
    }
    return $result;
}


# params_as_URLfields
#   turn a hash's key=value pairs into a GET-style request string
#
# ARGS 
#  %params   a hash
#
# RETURN
#  a string that is HTML escaped
sub params_as_URLfields {
    my %params = @_; # hashes of CGI params
    my $k="";
    my $v="";
    my $result = "";
    
    while (($k,$v) = each(%params)) {
	if ($v) {          # more bookmarkable URL by ommiting false $v's
	    if ($result) {
		$result = $result."&";
	    }
	    $result = $result.escapeHTML($k)
                             ."="
                             .escapeHTML($v);
	}
    }
    if ($result) {
	return "?$result"; # prefix with a ?
    } else {
	return "";
    }
}




#=========================routines that return long strings================
#
# installation_advice
#  Make a link to the page giving installation advice.
sub installation_advice {
    my $URL_str = shift(); # hashes of CGI params

    return "Some advice on what to do with any 
           new files is on our ".
	   a({-href=>INSTALLATIONADVICE_PAGE()."$URL_str"},
	     "install page").
	   ".\n";
}

#
# mirror_explanation
#  Make a link to the page allowing people to choose a new mirror.
sub mirror_explanation {
    my $URL_str = shift(); # hashes of CGI params

    return "There are many sites around the world that,
     as a generous service to the TeX community, are ".
     a({-href=>WEBFTP_ROOT()."CTAN.sites$URL_str"},
       "CTAN mirrors").". ".
     " Every night they visit CTAN and update their collection, 
       and then allow access to others. ".
     " This works wonderfully, if you bear in mind two cautions. ".
     " First, because mirrors sync up only once a day
       there is a small chance that
       you are looking for a file that is in one place but not in 
       another. ".
     " Second, because mirrors are subject to a variety of local
       conditions, they do not all offer the same access or services;
       in particular, they do not all offer the ability to make on-the-fly 
       .zip or .tar.gz files of directories.
       If this capacity is a requirement for you and your present mirror
       does not offer it then you must ".
       a({href=>GETMIRROR_PAGE()."$URL_str"},
	 "choose a different mirror").
       ". ";
}

#
# regex_explanation
#  Make a link to the page giving advice on making regex's.
sub regex_explanation {
    my $URL_str = shift(); # hashes of CGI params

    return "Query strings are ".
	a({href => REGEXEXPLAIN_PAGE."$URL_str"},
	  "regular expressions").
	". ";      
}

#
# end_CTAN_page
#  give pages a bottom
sub end_CTAN_page {
    my $extra_text = shift();
    my $URL_str = shift();

    my $returned_string;

    $returned_string = "<hr>\n";
    $returned_string = $returned_string.
	p(
	  i(
	    "About this page: ",
	    a({href=>CONTACTS_PAGE()."$URL_str"},
	      "CTAN contact information"),
	    ", the ",
	    a({href=>TOPINDEX_PAGE()."$URL_str"},
	      "CTAN home page").
	    $extra_text
	    )
	  ).
	  end_html();
    return $returned_string;
}

#=========================utility routines========================
# trim whitespace off front or back of a string
#  From Perl Cookbook p. 30
sub trim {
    my @out = @_;
    for (@out) {
	s/^\W+//;
        s/\W+$//;
    }
    return wantarray ? @out : $out[0];
}


# debugging tool
sub debug_info {
    my $test_str = @_;

    my $return_str = ">>> -|";
    my $entry = "";

    foreach $entry (@_) {
	$return_str = $return_str."|- -|$entry";
    }
    return  "\n$return_str|_ <<<\n";
}



#=========================header reader====================================
#
# CTAN_header
#   Form the http header for CTAN pages; handles cookies, etc.
#                                                                           
# ARGS  
#   $coming_from_URL The module that called this function      
#   $flag_goto_getmirror  ?Can bounce the user to a getmirror page          
#                         (If this is that page, want answer of no.)
#   $cookie_data_ref  Reference to a hash of data from the cookies
#   $param_data_ref Reference to a hash of data from the params.        
#                                                                           
# RETURNS                                                                   
#   a string  containing the header that will be sent.
#   a flag  that is true iff a redirect is being sent
#                                                                           
# LOGIC                                                                     
#   If we don't know the mirror, or if the user has requested a new mirror  
# then we redirect to the get-a-new-mirror page.                            
#   Otherwise send a header (if we need to send a cookie as part of that
# header, do so).                           
# 
# NOTES
#  * If we are both (i) given info that requires us to go to the get-a-mirror
#    page and (ii) also asked to send a cookie, we should do the former but not
#    the latter.
#                                                                           
sub CTAN_header {
    my $coming_from_URL = shift();  # what routine called me?
    my $flag_goto_getmirror = shift(); # can bounce user to mirror page?
    my ($cookie_data_ref,$param_data_ref) = @_; #refs to hashes

    my $mirror = "";
    my $return_string = "";

    # these have been cleared, and possibly primed by the calling program
    get_cookie_data($cookie_data_ref);
    get_param_data($param_data_ref);

    $mirror = determine_mirror($cookie_data_ref,$param_data_ref);

    # if this is a page where we need to know a mirror ...
    if ($flag_goto_getmirror) {
    #  ... and there is no mirror (i.e., new user)
    #           or the mirror is not known (dropped out?)
	if ((!($mirror)) 
	    || (!(exists  $mirror_data{$mirror}))) {
	    #  remember the page they intended to go to	
	    $param_data_ref->{PARAM_ACTION_KEY()} = $coming_from_URL;   
	    my $URL_str = params_as_URLfields(%$param_data_ref);
	    # then redirect to the get-a-mirror page
	    return (redirect("http://".THIS_SITE_WEB().GETMIRROR_PAGE()."$URL_str"),1);
	}
    }


    if ($param_data_ref->{PARAM_NEWMIRRORFLAG_KEY()}) { # asked to send cookie?
	if (!($mirror)) {
	    $mirror = THISSITE();  # a default for mirror (needed?) 
	} 
	$cookie = cookie(
			 -name => COOKIE_MIRROR_KEY(),
			 -value => "$mirror",
			 -domain => COOKIE_DOMAIN(),
			 -expires => "+1y"
			 ); 
	$param_data_ref->{PARAM_NEWMIRRORFLAG_KEY()} = 0; # next page sends cookie
	return (header(-cookie => $cookie),0);
    } else {
	return (header(),0);
    }
}



1;
__END__
