#package DirInfo;  # FOR TESTING ONLY; Next line for production
package Apache::DirInfo;
# file Apache/DirInfo.pm 
#  Information about CTAN directories 
#  !!! generated from dir_info.pl; don't edit this file directly !!! 
use Exporter;
@ISA = ('Exporter');
@EXPORT = qw( 
	       %descs 
	       &new_key 
	       &insert_cat_info &get_cat_info  &get_cat 
	       &get_extra_info
	       &any_info &display_info
	     );
use Apache::CTAN;

 
# The descs hash
#  Structure: key => [{..},[..]]
# The keys are CTAN directories.  The vals are pairs.  Entry 0 is
# a hash of Catalogue package_name=>description pairs.  Entry 1 is
# a list of strings that are further descriptions.
%descs = (
	  );


# new_key: put a new key into the descs hash, with a null value
# ARGS
#    the key; a CTAN directory  
sub new_key {
    my $k = shift();

    $descs{$k} = [{},[]];
}


# insert_cat_info: put a catalogue k=>v pair into the descs entry
# ARGS
#  $dkey  key into descs; the directory
#  $catkey, $val  key=>val pair to be entered
sub insert_cat_info {
    my $dkey = shift();
    my $catkey = shift();
    my $val = shift();

    unless (exists($descs{$dkey})) {
	new_key($dkey);
    }
    @{ $descs{$dkey} }->[0]{$catkey} = $val;
}


# get_cat_info:  get val associated with a cat key for a desc key
# ARGS
#  $dkey  key into descs hash; a directory name
#  $catkey  a key for the Catalogue (CTAN package name)
# RETURNS
#  undef if no such 
#  "" if no such 
#  val o.w.
sub get_cat_info {
    my $dkey = shift ();
    my $catkey = shift();

    if (exists($descs{$dkey})) {
	if (exists(@{ $descs{$dkey} }->[0]{$catkey})) {
	    return @{ $descs{$dkey} }->[0]{$catkey};
	} else {
	    return "";
	}
    } else {
	return undef;
    }
}

# get_cat_info:  get cat hash associated with a desc key
# ARGS
#  $dkey  key into descs hash; a directory name
# RETURNS
#  undef if no such 
#  hash o.w.
sub get_cat {
    my $dkey = shift ();

    if (exists($descs{$dkey})) {
	return %{ @{ $descs{$dkey} }->[0] }; 
    } else {
	return undef;
    }
}


# trim: remove surrounding whitespace 
#  from Perl Cookbook, p. 30
sub trim {
    my @out = @_;

    for (@out) {
	s/^\s+//;
	s/\s+$//;
    }
    return wantarray ? @out : $out[0];
}





# insert_extra_info: put a entry into the descs entry
# ARGS
#    key into descs; the directory
#    info to be entered
sub insert_extra_info {
    my $dkey = shift();
    my $info = shift();

    unless (exists($descs{$dkey})) {
	new_key($dkey);
    }
    push  @{ @{ $descs{$dkey} }[1] }, $info;
}



# get_extra_info:  get extra info associated with a desc key
# ARGS
#    key into descs hash; a directory name
# RETURNS
#  undef if no such 
#  array o.w.
sub get_extra_info {
    my $dkey = shift ();

    if (exists($descs{$dkey})) {
	return @{ @{ $descs{$dkey} }[1] };
    } else {
	return undef;
    }
}


# any_info
#  return true if any info is available on the directory
# ARGS
#  $dir_key Name of directory
# RETURN
#  true or false
sub any_info {
    my $dir_key = shift();
    $dir_key =~ s!/$!!; # if it ends in / get rid of that

    if (exists($descs{$dir_key})) {
	return (get_cat($dir_key) || get_extra_info($dir_key));
    } else {
	return 0;
    }
} 


# display info
#  show the information about a directory
# ARGS
#  $dir_key  Name of directory
# RETURN
#  string for displaying information
sub display_info {
    my $dir_key = shift();
    my $URL_str = shift();

    $dir_key =~ s!/$!!; # if it ends in / get rid of that

    my $k = ""; my $v = "";
    my $returned_str = "";

    my @extra_info = get_extra_info($dir_key);
    if (@extra_info) {
	$returned_str = $returned_str."General information on this material\n";
	$returned_str = $returned_str."<ul>\n";
	foreach $v (@extra_info) {
	    $returned_str = $returned_str."<li> $v \n";
	}
	$returned_str = $returned_str."</ul>\n";
    }

    my %cat_hash = get_cat($dir_key);
    if (%cat_hash) {
	$returned_str = $returned_str."Catalogue information\n";
	$returned_str = $returned_str."<ul>\n";
	while (($k,$v) = each(%cat_hash)) {
            $v =~ /(\s*)<<<<(.*)>>>>(.*)/;
	    $pkg_name = trim($2);
	    $pkg_desc = trim($3);
	    $returned_str = $returned_str."<li><a href=\"".WEBFTP_ROOT()."help/Catalogue/entries/$k.html$URL_str\"><b>$pkg_name</b></a> $pkg_desc\n";
	}
	$returned_str = $returned_str."</ul>\n";
    }

    return "<p>".$returned_str."</p>";
}




@line_fields = ();
while ($line = <DATA>) {
    @line_fields = split /\t/, $line;
    $dirkey = shift(@line_fields);
    $dirkey = trim($dirkey);
    $line_fields = @line_fields;
    if ($line_fields == 1) {
	$extraval = trim(shift(@line_fields));
	insert_extra_info($dirkey,$extraval);
    } elsif ($line_fields >= 2) {
	$catkey = trim(shift(@line_fields));
	$catname = trim(shift(@line_fields));
	$cattxt = trim(shift(@line_fields));
	insert_cat_info($dirkey,$catkey,"$catname $cattxt");
    } else {
	# ignore it
    }
}


1;

__DATA__
support/TVS	tvs	<<<<TVS>>>>	TeX Versioning System.
biblio/bibtex/contrib/germbib	germbib	<<<<germbib>>>>	German variants of standard BibTeX styles.
dviware/dvi2bitmap	dvi2bitmap	<<<<dvi2bitmap>>>>	Utility to convert TeX DVI files directly to bitmaps.
macros/latex/contrib/supported/isodate	isodate	<<<<isodate>>>>	Tune the output format of the \today command.
fonts/archaic/hieroglf	hieroglf	<<<<hieroglf>>>>	About 60 Egyptian Hieroglyphs.
fonts/archaic/oands	oands	<<<<oands>>>>	Characters used as symbols when transliterating ancient scripts.
macros/latex/contrib/supported/minitoc	minitoc	<<<<minitoc>>>>	Produce a table of contents for each chapter.
macros/latex/contrib/supported/jkthesis	jkthesis	<<<<jkthesis>>>>	Document class for formatting a thesis.
macros/latex/contrib/supported/listings	listings	<<<<listings>>>>	Typeset source code listings using LaTeX.
macros/latex/contrib/supported/bibtopic	bibtopic	<<<<bibtopic>>>>	Include multiple `by topic' bibliographies in a document.
macros/latex/contrib/supported/jurabib	jurabib	<<<<jurabib>>>>	BibTeX databases for German legal texts.
macros/latex/contrib/supported/curves	curves	<<<<curves>>>>	Curves for LaTeX picture environment
macros/latex/contrib/supported/footmisc	footmisc	<<<<footmisc>>>>	Footnotes with all the options.
macros/latex/contrib/other/misc	truncate	<<<<truncate>>>>	Truncate text to a specified width.
info/lshort/mongolian	lshort-mongolian	<<<<lshort-mongolian>>>>	No caption.
fonts/semaphor	semaphor	<<<<semaphor>>>>	Semaphore alphabet font in METAFONT.
macros/latex/contrib/supported/vmargin	vmargin	<<<<vmargin>>>>	Set various dimensions.
info/webguide	webguide	<<<<webguide>>>>	Brief Guide to LaTeX Tools for Web publishing.
info/TrueType	truetype	<<<<True Type>>>>	How to use TrueType fonts with teTeX.
support/psutils	psutils	<<<<psutils>>>>	PostScript utilities.
macros/latex/contrib/supported/wordcount	wordcount	<<<<wordcount>>>>	Estimate the number of words in a LaTeX document.
macros/xmltex/base	xmltex	<<<<xmltex>>>>	Support for parsing XML documents.
macros/xmltex/contrib/xmlplay	xmlplay	<<<<xmlplay>>>>	Typeset Shakespeare's plays as marked up by Bosak.
language/hyphenation/ukrhyph	ukrhyph	<<<<ukrhyph>>>>	Ukranian hyphenation.
macros/latex/contrib/supported/trfsigns	trfsigns	<<<<trfsigns>>>>	Typeset transform signs.
macros/latex/contrib/supported/photo	photo	<<<<photo>>>>	A float environment for photographs.
macros/latex/contrib/supported/texshade	texshade	<<<<texshade>>>>	Package for setting nucleotide and peptide alignments.
help/wp-conv	wp-conv	<<<<wp-conv>>>>	FAQ on converters between (La)TeX and PC-Textprocessors.
fonts/trajan	trajan	<<<<trajan>>>>	Fonts from the Trajan column in Rome in 114 AD.
systems/unix/teTeX	tetex	<<<<tetex>>>>	The TeX distribution for Unix/Linux.
systems/texlive	texlive	<<<<texlive>>>>	A CD-ROM distribution of TeX and friends.
fonts/skak	skak	<<<<skak>>>>	Typeset chess games.
macros/latex/contrib/supported/mparhack	mparhack	<<<<mparhack>>>>	A workaround for the LaTeX bug in marginpars.
macros/latex/contrib/supported/hvmath	hvmath	<<<<hvmath>>>>	Support for using the Micropress HV-Math fonts (Helvetica Maths).
info/lshort/english	lshort-english	<<<<lshort-english>>>>	A (Not So) Short Introduction to LaTeX2e.
biblio/bibtex/contrib/inlinebib	inlinebib	<<<<inlinebib>>>>	Inlined \cites.
info/ltt	ltt	<<<<ltt>>>>	Example code for "LaTeX Tips und Tricks" book.
info/lshort/portuguese	lshort-portuguese	<<<<lshort-portuguese>>>>	Introduction to LaTeX in Portuguese.
info/lshort/finnish	lshort-finnish	<<<<lshort-finnish>>>>	Finnish version of   A Short      Introduction to LaTeX2e
info/lshort/french	lshort-french	<<<<lshort-french>>>>	No caption.
macros/latex/contrib/supported/grfpaste	grfpaste	<<<<grfpaste>>>>	Include fragments of a dvi file.
macros/latex/contrib/supported/manfnt	manfnt	<<<<manfnt>>>>	LaTeX support for the TeX book symbols.
info/lshort/german	lshort-german	<<<<lshort-german>>>>	German version of   A Short      Introduction to LaTeX2e : LaTeX2e-Kurzbeschreibung.
biblio/bibtex/contrib/oxford	oxford	<<<<oxford>>>>	A BibTeX style of citations for the humanities.
macros/latex/contrib/supported/outliner	outliner	<<<<outliner>>>>	Change section levels easily.
macros/latex/contrib/supported/muthesis	muthesis	<<<<muthesis>>>>	Document classes for University of Manchester Department of      Computer Science.
graphics/metapost	metapost	<<<<metapost>>>>	No caption.
info/lshort/italian	lshort-italian	<<<<lshort-italian>>>>	Italian translation of the   (Not So) Short Introduction to LaTeX.
fonts/ifsym	ifsym	<<<<ifsym>>>>	Symbols for alpinistic, electronic, meteorological, geometric etc. usage.
dviware/dvips	dvips	<<<<dvips>>>>	A dvi to PostScript driver.
macros/latex/contrib/supported/fancynum	fancynum	<<<<fancynum>>>>	Typeset numbers.
macros/latex/contrib/supported/contour	contour	<<<<contour>>>>	Print a coloured contour around text.
macros/latex/contrib/supported/fixfoot	fixfoot	<<<<fixfoot>>>>	Multiple use of the same footnote text
fonts/eulervm	eulervm	<<<<eulervm>>>>	Euler virtual math fonts.
help/Catalogue	catalogue	<<<<catalogue>>>>	A catalogue of what's available on CTAN.
graphics/metapost/contrib/macros/expressg	expressg	<<<<expressg>>>>	Diagrams consisting of boxes, lines, and annotations.
macros/latex/contrib/supported/docmfp	docmfp	<<<<docmfp>>>>	Document non-LaTeX code.
macros/latex/contrib/supported/currvita	currvita	<<<<currvita>>>>	Package for typesetting a curriculum vitae.
macros/latex/contrib/other/citeref	citeref	<<<<citeref>>>>	Support backward references in the bibliography.
macros/latex/contrib/supported/flabels	flabels	<<<<flabels>>>>	Labels for files and folders.
macros/latex/contrib/supported/cooking	cooking	<<<<cooking>>>>	Typeset recipes.
language/chinese/CJK	cjk	<<<<cjk>>>>	No caption.
support/chktex	chktex	<<<<chktex>>>>	No caption.
biblio/bibtex/contrib/german/dinat	dinat	<<<<dinat>>>>	Bibliography style for German texts.
macros/latex/contrib/supported/combine	combine	<<<<combine>>>>	Bundle individual documents into a single document.
macros/latex/contrib/supported/smflatex	smflatex	<<<<smflatex>>>>	Classes conforming to Societie Mathematique de France.
macros/latex/contrib/supported/sf298	sf298	<<<<sf298>>>>	Standard form 298.
macros/latex/contrib/supported/regcount	regcount	<<<<regcount>>>>	Display the allocation status of the TeX registers.
macros/latex/contrib/other/smartref	smartref	<<<<smartref>>>>	Extend LaTeX's \ref capability.
macros/latex/contrib/supported/play	play	<<<<play>>>>	Typeset plays.
macros/latex/contrib/other/yplan	yplan	<<<<yplan>>>>	Daily planner type calendar.
macros/latex/contrib/supported/snapshot	snapshot	<<<<snapshot>>>>	List the external dependencies of a LaTeX document.
macros/latex/contrib/supported/subfloat	subfloat	<<<<subfloat>>>>	Sub-numbering for figures and tables.
latex/support/contrib/supported/topfloat	topfloat	<<<<topfloat>>>>	Move float's to the top of the page.
macros/latex/contrib/supported/pitthesis	pitthesis	<<<<pitthesis>>>>	Document class for University of Pittsburgh theses.
macros/latex/contrib/other/postcards	postcards	<<<<postcards>>>>	Facilitates mass-mailing of postcards (junkmail).
macros/latex/contrib/supported/tmmath	tmmath	<<<<tmmath>>>>	Support for using the Micropress TM-Math fonts.
macros/latex/contrib/supported/totpages	totpages	<<<<totpages>>>>	Access last page number and page mark of last page.
macros/generic/2up	twoup	<<<<twoup>>>>	Print two virtual pages on each physical page.
fonts/utilities/ttf2pk	ttf2pk	<<<<ttf2pk>>>>	No caption.
graphics/metapost/macros/3d	threed	<<<<threed>>>>	3D animations.
macros/latex/contrib/supported/t-angles	t-angles	<<<<t-angles>>>>	Draw tangles, trees, Hopf algebra operations and other pictures.
macros/latex/contrib/supported/romannum	romannum	<<<<romannum>>>>	Generate roman numerals instead of arabic digits.
macros/plain/contrib/misc	plainmisc	<<<<plainmisc>>>>	Miscellaneous useful macros for plain TeX.
macros/latex/contrib/supported/pictex2	pictex2	<<<<pictex2>>>>	Adds relative coords and rules for dots in plots.
macros/latex/contrib/supported/textopo	textopo	<<<<textopo>>>>	Annotated membrane protein topology plots.
macros/latex/contrib/supported/savefnmark	savefnmark	<<<<savefnmark>>>>	Save name of the footnote mark for reuse.
systems/vtex	vtex	<<<<VTeX/Free>>>>	TeX system and PDF support for Linux and OS/2.
macros/latex/contrib/supported/titling	titling	<<<<titling>>>>	Control over the typesetting of the \maketitle command.
macros/latex/contrib/supported/substr	substr	<<<<substr>>>>	Deal with substrings in strings.
macros/latex/contrib/supported/listbib	listbib	<<<<listbib>>>>	Lists contents of bibtex files for archival purposes.
macros/latex/contrib/other/gene/limap	limap	<<<<limap>>>>	Typeset maps and blocks according to the Information Mapping method.
macros/latex/contrib/supported/isorot	isorot	<<<<isorot>>>>	Rotation of document elements.
macros/latex/contrib/supported/koma-script	koma-script	<<<<koma-script>>>>	European typography for article/book/report classes.
macros/latex/contrib/supported/multibib	multibib	<<<<multibib>>>>	Multiple bibliographies within one document.
support/latex2html	latex2html	<<<<latex2html>>>>	Convert LaTeX into HTML documents.
macros/latex/contrib/supported/frankenstein	frankenstein	<<<<frankenstein>>>>	A collection of LaTeX packages.
macros/latex/contrib/supported/pdfscreen	pdfscreen	<<<<pdfscreen>>>>	Support screen-based document design.
macros/latex/contrib/supported/pdfslide	pdfslide	<<<<pdfslide>>>>	Presentation slides using pdftex.
macros/latex/contrib/supported/galois	galois	<<<<galois>>>>	Write Galois connections in two-ddimensional style.
macros/latex/contrib/supported/nonfloat	nonfloat	<<<<nonfloat>>>>	Non-floating table and figure captions.
info/lshort/polish	lshort-polish	<<<<lshort-polish>>>>	Introduction to LaTeX in Polish.
macros/latex/contrib/supported/ncctools	ncctools	<<<<ncctools>>>>	No caption.
macros/latex/contrib/supported/mflogo	mflogo	<<<<mflogo>>>>	LaTeX support for MetaFont and  logo fonts.
info/lshort/russian	lshort-russian	<<<<lshort-russian>>>>	No caption.
info/lshort/spanish	lshort-spanish	<<<<lshort-spanish>>>>	No caption.
macros/latex/base	ltxdoc	<<<<ltxdoc>>>>	Class for documented LaTeX2e classes.
macros/latex/contrib/other/lexikon	lexikon	<<<<lexikon>>>>	Implements commands to generate a two language dictionary.
support/html	html	<<<<html>>>>	Various TeX documentation converted to HTML.
macros/latex/contrib/supported/makecmds	makecmds	<<<<makecmds>>>>	The new \makecommand command always (re)defines a command.
macros/latex/contrib/supported/minutes	miutes	<<<<minutes>>>>	Package for writing minutes of meetings.
fonts/mathpazo	mathpazo	<<<<mathpazo>>>>	Pazo Math fonts and LaTeX package to typeset Palatino.
macros/latex/contrib/supported/lhelp	lhelp	<<<<lhelp>>>>	Miscelaneous helper pacakges.
macros/latex/contrib/other/extsizes	extsizes	<<<<extsizes>>>>	Extends article and report with extra sized fonts.
fonts/cryst	cryst	<<<<cryst>>>>	Font for symmetry elements in crystallography.
fonts/bookhands	bookhands	<<<<bookhands>>>>	A collection of book-hand fonts.
tools/bzip2	bzip2	<<<<bzip2>>>>	Compression program.
macros/latex/contrib/supported/bytefield	bytefield	<<<<bytefield>>>>	Create illustrations for network protocol specifications.
biblio/bibtex/8-bit	bibtex8bit	<<<<bibtex8bit>>>>	A fully 8-bit adaptation of BibTeX 0.99.
fonts/armenian	armenian	<<<<armenian>>>>	A package which lets one to write in Armenian with TeX.
biblio/bibtex/contrib	apacite	<<<<apacite>>>>	No caption.
macros/generic/arrayjob	arrayjob	<<<<arrayjob>>>>	Array data structures for (La)TeX.
macros/latex/contrib/other/calxxxx	calxxxx	<<<<calxxxx>>>>	Prints a card-size calendar for any year.
macros/latex/contrib/supported/bizcard	bizcard	<<<<bizcard>>>>	Typeset business cards.
biblio/bibtex/contrib/bibhtml	bibhtml	<<<<bibhtml>>>>	BibTeX support for HTML files.
macros/latex/contrib/supported/bibunits	bibunits	<<<<bibunits>>>>	Multiple bibliographies in one document.
/macros/latex/contrib/supported/ascelike	ascelike	<<<<ascelike>>>>	Bibliography style for the American Society of Civil Engineer.
fonts/archaic	archaic	<<<<archaic>>>>	A collection of archaic fonts.
macros/latex/contrib/supported/aeguill	aeguill	<<<<aeguill>>>>	Add several kinds of guillemets to the ae fonts.
macros/latex/contrib/supported/abstract	abstract	<<<<abstract>>>>	Control the typesetting of the abstract environment.
macros/latex/contrib/supported/acmconf	acmconf	<<<<acmconf>>>>	Association for Computing Machinery conference proceedings.
macros/latex/contrib/supported/aastex	aastex	<<<<aastex>>>>	American Astronomical Society format.
macros/latex/contrib/other/comment	comment	<<<<comment>>>>	Selectively include/excludes portions of text.
macros/latex/contrib/supported/geometry	geometry	<<<<geometry>>>>	Flexible and complete interface to document dimensions.
macros/latex/contrib/supported/cmdtrack	cmdtrack	<<<<cmdtrack>>>>	Check used commands.
macros/latex/contrib/supported/booktabs	booktabs	<<<<booktabs>>>>	Nicer layout of tables.
macros/latex/contrib/supported/yafoot	yafoot	<<<<yafoot>>>>	Miscellaneous footnote commands.
macros/latex/contrib/supported/stdclsdv	stdclsdv	<<<<stdclsdv>>>>	Provide sectioning information for package writers.
macros/latex/contrib/supported/umoline	umoline	<<<<umoline>>>>	Underlines text allowing line breaking.
macros/latex/contrib/supported/newvbtm	newvbtm	<<<<newvbtm>>>>	Define your own verbatim-like environment.
support/html2text	html2text	<<<<html2text>>>>	Convert HTML into text.
macros/latex/contrib/supported/natbib	natbib	<<<<natbib>>>>	Bibliography style with author-year and numbered references.
macros/latex/contrib/other/ntabbing	ntabbing	<<<<ntabbing>>>>	Simple tabbing extension for automatic line numbering.
web/c_cpp/cwebbin	cwebbin	<<<<cwebbin>>>>	CWEB for ANSI-C/C++ compilers on UNIX/Linux, MS/Windows, and Amiga.
biblio/bibtex/utils	bbl2html	<<<<bbl2html>>>>	Convert a LaTeX .bbl file to formatted html code.
support/ps2eps	ps2eps	<<<<ps2eps>>>>	Produce Encapsulated PostScript from single page PostScript.
macros/latex/contrib/supported/misc	chngpage	<<<<chngpage>>>>	Change the page layout in the middle of a document.
macros/latex/required/amslatex/math	amsmath	<<<<amsmath>>>>	AMS math facilities for LaTeX.
graphics/transfig	transfig	<<<<transfig>>>>	Transform xfig pictures into many other formats.
graphics/xfig	xfig	<<<<xfig>>>>	XWindows vector drawing program.
systems/unix/TeXmacs	texmacs	<<<<TeXmacs>>>>	Structured text editor for TeX.
macros/latex/contrib/other/misc	notoccite	<<<<notoccite>>>>	Prevent erroneous numbering of cites when using BibTeX/unsrt.
macros/context/cont-tmf	m-pictex	<<<<m-pictex>>>>	Solves the `out of dimen' problem.
fonts/cyrillic/lh	lh	<<<<lh>>>>	Olga Lapko's LH fonts.
macros/latex/contrib/supported/ticket	ticket	<<<<ticket>>>>	Make labels, visting-cards, pins with LaTeX.
macros/latex/contrib/other/misc	raggedr	<<<<raggedr>>>>	Set an entire document raggedright.
language/french	french	<<<<french>>>>	Style for French typography: light version.
support/pstoedit	pstoedit	<<<<pstoedit>>>>	Translate PostScript and PDF to other formats.
macros/latex/contrib/supported/ifmslide	ifmslide	<<<<ifmslide>>>>	Presentation slides (from computer screen) and printouts.
systems/win32/bakoma	bakoma	<<<<bakoma>>>>	TeX for MS-Windows for electronic documents.
macros/latex/contrib/supported/arydshln	arydshln	<<<<arydshln>>>>	Horizontal and vertical dashed lines.
support/poster	poster	<<<<poster>>>>	Scale PostScript images for larger media or tiling.
macros/generic/hexdump	hexdump	<<<<hexdump>>>>	Read and format ASCII hexdump files.
macros/latex/contrib/supported/lineno	lineno	<<<<lineno>>>>	Line numbers on paragraphs.
fonts/cmbright	cmbright	<<<<cmbright>>>>	Support for CM Bright fonts in LaTeX.
macros/latex/contrib/supported/ccfonts	ccfonts	<<<<ccfonts>>>>	Support for Concrete text and math fonts in LaTeX.
macros/latex/contrib/supported/makeglos	makeglos	<<<<makeglos>>>>	Include a glossary into a document.
macros/latex/contrib/supported/gloss	gloss	<<<<gloss>>>>	Create glossaries using BibTeX.
macros/latex/contrib/supported/nomencl	nomencl	<<<<nomencl>>>>	Produce lists of symbols as in nomenclature.
support/glosstex	glosstex	<<<<glosstex>>>>	Prepare glossaries in LaTeX.
macros/latex/contrib/supported/camel	index	<<<<index>>>>	Extended index for LaTeX including multiple indexes.
support/ghostscript/rjl	gsview	<<<<gsview>>>>	View PostScript under MS-Windows or OS/2.
macros/latex/base	makeidx	<<<<makeidx>>>>	Standard LaTeX package for creating indexes.
macros/latex/required/tools	verbatim	<<<<verbatim>>>>	The LaTeX verbatim environment.
macros/latex/contrib/supported/moreverb	moreverb	<<<<moreverb>>>>	Extended verbatim.
digests/tugboat/t-of-c	tugboat-toc	<<<<tugboat-toc>>>>	The complete accumulation of TUGboat tables of contents.
biblio/bibtex/contrib/	jasm99	<<<<jas99_m>>>>	BibTeX style for American Meteorological Society (AMS).
macros/latex/required/babel/contrib/spanish	spanishb	<<<<spanishb>>>>	Support for the Spanish language in Babel.
macros/latex/contrib/other/misc	cases	<<<<cases>>>>	Numbered cases environment
support/epstopdf	epstopdf	<<<<epstopdf>>>>	Convert eps to encapsulated pdf using gs.
support/utf2any	utf2any	<<<<utf2any>>>>	Converting UTF-7 and UTF-8 to LaTeX, HTML, and other text formats.
systems/unix/teTeX/1.0/contrib	texdoctk	<<<<texdoctk>>>>	Easy access to package documentation.
biblio/bibtex/utils/isi2bibtex	isi2bibtex	<<<<isi2bibtex>>>>	Converter for ISI to  BibTeX.
systems/win32/LaTeX_WIDE	latexwide	<<<<LaTeX-WIDE>>>>	Multifunctional editor for LaTeX in MSWindows.
macros/latex/contrib/other/misc	secdot	<<<<secdot>>>>	Section numbers with trailing dots
dviware/catdvi	catdvi	<<<<catdvi>>>>	A DVI to plain text translator.
systems/win32/TeXnicCenter	texniccenter	<<<<TeXnicCenter>>>>	Integrated development environment for LaTeX on MSWindows.
fonts/eurosans	eurosans	<<<<eurosans>>>>	Interface to Adobe's free Euro fonts.
macros/generic/TeX-PS/cmyk-hax	cmyk-hax	<<<<cmyk-hax>>>>	A TeX macro package for colour manipulation (using PostScript).
macros/latex/contrib/supported/titlesec	titlesec	<<<<titlesec>>>>	Select alternative section titles.
systems/mac	epsfview	<<<<epsfview>>>>	AppleScript tool (for Mac) for viewing figures generated with MetaPost.
support/latex2man	latex2man	<<<<latex2man>>>>	Translate LaTeX-based manual pages into Unix man format.
macros/latex/contrib/supported/envlab	envlab	<<<<envlab>>>>	Facilates addressing envelopes or mailing labels.
info	metafp	<<<<metafp>>>>	Some Experiences in Running METAFONT and MetaPost.
macros/latex/required/amslatex	amscls	<<<<amscls>>>>	AMS document class for LaTeX.
usergrps/uktug/faq	faq	<<<<faq>>>>	The UK TeX Users Group Frequently Asked Questions.
fonts/utilities/fontinst	fontinst	<<<<fontinst>>>>	No caption.
dviware/dvichk	dvichk	<<<<dvichk>>>>	List the page numbers in a DVI file.
macros/latex/contrib/supported/misc	varindex	<<<<varindex>>>>	Luxury frontend to the \index command.
systems/win32/winshell	winshell	<<<<winshell>>>>	A MS-Windows32 user interface for TeX.
macros/latex/contrib/supported/akletter	akletter	<<<<akletter>>>>	Comprehensive letter support.
systems/os2/epmtfe	epmtfe	<<<<epmtfe>>>>	TeX environment for OS/2.
fonts/utilities/ttf2pt1	ttf2pt1	<<<<ttf2pt1>>>>	Converts True Type fonts into PS Type 1 fonts.
language/polish	pl-mf	<<<<pl-mf>>>>	Polish extension of Computer Modern fonts in MF sources.
web/matlabweb	matlabweb	<<<<matlabweb>>>>	Literate programming system for Matlab.
info/mil3	mil3	<<<<mil3>>>>	Samples from Math into LaTeX.
macros/latex/contrib/supported/acronym	acronym	<<<<acronym>>>>	Expand acronyms at least once.
obsolete/systems/msdos/latexcad	latexcad	<<<<latexcad>>>>	A CAD drawing package.
language/polish/plpsfont	plpsfont	<<<<plpsfont>>>>	Polish extension of Computer Modern fonts in Type1 format.
language/polish	plfonts	<<<<plfonts>>>>	Polish extension to CM fonts.
fonts/psfonts/polish/antp	antp	<<<<antp>>>>	Antykwa P\'o\l{}tawskiego: a Type 1 family of Polish traditional type.
fonts/psfonts/polish/antp	qxcm	<<<<qxcm>>>>	An experimental collection of extended CM fonts             in PostScript Type 1 format
macros/context	ppchtex	<<<<ppchtex>>>>	A package that can be used to typeset chemical formulas.
macros/context	context	<<<<context>>>>	The ConTeXt macro package.
info/simplified-latex	simplified-latex	<<<<simplified-latex>>>>	A Simplified Introduction to LaTeX.
support/thumbpdf	thumbpdf	<<<<thumbpdf>>>>	Thumbnails for pdfTeX and dvips/ps2pdf.
systems/pdftex	pdftex	<<<<pdftex>>>>	Generate PDF from TeX directly.
support/rtf2latex2e	rtf2latex2e	<<<<rtf2latex2e>>>>	Convert Rich Text Format (RTF) files to LaTeX2e.
graphics/pstricks	pstricks	<<<<pstricks>>>>	PostScript macros for TeX.
macros/latex/contrib/supported/sidecap	sidecap	<<<<sidecap>>>>	Typeset captions sideways.
macros/latex/contrib/supported/springer/svjour	svjour	<<<<svjour>>>>	Springer-Verlag journal macros.
support/rmligs	rmligs	<<<<rmligs>>>>	Remove incorrectly used ligatures from German LaTeX documents.
support/prv	prv	<<<<prv>>>>	Compile, preview, and print LaTeX documents.
macros/latex/contrib/supported/SIunits	siunits	<<<<siunits>>>>	International System of Units.
macros/latex/contrib/supported/twoup	twoupltx	<<<<twoup>>>>	Print two virtual pages on each physical page.
support/wp2latex	wp2latex	<<<<wp2latex>>>>	Convert WordPerfect documents to LaTeX.
macros/latex/contrib/supported/tocbibind	tocbibind	<<<<tocbibind>>>>	Add bibliography/index/contents to Table of Contents.
macros/latex/contrib/supported/webeq	web	<<<<web>>>>	Establishes a page layout for an on-screen (PDF) document.
systems/mac/oztex-german	oztex-german	<<<<oztex-german>>>>	German version of   oztex .
systems/unix/teTeX/contrib	texdoc	<<<<texdoc>>>>	Documentation files for teTeX-texmf.
web/webfiles	webfiles	<<<<webfiles>>>>	Include several CWEB and/or Spidery WEB documents in a single LaTeX .
macros/latex/contrib/supported/paralist	paralist	<<<<paralist>>>>	Enumerate and itemize within paragraphs.
macros/passivetex	passivetex	<<<<passivetex>>>>	Support package for XML/SGML typesetting
macros/latex/contrib/supported/setspace	setspace	<<<<setspace>>>>	Set space between lines (e.g., double and one and a half spacing.
systems/win32/winlatex	winlatex	<<<<winlatex>>>>	FrontEnd for TeX, Win98/NT, needs Microsoft VisualBasic-DLLs.
support/tiny_c2l	tinyc2l	<<<<tinyc2l>>>>	Pretty print C/C++/Java source code using LaTeX.
support/xtem_texmenu	xtem	<<<<xtem>>>>	An X11 TeX menu built on Tcl/Tk.
macros/latex/contrib/supported/titlesec	titletoc	<<<<titletoc>>>>	Alternative headings for toc/tof/tol.
fonts/wsuipa	wsuipa	<<<<wsuipa>>>>	Style for using International Phonetic Alphabet fonts.
fonts/tipa	tipa	<<<<tipa>>>>	Fonts and macros for IPA phonetics characters.
support/pssplit	pssplit	<<<<pssplit>>>>	Print selected pages from PostScript files.
support/wsuipa2tipa	wsuipa2tipa	<<<<wsuipa2tipa>>>>	Translate wsuipa font commands into tipa font commands.
macros/xmltex/contrib/xml-catalogue	xml-catalogue	<<<<xml-catalogue>>>>	Use xmltex to format the TeX Catalogue.
fonts/korean/HLaTeX	uhc-gothic	<<<<uhc-gothic>>>>	Fonts for the Korean language.
macros/latex/contrib/supported/xtab	xtab	<<<<xtab>>>>	Break tables across pages.
macros/latex/required/psnfss	psnfss	<<<<psnfss>>>>	Font support for common PostScript fonts.
macros/latex/contrib/other/misc	placeins	<<<<placeins>>>>	Control float placement.
macros/generic	random	<<<<random>>>>	Generating "random" numbers in TeX.
macros/latex/contrib/supported/tocloft	tocloft	<<<<tocloft>>>>	Control table of contents, figures, etc.
macros/latex/contrib/supported/koma-script/contrib	scrnger	<<<<scrnger>>>>	Support for ngerman in scrlettr and scrdate in koma-script.
macros/latex/contrib/supported/mdwtools	syntax-mdw	<<<<syntax>>>>	Typeset syntax descriptions.
macros/latex/contrib/other/syntax	syntax2	<<<<syntax>>>>	Creation of syntax-diagrams.
macros/latex/contrib/supported/refcheck	refcheck	<<<<refcheck>>>>	Check references (in figures, table, equations, etc).
support/tth/dist	tth	<<<<tth>>>>	A TeX to HTML translator.
support/references	references	<<<<references>>>>	Bibliographic software supporting LaTeX/BibTeX.
systems/win32/texshell32	texshell32	<<<<texshell32>>>>	A free TeXShell for MS-Windows 95 and NT.
fonts/psfonts/polish	pl-qx	<<<<pl-qx>>>>	LaTeX support for extra Polish fonts (antyktor, qfonts).
support/xtrcode	xtrcode	<<<<xtrcode>>>>	Extract contents of LaTeX environments.
support/ps_conv	ps_conv	<<<<ps_conv>>>>	A converter from PostScript to Encapsulated PostScript.
support/psrip	psrip	<<<<psrip>>>>	Extracts images from PostScript files.
systems/mac/pdftex	pdftex_oztex	<<<<pdftex_oztex>>>>	PdfTeX designed to run with OzTeX.
macros/latex/contrib/supported/ut-thesis	ut-thesis	<<<<ut-thesis>>>>	University of Toronto thesis style.
support/txt2tex	txt2tex	<<<<txt2tex>>>>	Add LaTeX markup to a text document.
support/tth/rpm	tth-rpm	<<<<tth-rpm>>>>	TeX to HTML translator packaged for RedHat Linux.
systems/win32/miktex/util	tth-win	<<<<tth-win>>>>	TeX-to-HTML converter for MS-Windows32.
macros/latex/contrib/other/misc	parskip	<<<<parskip>>>>	Layout with zero \parindent, non-zero \parskip.
documentation/spanish/TeEncontreX	teencontrex	<<<<TeEncontreX>>>>	HTML-based help for TeX and LaTeX.
macros/latex/contrib/supported/scale	scale	<<<<scale>>>>	Scale document by sqrt(2) or magstep(2).
macros/latex/contrib/supported/songbook	songbook	<<<<songbook>>>>	Package for typesetting song lyrics.
macros/latex/contrib/supported/permute	permute	<<<<permute>>>>	Supportfor symmetric groups.
biblio/bibtex/utils/qbibman	qbibman	<<<<qbibman>>>>	Graphical frontend to   BibTool .
macros/latex/contrib/other/misc	ulem	<<<<ulem>>>>	Package for underlining.
macros/latex/contrib/other/misc	relsize	<<<<relsize>>>>	Set the font size relative to the current font size.
macros/latex/contrib/supported/xymtex	xymtex	<<<<xymtex>>>>	Typesetting chemical structures.
macros/latex/contrib/supported/ms	prelim2e	<<<<prelim2e>>>>	Allows the marking of preliminary versions of a document.
macros/latex/contrib/supported/bosisi	quotes	<<<<quotes>>>>	No caption.
support/rail	rail	<<<<rail>>>>	No caption.
macros/latex/contrib/supported/schedule	schedule	<<<<schedule>>>>	No caption.
macros/latex/contrib/supported/frankenstein	slemph	<<<<slemph>>>>	Slanted emphasis in LaTeX.
macros/latex/contrib/supported/bosisi	sobolev	<<<<sobolev>>>>	No caption.
support/emacs-modes/swiftex	swiftex	<<<<swiftex>>>>	Edit doc.sty and normal LaTeX files with GNU Emacs.
support/tex2rtf	tex2rtf	<<<<tex2rtf>>>>	No caption.
macros/latex/contrib/supported/frankenstein	titles	<<<<titles>>>>	Titles of books, articles, etc in LaTeX.
usergrps/tug	twg-list	<<<<twg-list>>>>	Members of the TUG Technical Working Groups.
systems/win32	win95-guide	<<<<win95-guide>>>>	No caption.
info/spanish	tipos	<<<<tipos>>>>	Description of fonts for TeX in Spanish.
graphics/texpict	texpict	<<<<texpict>>>>	Create drawings for LaTeX.
fonts/bookhands/uncial	uncial	<<<<uncial>>>>	Manuscript book-hand fonts.
fonts/vicentino	vicentino	<<<<vicentino>>>>	Vicentino fonts.
macros/texinfo	texinfo	<<<<texinfo>>>>	Texinfo documentation system.
fonts/pacioli	pacioli	<<<<pacioli>>>>	Fonts designed by Fra Luca de Pacioli in 1497.
language/hyphenation/ruhyphen	ruhyphen	<<<<ruhyphen>>>>	Russian hyphenation.
systems/mac/oztex	oztex	<<<<oztex>>>>	TeX for the Macintosh.
macros/latex/contrib/supported/shorttoc	shorttoc	<<<<shorttoc>>>>	Table of contents with different depths.
biblio/bibtex/contrib/swebib	swebib	<<<<swebib>>>>	Swedish translation of standard BibTeX styles.
info/win-help/latex/russian	russian-help	<<<<russian-help>>>>	LaTeX help in Russian.
macros/latex/contrib/supported/thesis	thesis	<<<<thesis>>>>	Typeset thesis.
macros/latex/contrib/other/misc	topcapt	<<<<topcapt>>>>	Place captions above figures and tables.
macros/latex/contrib/supported/Tabbing	tabbing	<<<<tabbing>>>>	Tabbing with accented letters.
macros/latex/contrib/supported/protocol	protocol	<<<<protocol>>>>	Typeset meeting protocols.
macros/latex/contrib/supported/showlabels	showlabels	<<<<showlabels>>>>	Show label commands in the margin.
macros/latex/contrib/supported/quotchap	quotchap	<<<<quotchap>>>>	Decorative chapter headings.
fonts/utilities/pbmtogf	pbmtogf	<<<<pbmtogf>>>>	Convert pbm images to gf font files.
support/texdepend	texdepend	<<<<texdepend>>>>	Find dependencies in a LaTeX file.
macros/latex/contrib/supported/overpic	overpic	<<<<overpic>>>>	Combine LaTeX commands over included graphics.
macros/latex/contrib/supported/jknappen	sgmlcmpt	<<<<sgmlcmpt>>>>	Suppport for LaTeX formulae as SGML PCDATA.
language/tamil/wntamil	wntamil	<<<<wntamil>>>>	Tamil to TeX converter.
macros/latex/contrib/supported/t2	t2	<<<<t2>>>>	No description available.
language/oriya	oriya	<<<<oriya>>>>	Typesetting the Oriya script using TeX.
macros/latex/contrib/other/thumb	thumb	<<<<thumb>>>>	Thumb marks in documents.
language/polish	platex	<<<<platex>>>>	Typeset Polish documents with LaTeX and Polish fonts.
macros/latex/contrib/other/pawpict	pawpict	<<<<pawpict>>>>	Using graphics from PAW.
macros/latex/contrib/supported/ssqquote	ssqquote	<<<<ssqquote>>>>	No caption.
macros/latex/contrib/supported/oberdiek	twoopt	<<<<twoopt>>>>	Definitions with two optional arguments.
fonts/uni	uni	<<<<uni>>>>	The Universal font.
macros/latex/contrib/supported/oberdiek	pagesel	<<<<pagesel>>>>	Selecting shipout pages.
macros/generic/TeX-PS	tex-ps	<<<<tex-ps>>>>	TeX to PostScript generic macros and add-ons.
systems/win32/winedt	winedt	<<<<winedt>>>>	MS-Windows shell and editor for TeX.
systems/win32/snviewer	snviewer	<<<<snviewer>>>>	Scientific Notebook Viewer.
macros/latex/contrib/supported/utorontothesis	utorontothesis	<<<<utorontothesis>>>>	No caption.
fonts/stmaryrd/ps-type1/hoekwater	stmaryrd-ps	<<<<stmaryrd-ps>>>>	St Mary road signs in PostScript.
fonts/greek/yannis	yannisgr	<<<<yannisgr>>>>	Greek fonts by Yannis Haralambous.
macros/latex/contrib/supported/yfonts	yfonts	<<<<yfonts>>>>	Support for old German fonts.
macros/latex/contrib/supported/yhmath	yhmath	<<<<yhmath>>>>	Extended maths fonts for LaTeX.
language/yi4latex	yi4latex	<<<<yi4latex>>>>	No caption.
fonts/gothic/yinit	yinit	<<<<yinit>>>>	No caption.
macros/latex/contrib/supported/youngtab	youngtab	<<<<youngtab>>>>	Typeset Young-Tableaux.
macros/ytex	ytex	<<<<ytex>>>>	Macro package developed at MIT.
macros/latex/contrib/other/zed-csp	zed-csp	<<<<zed-csp>>>>	Typesetting Z and CSP format specifications.
fonts/zefonts	zefonts	<<<<zefonts>>>>	No caption.
dviware/xdvi	xdvi	<<<<xdvi>>>>	A dvi previewer for the X Window System.
dviware/xdvik	xdvik	<<<<xdvik>>>>	A version of xdvi with recursive searching.
macros/latex/required/tools	xr	<<<<xr>>>>	References to other LaTeX documents.
macros/latex/required/tools	xspace	<<<<xspace>>>>	Define commands that don't eat spaces.
macros/generic/diagrams/xypic	xypic	<<<<xypic>>>>	No caption.
tools/word2x	word2x	<<<<word2x>>>>	No caption.
macros/latex/contrib/other/misc	wrapfig	<<<<wrapfig>>>>	Produces figures which text can flow around.
systems/win32/wtex95	wtex95	<<<<wtex95>>>>	No caption.
macros/latex209/contrib/xarticle	xarticle	<<<<xarticle>>>>	A class that allows use of 7pt, 8pt and 9pt style options.
macros/latex/contrib/other/seminar/src	xcomment	<<<<xcomment>>>>	Allows selected environments to be included/excluded.
macros/latex/contrib/other/williams	williams	<<<<williams>>>>	Miscellaneous macros by Peter Williams.
systems/win32/fptex	windvi	<<<<windvi>>>>	MS-Windows DVI driver.
support/wmf2eps	wmf2eps	<<<<wmf2eps>>>>	Windows meta file conversion.
fonts/wnri	wnri	<<<<wnri>>>>	No caption.
macros/latex/contrib/other/misc	vruler	<<<<vruler>>>>	No caption.
macros/latex/contrib/other/warpcol	warpcol	<<<<warpcol>>>>	No caption.
fonts/wasy/ps-type1/hoekwater	wasy-ps	<<<<wasy-ps>>>>	No caption.
fonts/wasy	wasy	<<<<wasy>>>>	The wasy fonts (Waldis symbol fonts).
fonts/wasy2/ps-type1/hoekwater	wasy2-ps	<<<<wasy2-ps>>>>	No caption.
fonts/wasy2	wasy2	<<<<wasy2>>>>	The wasy fonts (Waldis symbol fonts).
macros/latex/contrib/supported/wasysym	wasysym	<<<<wasysym>>>>	Extra characters from the Waldis symbol fonts.
fonts/barcodes/willadt	wbarcode	<<<<wbarcode>>>>	Typeset common (and less common) barcodes with TeX.
systems/win32/web2c	web2c-win32	<<<<web2c-win32>>>>	No caption.
systems/web2c	web2c	<<<<web2c>>>>	The ``standard'' source C version of the TeX sysmtem.
macros/plain/contrib/vertex	vertex	<<<<vertex>>>>	Styles for economics working papers and journals.
systems/msdos/utilities/vfcomb	vfcomb	<<<<vfcomb>>>>	No caption.
fonts/utilities/vfinst	vfinst	<<<<vfinst>>>>	No caption.
macros/latex/contrib/supported/viiptart	viiptart	<<<<viiptart>>>>	No caption.
macros/latex/contrib/other/vita	vita	<<<<vita>>>>	No caption.
fonts/vietnamese/vncmr	vncmr	<<<<vncmr>>>>	A Vietnamese extension of the cmr fonts.
obsolete/macros/latex/contrib/other/misc	vpage	<<<<vpage>>>>	Set page sizes.
macros/generic/vrb	vrb	<<<<vrb>>>>	Verbatim macros via plain TeX.
macros/latex/contrib/supported/vrsion	vrsion	<<<<vrsion>>>>	Add version number to DVI file.
fonts/urwvf	urwvf	<<<<urwvf>>>>	No caption.
macros/latex/contrib/other/fragments	ut-backref	<<<<ut-backref>>>>	No caption.
macros/latex/contrib/other/misc	threeparttable	<<<<threeparttable>>>>	Tables with captions and notes all the same width.
macros/latex/contrib/supported/utthesis	utthesis	<<<<utthesis>>>>	No caption.
macros/latex/contrib/supported/uwthesis	uwthesis	<<<<uwthesis>>>>	University of Washington thesis style.
macros/latex/required/tools	varioref	<<<<varioref>>>>	Intelligent page references.
macros/latex/contrib/other/vdm	vdm	<<<<vdm>>>>	Typesetting VDM schemas.
macros/latex/contrib/supported/vector	vector	<<<<vector>>>>	No caption.
macros/generic	underlin	<<<<underlin>>>>	Package for underlining.
macros/latex/contrib/other/misc	underscore	<<<<underscore>>>>	Make ``_'' print as \textunderscore in text.
support/uniqleaf	uniqleaf	<<<<uniqleaf>>>>	No caption.
macros/latex/contrib/supported/units	units	<<<<units>>>>	No caption.
fonts/universa	universa	<<<<universa>>>>	No caption.
macros/latex/contrib/other/misc	url	<<<<url>>>>	Verbatim with URL-sensitive line breaks.
fonts/psfonts/urw	urw	<<<<urw>>>>	No caption.
macros/latex209/contrib/script	typearea	<<<<typearea>>>>	Set page margins.
macros/latex/contrib/supported/carlisle	typehtml	<<<<typehtml>>>>	Typeset HTML directly from LaTeX.
macros/plain/contrib/TypeSpec	typespec	<<<<typespec>>>>	No caption.
macros/latex/contrib/supported/uaclasses	uaclasses	<<<<uaclasses>>>>	No caption.
macros/latex/contrib/supported/ucthesis	ucthesis	<<<<ucthesis>>>>	No caption.
language/hyphenation	ukhyph	<<<<ukhyph>>>>	Hyphenation patterns for British English.
macros/latex/contrib/supported/ulsy	ulsy	<<<<ulsy>>>>	Extra mathematical characters.
macros/latex/contrib/supported/umlaute	umlaute	<<<<umlaute>>>>	No caption.
macros/latex/contrib/supported/niceframe	umrand	<<<<umrand>>>>	Package for page frames.
language/tibetan/steiner	ttt	<<<<ttt>>>>	A Tibetan Transcript Transliterator for LaTeX.
macros/latex/contrib/supported/tugboat	tugboat	<<<<tugboat>>>>	LaTeX macros for TUGboat articles.
macros/latex/contrib/supported/type1cm	type1cm	<<<<type1cm>>>>	No caption.
macros/latex/contrib/supported/treesvr	treesvr	<<<<treesvr>>>>	Tree macros.
macros/latex209/contrib/trees/tree_tex	treetex	<<<<treetex>>>>	No caption.
support/TeXshell/tsconfig	tsconfig	<<<<tsconfig>>>>	No caption.
support/ttf2mf	ttf2mf	<<<<ttf2mf>>>>	No caption.
fonts/utilities/ttf2pk	ttf2tfm	<<<<ttf2tfm>>>>	No caption.
support/ttftogf	ttftogf	<<<<ttftogf>>>>	Convert MS-Windows True Type fonts to GF format.
dviware/tmview	tmview	<<<<tmview>>>>	A DVI previewer for SVGA displays.
macros/latex/contrib/supported/tocvsec2	tocvsec2	<<<<tocvsec2>>>>	Section numbering and table of contents control.
fonts/utilities/t1install/toil	toil	<<<<toil>>>>	An installer of PostScript fonts for TeX.
macros/latex/contrib/other/tracking	tracking	<<<<tracking>>>>	No caption.
macros/generic/TeX-PS	trans	<<<<trans>>>>	A simple TeX macro package for PostScript transformations.
macros/latex/contrib/other/timesht	timesht	<<<<timesht>>>>	Package for typesetting time sheets.
macros/latex/contrib/supported/titlefoot	titlefoot	<<<<titlefoot>>>>	Add special material to footer of title page.
macros/latex/contrib/other/misc	titleref	<<<<titleref>>>>	A "\titleref" command to cross-reference section titles.
biblio/bibtex/utils/tkbibtex	tkbibtex	<<<<tkbibtex>>>>	A portable editor and browser for BibTeX files.
macros/latex/required/tools	theorem	<<<<theorem>>>>	No caption.
macros/latex/contrib/supported/carlisle	textcase	<<<<textcase>>>>	Case conversion ignoring mathematics.
graphics/tiff	tiff	<<<<tiff>>>>	The tiff graphics package.
support/pstools/tiff2ps	tiff2ps	<<<<tiff2ps>>>>	A PostScript program for converting TIFF files to EPS.
macros/latex/contrib/supported/piff	time	<<<<time>>>>	Defines a macro \now to print the current time.
macros/texsis	texsis	<<<<texsis>>>>	A Plain TeX macro package along the lines of LaTeX.
graphics/texsketch	texsk	<<<<texsk>>>>	Simple LaTeX drawing program for OS/2 PM.
macros/text1	text1	<<<<text1>>>>	TeX format from the University of Washington.
macros/latex/contrib/supported/supertabular	supertabular	<<<<supertabular>>>>	A multi-page tables package.
fonts/psfonts/ts1	textcomp	<<<<textcomp>>>>	Text Companion fonts.
macros/latex/contrib/supported/textfit	textfit	<<<<textfit>>>>	No caption.
macros/latex/contrib/supported/textmerg	textmerg	<<<<textmerg>>>>	Merge text in TeX and LaTeX.
support/textoolspro	textoolspro	<<<<textoolspro>>>>	No caption.
macros/latex/contrib/supported/textpos	textpos	<<<<textpos>>>>	Place boxes absolutely.
macros/latex/contrib/other/TeXemplar	texemplar	<<<<texemplar>>>>	A class for the journal of CervanTeX.
macros/tip	texip	<<<<texip>>>>	Macros from TeX in Practice.
support/texlist	texlist	<<<<texlist>>>>	Typeset program (or ASCII text file) listings.
support/texperf	texperf	<<<<texperf>>>>	A WordPerfect to LaTeX translator.
support/tex2ltx	tex2ltx	<<<<tex2ltx>>>>	No caption.
support/TeX4ht	tex4ht	<<<<tex4ht>>>>	Convert (La)TeX to HTML/XML.
graphics/texdraw	texdraw	<<<<texdraw>>>>	Graphical macros, using embedded PostScript.
systems/os2/texed	texed	<<<<texed>>>>	No caption.
fonts/tengwar	tengwar	<<<<tengwar>>>>	No caption.
macros/latex/contrib/supported/bezos	tensind	<<<<tensind>>>>	Typeset tensors.
macros/latex/contrib/supported/piff	tensor	<<<<tensor>>>>	No caption.
macros/latex/contrib/supported/termcal	termcal	<<<<termcal>>>>	Print a class calendar.
macros/latex/required/amslatex/math	testmath	<<<<testmath>>>>	Examples of the AMS-LaTeX package.
systems/os2/doc/TeX-Math	tex-math	<<<<tex-math>>>>	No caption.
biblio/bibtex/contrib/tex2bib	tex2bib	<<<<tex2bib>>>>	Converts bibitems embedded in a document to bib format.
macros/latex/contrib/other/misc	tabls	<<<<tabls>>>>	No caption.
macros/latex/required/tools	tabularx	<<<<tabularx>>>>	Tabulars that widen automatically.
macros/generic/tables	tap	<<<<tap>>>>	An easy TeX macro package for typesetting complex tables.
macros/generic/diagrams/taylor	taylor	<<<<taylor>>>>	Diagram macros by Paul Taylor.
macros/plain/contrib/tbe	tbe	<<<<tbe>>>>	Examples from Arvind Borde's TeX by Example.
language/vietnamese/tcvn	tcvn	<<<<tcvn>>>>	No caption.
info/tds	tds	<<<<tds>>>>	The TeX Directory Structure documentation.
macros/latex/contrib/supported/subfigure	subfigure	<<<<subfigure>>>>	Figures divided into subfigures.
macros/latex/contrib/other/fragments	subscript	<<<<subscript>>>>	Provides the textsubscript command.
macros/latex/base	syntonly	<<<<syntonly>>>>	No caption.
support/syngen	syngen	<<<<syngen>>>>	A tool for generating syntax diagrams from BNF\@.
systems/pdftex/bin/DJGPP	pdftex-djgpp	<<<<pdftex-djgpp>>>>	No caption.
macros/latex/contrib/supported/synttree	synttree	<<<<synttree>>>>	No caption.
graphics/bit2spr	sprite	<<<<sprite>>>>	Macros to set bitmaps with TeX.
macros/startex	startex	<<<<startex>>>>	No caption.
fonts/stmaryrd	stmaryrd	<<<<stmaryrd>>>>	St Mary Road symbols for functional programming.
macros/latex/contrib/supported/subeqn	subeqn	<<<<subeqn>>>>	Package for subequation numbering.
macros/latex/contrib/supported/subeqnarray	subeqnarray	<<<<subeqnarray>>>>	Equation array with sub numbering.
macros/latex/contrib/supported/jknappen	smartmn	<<<<smartmn>>>>	No caption.
macros/latex209/contrib/misc	sober	<<<<sober>>>>	Reduces the amount of white space on the page.
macros/latex/required/tools	somedefs	<<<<somedefs>>>>	No caption.
macros/latex/contrib/supported/soul	soul	<<<<soul>>>>	Hyphenation for letterspacing, underlining, and more.
language/hyphenation	sorhyph	<<<<sorhyph>>>>	Upper sorbian hyphenations patterns.
language/spanish	spanish	<<<<spanish>>>>	No caption.
macros/latex/contrib/other/misc	sphack	<<<<sphack>>>>	No caption.
language/sinhala	sinhala	<<<<sinhala>>>>	Support for the sinhala language.
language/tibetan/sirlin	sirlin	<<<<sirlin>>>>	No caption.
macros/latex/contrib/other/slashbox	slashbox	<<<<slashbox>>>>	No caption.
macros/latex/contrib/supported/carlisle	slashed	<<<<slashed>>>>	Put a slash through characters.
macros/latex/contrib/supported/slidenotes	slidenotes	<<<<slidenotes>>>>	No caption.
macros/latex/base	slides	<<<<slides>>>>	No caption.
macros/latex/required/babel	slovak	<<<<slovak>>>>	Typeset Slovakian documents.
macros/latex/contrib/other/smallcap	smallcap	<<<<smallcap>>>>	No caption.
language/hyphenation	shhyphl	<<<<shhyphl>>>>	Serbo-croat hyphenation written in the latin alphabet.
macros/latex/contrib/supported/shortlst	shortlst	<<<<shortlst>>>>	No caption.
macros/latex/contrib/supported/showdim	showdim	<<<<showdim>>>>	No caption.
macros/latex/required/tools	showkeys	<<<<showkeys>>>>	Show label, ref, cite and bib keys.
macros/latex/contrib/other/siam	siam	<<<<siam>>>>	Styles for SIAM publications.
macros/latex/contrib/supported/siggraph	siggraph	<<<<siggraph>>>>	No caption.
usergrps/uktug/baskervi/4_4	simpsons	<<<<simpsons>>>>	MetaFont source for Simpsons characters.
macros/latex/contrib/supported/serial	serial	<<<<serial>>>>	Generate serial letters.
macros/latex/contrib/supported/sfg	sfg	<<<<sfg>>>>	No caption.
macros/latex/contrib/supported/sfheaders	sfheaders	<<<<sfheaders>>>>	No caption.
macros/latex/contrib/supported/shadbox	shadbox	<<<<shadbox>>>>	Shade the background of any box (text, figure, table, etc.).
macros/latex/contrib/supported/shadethm	shadethm	<<<<shadethm>>>>	No caption.
macros/latex209/contrib/shading	shading	<<<<shading>>>>	A LaTeX Style file for putting text on a shaded background.
macros/latex209/contrib/misc	shadow	<<<<shadow>>>>	Shadows.
macros/latex/contrib/other/misc	shapepar	<<<<shapepar>>>>	A macro to typeset paragraphs in specific shapes.
macros/latex/contrib/supported/sauterfonts	sauterfonts	<<<<sauterfonts>>>>	No caption.
macros/latex/contrib/supported/carlisle	scalefnt	<<<<scalefnt>>>>	Rescale fonts to arbitrary sizes.
macros/latex/contrib/other/script	script	<<<<script>>>>	Variant report / book styles.
macros/latex/contrib/other/misc	section	<<<<section>>>>	Sections.
macros/latex/contrib/supported/sectsty	sectsty	<<<<sectsty>>>>	Control sectional headers.
macros/latex/contrib/other/misc	selectp	<<<<selectp>>>>	No caption.
macros/latex/contrib/supported/semantic	semantic	<<<<semantic>>>>	No caption.
macros/latex/contrib/other/seminar	seminar	<<<<seminar>>>>	Overhead slides.
macros/latex/contrib/supported/rplain	rplain	<<<<rplain>>>>	Redefines the `plain' pagestyle.
fonts/rsfs/ps-type1/hoekwater	rsfs-ps	<<<<rsfs-ps>>>>	No caption.
fonts/rsfs	rsfs	<<<<rsfs>>>>	No caption.
macros/generic	ruler	<<<<ruler>>>>	A ruler for TeX.
fonts/archaic/runic	runic	<<<<runic>>>>	Fonts for Anglo-Saxon futharc script.
support/s2latex	s2latex	<<<<s2latex>>>>	A scribe to LaTeX converter.
macros/latex/contrib/supported/saferef	saferef	<<<<saferef>>>>	No caption.
language/sanskrit	sanskrit	<<<<sanskrit>>>>	No caption.
fonts/cm/sauter	sauter	<<<<sauter>>>>	No caption.
macros/generic/rlepsf	rlepsf	<<<<rlepsf>>>>	No caption.
macros/latex/contrib/supported/rmpage	rmpage	<<<<rmpage>>>>	A package to help change page layout parameters in LaTeX.
language/romanian/RomanianTeX	romaniantex	<<<<romaniantex>>>>	LaTeX support for Romanian.
macros/latex/contrib/other/misc	romanneg	<<<<romanneg>>>>	Roman Neg.
macros/latex/contrib/supported/rotating	rotating	<<<<rotating>>>>	No caption.
macros/latex/contrib/supported/rotfloat	rotfloat	<<<<rotfloat>>>>	Rotate floats.
macros/generic/realcalc	realcalc	<<<<realcalc>>>>	Macros for real arithmetic calculations.
macros/latex/contrib/other/recipe	recipe	<<<<recipe>>>>	A LaTeX2e class file to typeset recipes.
macros/latex/contrib/supported/refman	refman	<<<<refman>>>>	Format technical reference manuals.
macros/latex/contrib/supported/relenc	relenc	<<<<relenc>>>>	No caption.
macros/latex/contrib/supported/carlisle	remreset	<<<<remreset>>>>	Remove counters from reset list.
macros/generic/eijkhout	repeat	<<<<repeat>>>>	No caption.
macros/latex/contrib/supported/revnum	revnum	<<<<revnum>>>>	No caption.
macros/latex209/contrib/revtex	revtex	<<<<revtex>>>>	Styles for various Physics Journals.
macros/latex/contrib/other/r_und_s	r-und-s	<<<<r-und-s>>>>	No caption.
macros/generic	ragged	<<<<ragged>>>>	Ragged left and ragged right options.
macros/latex/contrib/supported/ms	ragged2e	<<<<ragged2e>>>>	Defines \Centering, \RaggedLeft, and \RaggedRight, and      corresponding environments.
macros/latex209/contrib/misc	rangecite	<<<<rangecite>>>>	Will turn a range of citations into something like [1..3].
macros/latex/required/tools	rawfonts	<<<<rawfonts>>>>	No caption.
macros/latex/contrib/supported/koi8	rawprint	<<<<rawprint>>>>	Print raw Russian text.
macros/latex/contrib/supported/rcs	rcs	<<<<rcs>>>>	Use RCS (revision control system) tags in LaTeX documents.
macros/latex/contrib/supported/rcsinfo	rcsinfo	<<<<rcsinfo>>>>	Support for the revision control system.
macros/latex/contrib/supported/carlisle	pspicture	<<<<pspicture>>>>	PostScript picture support.
fonts/punk	punk	<<<<punk>>>>	Donald Knuth's punk font.
support/qfig	qfig	<<<<qfig>>>>	No caption.
fonts/psfonts/polish/qfonts	qfonts	<<<<qfonts>>>>	A collection of PostScript (Adobe Type 1) fonts in QX layout.
macros/latex/contrib/other/qobitree	qobitree	<<<<qobitree>>>>	LaTeX macros for typesetting trees.
macros/latex/contrib/supported/qsymbols	qsymbols	<<<<qsymbols>>>>	No caption.
support/psfixbb	psfixbb	<<<<psfixbb>>>>	No caption.
macros/latex/contrib/supported/altfont	psfont	<<<<psfont>>>>	No caption.
fonts/psfonts	psfonts	<<<<psfonts>>>>	PostScript fonts for use with TeX and LaTeX.
macros/latex/contrib/supported/psfrag	psfrag	<<<<psfrag>>>>	No caption.
macros/psizzl	psizzl	<<<<psizzl>>>>	A TeX format from SLAC.
macros/latex/contrib/supported/pslatex	pslatex	<<<<pslatex>>>>	Use PostScript fonts by default.
macros/latex/contrib/supported/psnfssx	psnfssx	<<<<psnfssx>>>>	Extra styles and encodings for PostScript fonts.
macros/latex/contrib/supported/progkeys	progkeys	<<<<progkeys>>>>	No caption.
macros/latex/contrib/supported/program	program	<<<<program>>>>	Typesetting programs and algorithms.
macros/generic/proofs/taylor	proofs	<<<<proofs>>>>	Macros for building proof trees.
support/ps_view	ps_view	<<<<ps_view>>>>	A PostScript previewer of PostScript files.
macros/latex209/contrib/misc	psboxit	<<<<psboxit>>>>	Enables one to put a PostScript drawing behind a TeX box.
systems/os2/pmcstex	pmcstex	<<<<pmcstex>>>>	LaTeX in emTeX IDE/FrontEnd for EPM.
macros/latex/contrib/supported/pmgraph	pmgraph	<<<<pmgraph>>>>	No caption.
macros/generic/TeX-PS/poligraf	poligraf	<<<<poligraf>>>>	A TeX macro package for prepress.
macros/latex/contrib/other/polyglot	polyglot	<<<<polyglot>>>>	A package for LaTeX2e multilingual support.
macros/latex/contrib/supported/prettyref	prettyref	<<<<prettyref>>>>	No caption.
macros/latex/contrib/other/gene/pl	pl	<<<<pl>>>>	Literate Programming for Prolog with LaTeX.
macros/latex/contrib/supported/carlisle	plain	<<<<plain>>>>	Make plain TeX files LaTeXable.
macros/latex/contrib/supported/plari	plari	<<<<plari>>>>	A document class for typesetting stageplay scripts.
macros/plain/contrib/calendar	plcalendar	<<<<plcalendar>>>>	Plain macros for making nice calendars.
macros/phyzzx	phyzzx	<<<<phyzzx>>>>	A TeX format for physicists.
macros/latex209/contrib/picinpar	picinpar	<<<<picinpar>>>>	Insert pictures into paragraphs.
macros/latex209/contrib/picins	picins	<<<<picins>>>>	Insert pictures into paragraphs.
graphics/pictex	pictex	<<<<pictex>>>>	Picture drawing macros for TeX and LaTeX.
macros/latex/contrib/supported/piff	piff	<<<<piff>>>>	Macro tools by Mike Piff.
fonts/okuda/modified	piq	<<<<piq>>>>	No caption.
systems/unix/pkfind	pkfind	<<<<pkfind>>>>	No caption.
macros/plain/contrib/pdcmac	pdcmac	<<<<pdcmac>>>>	Damian Cugley's macro tools.
fonts/archaic/phoenician	phoenician	<<<<phoenician>>>>	Fonts for the semitic script in use from about 1600 BC.
fonts/utilities/pf2afm	pf2afm	<<<<pf2afm>>>>	AFM generator for Adobe Type 1 fonts.
fonts/psfonts/psnfss-source	psnfss-source	<<<<psnfss-source>>>>	Sources (makefiles and fontinst scripts) of the PSNFSS.
fonts/phonetic	phonetic	<<<<phonetic>>>>	MetaFont Phonetic fonts, based on Computer Modern.
biblio/bibtex/contrib	phppcf	<<<<phppcf>>>>	No caption.
macros/physe	physe	<<<<physe>>>>	PHYSE format.
fonts/pandora	pandora	<<<<pandora>>>>	The Pandora font family.
macros/latex/contrib/supported/paper	paper	<<<<paper>>>>	No caption.
macros/latex/contrib/supported/parallel	parallel	<<<<parallel>>>>	No caption.
macros/eplain	path	<<<<path>>>>	A LaTeX package to break long strings at convenient places.
macros/latex/contrib/supported/pb-diagram	pb-diagram	<<<<pb-diagram>>>>	A diagram package using LAMSTeX or Xy-pic fonts.
language/hebrew/fonts/pccode	pcfonts	<<<<pcfonts>>>>	Support for Hebrew.
macros/latex/contrib/supported/overword	overword	<<<<overword>>>>	No caption.
graphics/pagedraw	pagedraw	<<<<pagedraw>>>>	No caption.
macros/latex/contrib/supported/pageno	pageno	<<<<pageno>>>>	No caption.
language/bengali/pandey	pandey	<<<<pandey>>>>	Support for the Bengali language.
macros/latex/contrib/supported/piff	onepagem	<<<<onepagem>>>>	If the document has only one page, omit page number.
macros/latex/contrib/other/misc	optional	<<<<optional>>>>	Facilitate optional printing of parts of a document.
systems/os2/os2tex	os2tex	<<<<os2tex>>>>	A distribution of TeX for OS/2 Warp.
fonts/osmanian	osmanian	<<<<osmanian>>>>	Osmanian fonts by Alan Stanier for writing Somali.
fonts/cyrillic/ot2cyr	ot2cyr	<<<<ot2cyr>>>>	Macros to use the OT2 Cyrillic encoding.
macros/latex/contrib/supported/cite	overcite	<<<<overcite>>>>	Compressed lists of superscript numerical citations.
macros/latex/contrib/other/misc	version	<<<<version>>>>	Conditionally include text.
fonts/utilities/t1utils	t1utils	<<<<t1utils>>>>	Simple type-1 font manipulation programs.
systems/win32/bakoma/contrib	bakoma-games	<<<<bakoma-games>>>>	BaKoMa modules for music and games.
info/finnish/texmalli	texmalli	<<<<texmalli>>>>	A quick Finnish introduction to using LaTeX.
info/TrueType	ttf-tetex	<<<<ttf-tetex>>>>	Using TrueType fonts with teTeX.
macros/plain/contrib/font_selection	font-selection	<<<<font-selection>>>>	Font selection for plain TeX.
dviware/dvipsconfig	dvipsconfig	<<<<dvipsconfig>>>>	Collection of dvips PostScript headers.
macros/latex/contrib/supported/hyperref	hyperref	<<<<hyperref>>>>	Extensive support for hypertext in LaTeX.
macros/latex/contrib/supported/oberdiek	hypbmsec	<<<<hypbmsec>>>>	Hypertext bookmarks in sectioning commands.
macros/latex/contrib/supported/misc	needspace	<<<<needspace>>>>	Insert pagebreak if not enough space.
macros/latex/contrib/other/misc	ftcap	<<<<ftcap>>>>	Allows \caption at the beginning of a table-environment.
macros/latex/contrib/supported/jknappen	jknappen	<<<<jknappen>>>>	Miscellaneous packages by Joerg Knappen.
macros/latex/contrib/other/misc	flashcard	<<<<flashcard>>>>	Typeset flash cards.
macros/latex/contrib/supported/ifacmtg	ifacmtg	<<<<ifacmtg>>>>	Elsevier Science preprint style for IFAC meetings.
macros/latex/contrib/supported/custom-bib	custom-bib	<<<<custom-bib>>>>	Customised BibTeX styles.
macros/latex/contrib/supported/hc	hcbundle	<<<<hcbundle>>>>	Replacement for the LaTeX classes.
macros/latex/contrib/supported/newlfm	newlfm	<<<<newlfm>>>>	Write letters, facsimilies, and memos.
macros/latex/contrib/supported/ccaption	ccaption	<<<<ccaption>>>>	Continuation headings and legends for floats.
macros/latex/contrib/supported/cweb/contrib/cweb-hy	cwebhy	<<<<cweb-hy>>>>	Insert hyperlinks for included files.
info	fepslatex	<<<<fepslatex>>>>	French version of   esplatex .
macros/latex209/contrib/biblist	biblist	<<<<biblist>>>>	BibTeX styles by Joachim Schrod.
macros/latex/contrib/supported/float	float	<<<<float>>>>	Improved interface for floating objects.
macros/latex/contrib/supported/dinbrief	dinbrief	<<<<dinbrief>>>>	German letter DIN style.
macros/latex/contrib/supported/dichokey	dichokey	<<<<dichokey>>>>	Construct dichotomous identification keys.
biblio/bibtex/utils/bibtool	bibtool	<<<<bibtool>>>>	Command line manipulation of BibTeX files.
macros/latex/contrib/supported/ntheorem	ntheorem	<<<<ntheorem>>>>	Enhanced theorem environment.
macros/latex/contrib/other/mhequ	mhequ	<<<<mhequ>>>>	Multicolumn equations, tags, labels, sub-numbering.
support/fancyhdrBoxed	fancyhdrBoxed	<<<<fancyhdrBoxed>>>>	Page headers for the documentation of Software Engineering Projects.
macros/latex/contrib/supported/appendix	appendix	<<<<appendix>>>>	Extra control of appendices.
macros/latex/contrib/supported/misc	ifmtarg	<<<<ifmtarg>>>>	If-then-else command for processing potentially empty arguments.
macros/latex/contrib/supported/misc	nextpage	<<<<nextpage>>>>	Generalisations of the \clear...page and \newpage commands.
macros/latex/contrib/supported/misc	midpage	<<<<midpage>>>>	Environment for vertical centering.
macros/latex/contrib/supported/epigraph	epigraph	<<<<epigraph>>>>	A package for typesetting epigraphs.
systems/mac/cmactex	cmactex	<<<<cmactex>>>>	TeX for the Macintosh.
macros/lamstex/dvipaste	dvipaste	<<<<dvipaste>>>>	DVI manipulation.
support/jpeg2ps/os2	jpeg2ps-os2	<<<<jpeg2ps-os2>>>>	JPEG to PostScript converter for OS/2.
fonts/cm/ai	aifont	<<<<aifont>>>>	BSR/YandY/AMS Type 1 Computer Modern fonts.
language/korean/HLaTeX	hlatex	<<<<hlatex>>>>	Support for the Korean language.
macros/latex/contrib/supported/isostds	isostds	<<<<isostds>>>>	Typeset ISO International Standard documents.
support/impose	impose	<<<<impose>>>>	PostScript utilities.
systems/mac/oztex	macbibtex	<<<<macbibtex>>>>	BibTeX for the Macintosh.
biblio/bibtex/contrib	jqt1999	<<<<jqt1999>>>>	Journal of Quality Technology BibTeX format.
macros/latex/contrib/other/misc	listing	<<<<listing>>>>	Produce formatted program listings.
graphics/circuit_macros	circuit-macros	<<<<circuit-macros>>>>	M4 Macros for Electric circuit diagrams.
systems/os2/emtex-contrib/emtexTDS	emtextds	<<<<emtextds>>>>	TeX for OS/2.
language/devanagari	devanagari	<<<<devanagari>>>>	Typesetting Devanagari.
macros/latex/contrib/supported/crop	crop	<<<<crop>>>>	Support for cropmarks.
language/hyphenation	hypht1	<<<<hypht1>>>>	Additional hyphenation patterns.
language/devanagari/contrib/dn2	dn2	<<<<dn2>>>>	Fixes for devanagari.
language/greek/cb/mf	cbgreek	<<<<cbgreek>>>>	MetaFont source files for a complete set of Greek fonts.
macros/latex/contrib/other/misc	cancel	<<<<cancel>>>>	Place lines through maths formulae.
fonts/ae	ae	<<<<ae>>>>	Virtual fonts for PDF-files with T1 encoded CMR-fonts.
macros/latex/contrib/other/eepic	eepic	<<<<eepic>>>>	Extensions to epic and the LaTeX drawing tools.
graphics/metapost/macros/epsincl	epsincl	<<<<epsincl>>>>	The package facilitates including EPS files in METAPOST         documents; it makes use of (G)AWK.
graphics/metapost/macros/dviincl	dviincl	<<<<dviincl>>>>	A tiny package for including a DVI page into the EPS      files generated by METAPOST.
macros/latex/contrib/supported/frankenstein/unsupported	includex	<<<<includex>>>>	Extended \include.
macros/latex/contrib/supported/multirow	multirow	<<<<multirow>>>>	Creates tabular cells spanning multiple rows.
support/ochem	ochem	<<<<ochem>>>>	Typeset chemical formulae with LaTeX.
macros/latex/contrib/other	nestquot	<<<<nestquot>>>>	Alternate quotes between double and single with nesting.
macros/generic/dratex	dratex	<<<<dratex>>>>	General drawing macros entirely in TeX.
support/lgrind	lgrind	<<<<lgrind>>>>	Produce beautiful listings of source code with LaTeX.
dviware/dvii	dvii	<<<<dvii>>>>	Extract information from a DVI file.
systems/win32/miktex	miktex	<<<<miktex>>>>	A free TeX distribution for MS-Windows32.
macros/latex/contrib/supported/frankenstein	achicago-bst	<<<<achicago-bst>>>>	Chicago Manual BibTeX style.
macros/latex/contrib/other/misc	morefloats	<<<<morefloats>>>>	Increase the number of simultaneous LaTeX floats.
macros/latex/contrib/jeep	jeep	<<<<jeep>>>>	No description available.
macros/latex/contrib/other/misc	braket	<<<<braket>>>>	Dirac bra-ket and set notation.
macros/latex/required/amslatex	amslatex	<<<<amslatex>>>>	Miscellaneous LaTeX enhancements.
macros/generic	backgrnd	<<<<backgrnd>>>>	Mark text with grey background or change bar
support/ltx2x	ltx2x	<<<<ltx2x>>>>	Replace LaTeX commands in a document by user-defined strings.
support/frankenbundle	frankenbundle	<<<<frankenbundle>>>>	Develop and distribute groups of LaTeX packages and classes and      BibTeX bibstyles.
macros/latex/contrib/supported/adfathesis	adfathesis	<<<<adfathesis>>>>	Australian Defence Force Academy thesis format.
macros/latex/contrib/supported/easy	easy	<<<<easy>>>>	A collection of ``easy'' to use macros.
support/latex2rtf	latex2rtf	<<<<latex2rtf>>>>	Convert LaTeX into Rich Text Format.
fonts/utilities/makefonts	makefonts	<<<<makefonts>>>>	Shell scripts to generate pk files.
support/jpeg2ps	jpeg2ps	<<<<jpeg2ps>>>>	Convert JPEG files to PostScript Level 2 or 3 EPS.
macros/latex/contrib/supported/multirow	bigdelim	<<<<bigdelim>>>>	Big deliminators.
macros/latex/contrib/supported/multirow	bigstrut	<<<<bigstrut>>>>	Big struts.
language/hyphenation	frhyph	<<<<frhyph>>>>	French hyphenation patterns.
macros/latex/contrib/other/misc	chappg	<<<<chappg>>>>	Package for page numbering by chapter.
fonts/utilities/accfonts	accfonts	<<<<accfonts>>>>	Font manipulation utilities (mkt1font and vpl2vpl).
biblio/bibtex/utils/btOOl	btool	<<<<btOOL>>>>	Perl library for parsing and processing BibTeX files.
macros/latex/contrib/supported/frankenstein	abbrevs	<<<<abbrevs>>>>	Text abbreviations in LaTeX.
support/abc2mtex	abc2mtex	<<<<abc2mtex>>>>	Notate tunes stored in abc notation.
systems/win32/bakoma/dst	bakoma-malvern	<<<<bakoma-malvern>>>>	TeX for MS-Windows for electronic documents.
macros/latex/contrib/supported/frankenstein	achicago	<<<<achicago>>>>	Chicago Manual citations in LaTeX.
macros/alatex	alatex	<<<<alatex>>>>	Abstract LaTeX.
macros/latex/contrib/supported/frankenstein	attrib	<<<<attrib>>>>	Attribution of block quotations in LaTeX.
support/auctex	auctex	<<<<auctex>>>>	Emacs  support files for TeX.
macros/latex/contrib/supported/frankenstein/unsupported	bits	<<<<bits>>>>	Modular environments in LaTeX.
documentation/blackboard	blackboard	<<<<blackboard>>>>	No caption.
macros/latex/contrib/supported/frankenstein	blkcntrl	<<<<blkcntrl>>>>	Block-element hooks in LaTeX.
macros/latex/contrib/supported/bosisio	bosisio	<<<<bosisio>>>>	No caption.
language/casyl	casyl	<<<<casyl>>>>	Typeset Cree/Inuktitut in Canadian Aboriginal Syllabics.
macros/latex/required/graphics	color	<<<<color>>>>	Allows text and page background colors to be set.
macros/latex/contrib/supported/frankenstein	compsci	<<<<compsci>>>>	Document (LaTeX) programming with LaTeX.
macros/latex/contrib/supported/bosisi	dblfont	<<<<dblfont>>>>	No caption.
macros/latex/contrib/supported/frankenstein	dialogue	<<<<dialogue>>>>	Quote short scripted dialogue in LaTeX.
macros/latex/contrib/supported/frankenstein/unsupported	drama	<<<<drama>>>>	Production-style stage script in LaTeX.
info	epslatex	<<<<epslatex>>>>	guide to using Encapsulated PostScript in LaTeX.
macros/latex/contrib/supported/fancyhdr	fancyhdr	<<<<fancyhdr>>>>	Extensive control of page headers and footers in LaTeX2e.
macros/latex/contrib/supported/fax	fax	<<<<fax>>>>	Document class for preparing faxes.
macros/latex/contrib/supported/feynmf	feynmf	<<<<feynmf>>>>	Macros and fonts for creating Feynman (and other) diagrams.
macros/latex/contrib/supported/fncychap	fncychap	<<<<fncychap>>>>	This package provides six predefined chapter headings.
macros/latex/contrib/supported/fribrief	fribrief	<<<<fribrief>>>>	A LaTeX class for writing letters.
info/greek/gentle	gentl-gr	<<<<gentl-gr>>>>	Modern Greek translation of the Gentle Introduction to TeX.
language/hyphenation	ghyphen	<<<<ghyphen>>>>	No caption.
macros/latex/contrib/supported/bosisio	graphfig	<<<<graphfig>>>>	Simpler graphic, subfigure and float.
macros/latex/required/graphics	graphics	<<<<graphics>>>>	No caption.
macros/latex/required/graphics	graphicx	<<<<graphicx>>>>	Better support for graphics.
macros/latex/contrib/other/karnaugh	karnaugh	<<<<karnaugh>>>>	Typeset Karnaugh-Veitch-maps.
info/latex2e-help-texinfo	latex2e	<<<<latex2e>>>>	Documentation on LaTeX2e in OS/2 hypertext format and html.
macros/latex/contrib/supported/frankenstein	lips	<<<<lips>>>>	Text ellipses in LaTeX.
macros/latex/contrib/supported/frankenstein	moredefs	<<<<moredefs>>>>	LaTeX defining, expansion, and debugging commands.
macros/latex/doc	ltnews	<<<<ltnews>>>>	The latest LaTeX news.
macros/latex/contrib/supported/bosisi	mathcmd	<<<<mathcmd>>>>	No caption.
macros/latex/contrib/supported/bosisio	mathenv	<<<<mathenv>>>>	Defines some often useful math-mode environments.
support/mkpic	mkpic	<<<<mkpic>>>>	Perl interface to mfpic.
macros/latex/contrib/supported/frankenstein/unsupported	newclude	<<<<newclude>>>>	New \include system for LaTeX.
macros/latex/contrib/supported/bezos	dotlessi	<<<<dotlessi>>>>	Provides dotless i's and j's for use in any math font.
macros/latex/contrib/supported/carlisle	dotlessj	<<<<dotlessj>>>>	Generates a dot-less j.
language/tibetan/ctib	ctib4tex	<<<<ctib4tex>>>>	Tibetan for TeX and LATeX2e.
info/german/gleitobjekte	gleitobjekte	<<<<gleitobjekte>>>>	Tutorial from a DANTE meeting in November 1997.
graphics/pictex/mathspic	mathspic	<<<<mathspic>>>>	An MS-DOS filter program for use with PiCTeX.
macros/latex/contrib/other/leftidx	leftidx	<<<<leftidx>>>>	Left subscripts and superscripts in math mode.
language/mongolian/montex	montex	<<<<montex>>>>	Mongolian LaTeX.
macros/latex/contrib/supported/linguex	linguex	<<<<linguex>>>>	Format linguist examples.
biblio/bibtex/utils/bibweb	bibweb	<<<<bibweb>>>>	Automatically retrieve bibliography from MathSciNet.
macros/latex/contrib/supported/expdlist	expdlist	<<<<expdlist>>>>	Expanded description environments.
macros/latex/contrib/supported/chemcono	chemcono	<<<<chemcono>>>>	Support for compound numbers in chemistry documents.
dviware/dviout	dviout	<<<<dviout>>>>	TeX previewer and printer driver for MS-Windows.
macros/latex/contrib/supported/brclc	brclc	<<<<brclc>>>>	Support 16-bit (double) calculations in LaTeX.
support/latexn	latexn	<<<<latexn>>>>	Run LaTeX as many times as needed.
support/latexmk	latexmk	<<<<latexmk>>>>	Fully automated LaTeX document generation routine.
macros/latex/contrib/supported/webeq	exerquiz	<<<<exerquiz>>>>	Environments for defining exercises and quizzes.
fonts/mflogo/ps-type1/hoekwater	hoekwater	<<<<hoekwater>>>>	Converted mflogo font.
language/greek/package-babel/encodings	macgreek	<<<<macgreek>>>>	Greek language support.
fonts/cmolddig	cmolddig	<<<<cmolddig>>>>	Virtual fount setup for using old style digits.
macros/latex/contrib/supported/lettrine	lettrine	<<<<lettrine>>>>	Typeset dropped capitals.
macros/latex/contrib/supported/aguplus	aguplus	<<<<aguplus>>>>	Styles for American Geophysical Union.
systems/mac	ghostview-mac	<<<<ghostview-mac>>>>	No caption.
dviware/dvi2tty	dvi2tty	<<<<dvi2tty>>>>	Produce ACSII from DVI.
fonts/euro/latex/europs	europs	<<<<europs>>>>	Access to Adobe's Euro currency symbol fonts.
macros/latex/contrib/supported/export	export	<<<<export>>>>	Import and export values of LaTeX registers.
macros/latex209/contrib/misc	hangcaption	<<<<hangcaption>>>>	No caption.
macros/latex/contrib/supported/hanging	hanging	<<<<hanging>>>>	Hanging paragraphs.
macros/latex/contrib/supported/harpoon	harpoon	<<<<harpoon>>>>	Extra harpoons, using the graphics package.
biblio/bibtex/contrib	harvard	<<<<harvard>>>>	The Harvard bibliography style family.
macros/plain/contrib/harvmac	harvmac	<<<<harvmac>>>>	Paul Ginsparg's Harvard macros for scientific articles.
language/greek/cb/BibTeX	hellas	<<<<hellas>>>>	Type set bibliographies which include Greek.
macros/latex/contrib/other/grnumalt	grnumalt	<<<<grnumalt>>>>	No caption.
language/greek/grtimes	grtimes	<<<<grtimes>>>>	Typeset Greek text with the Times New Roman Greek.
fonts/utilities/gsftopk	gsftopk	<<<<gsftopk>>>>	No caption.
fonts/hands	hands	<<<<hands>>>>	Pointing hand fonts.
macros/latex/base	graphpap	<<<<graphpap>>>>	For producing graph paper.
fonts/cm/utilityfonts/gray	gray	<<<<gray>>>>	Fonts for gray scales.
fonts/archaic/greek4cbc	greek4cbc	<<<<greek4cbc>>>>	A Greek font from 394BC.
fonts/archaic/greek6cbc	greek6cbc	<<<<greek6cbc>>>>	A Greek font from the sixth century BC.
macros/latex/required/graphics	grfguide	<<<<grfguide>>>>	No caption.
graphics/gnuplot	gnuplot	<<<<gnuplot>>>>	General purpose plotting program.
fonts/go	go	<<<<go>>>>	Fonts and macros for typesetting go games.
fonts/gothic	gothic	<<<<gothic>>>>	Gothic and ornamental initial fonts by Yannis Haralambous.
fonts/doublestroke	doublestroke	<<<<doublestroke>>>>	No caption.
language/hyphenation	gnhyph	<<<<gnhyph>>>>	No caption.
language/german	german	<<<<german>>>>	Support for German typography.
biblio/bibtex/contrib/getrefs	getrefs	<<<<getrefs>>>>	No caption.
support/ghostscript/aladdin	ghostscript	<<<<ghostscript>>>>	Freely available PostScript interpreter.
macros/latex/contrib/other/misc	concrete-wrap	<<<<concrete-wrap>>>>	No caption.
fonts/genealogy	genealogy	<<<<genealogy>>>>	No caption.
info/gentle	gentle	<<<<genlte>>>>	A Gentle Intorudction to TeX.
macros/latex209/contrib/geomsty	geomsty	<<<<geomsty>>>>	No caption.
macros/latex/contrib/supported/fullpict	fullpict	<<<<fullpict>>>>	Full page pictures.
macros/latex/contrib/other/gene/fundus	fundus	<<<<fundus>>>>	Providing LaTeX access to various font families.
web/funnelAC	funnelweb	<<<<funnelweb>>>>	No caption.
fonts/futhark	futhark	<<<<futhark>>>>	Fonts for the Older Futhark script.
macros/latex/contrib/supported/g-brief	g-brief	<<<<g-brief>>>>	A document class for LaTeX2e.
macros/latex/contrib/supported/gb4e	gb4e	<<<<gb4e>>>>	Government Binding styles.
systems/os2/ftetx	ftetx	<<<<ftetx>>>>	No caption.
macros/latex209/contrib/misc	ftn	<<<<ftn>>>>	No caption.
macros/latex/required/tools	ftnright	<<<<ftnright>>>>	Footnotes in two column documents.
macros/latex/contrib/supported/fullblck	fullblck	<<<<fullblck>>>>	No caption.
macros/latex/contrib/other/fp	fp	<<<<fp>>>>	No caption.
systems/win32/fptex	fptex	<<<<fptex>>>>	A   teTeX -1.0 based distribution for      MS-Windows.
fonts/utilities/freetype	freetype	<<<<freetype>>>>	A free, full-featured TrueType rasterizer library.
macros/generic	formlett	<<<<formlett>>>>	Letters to multiple recipients.
macros/latex/contrib/other/formula	formula	<<<<formula>>>>	No caption.
support/4project	fourproject	<<<<fourproject>>>>	Analyse and display the structure of a TeX document.
systems/win32/4tex	fourtex	<<<<fourtex>>>>	A TeX environment for MS-Windows32.
support/4spell	fourspell	<<<<fourspell>>>>	Windows32 spell checker for TeX, RTF, HTML, and BibTeX.
macros/latex/required/tools	fontsmpl	<<<<fontsmpl>>>>	Print a sample of a font.
macros/latex/contrib/supported/footbib	footbib	<<<<footbib>>>>	A package to put bibliographic references as footnotes.
macros/latex/contrib/supported/footnpag	footnpag	<<<<footnpag>>>>	No caption.
macros/latex/contrib/supported/fltpage	fltpage	<<<<fltpage>>>>	No caption.
macros/latex/contrib/other/misc	fnpara	<<<<fnpara>>>>	No caption.
macros/latex/contrib/supported/foilhtml	foilhtml	<<<<foilhtml>>>>	No caption.
macros/latex/contrib/supported/foiltex	foiltex	<<<<foiltex>>>>	A LaTeX2e class for overhead transparencies.
macros/latex/contrib/supported/carlisle	fix2col	<<<<fix2col>>>>	Fix miscellaneous two column mode features.
support/flatex	flatex	<<<<flatex>>>>	No caption.
support/flatten	flatten	<<<<flatten>>>>	No caption.
macros/latex/contrib/other/floatfig	floatfig	<<<<floatfig>>>>	Allows text to be wrapped around figures.
macros/latex/contrib/other/floatflt	floatflt	<<<<floatflt>>>>	Wrap text around floats.
language/hyphenation	fihyph	<<<<fihyph>>>>	Hyphenation patterns for Finnish language.
tools/filehdr	filehdr	<<<<filehdr>>>>	No caption.
biblio/bibtex/contrib	finplain	<<<<finplain>>>>	A Finnish version of `plain.bst'.
macros/latex/contrib/supported/fancyref	fancyref	<<<<fancyref>>>>	A LaTeX package for fancy cross-referencing.
macros/latex/contrib/supported/fancyvrb	fancyvrb	<<<<fancyvrb>>>>	Sophisticated verbatim text.
fonts/jknappen/fc	fc	<<<<fc>>>>	No caption.
systems/mac/support/excalibur	excalibur	<<<<excalibur>>>>	No caption.
macros/latex/exptl/project/expl3	expl3	<<<<expl3>>>>	No caption.
macros/latex/base	exscale	<<<<exscale>>>>	Implements scaling of the `cmex' fonts.
macros/latex/contrib/supported/ncctools	extdash	<<<<extdash>>>>	No caption.
macros/latex/contrib/supported/fancybox	fancybox	<<<<fancybox>>>>	No caption.
macros/latex/contrib/supported/ms	everysel	<<<<everysel>>>>	A LaTeX package which provides hooks into selectfont.
macros/latex/contrib/supported/ms	everyshi	<<<<everyshi>>>>	Introduces a new hook for taking action at every \shipout.
macros/latex/contrib/supported/exam	exam	<<<<exam>>>>	Package for typesetting exam scripts.
macros/latex/contrib/supported/examdesign	examdesign	<<<<examdesign>>>>	Package for typesetting exams.
macros/latex/contrib/supported/exams	exams	<<<<exams>>>>	No caption.
macros/latex/contrib/supported/euler	euler	<<<<euler>>>>	No caption.
macros/latex/contrib/supported/euro	euro	<<<<euro>>>>	Arbitrary national currency amounts using the Euro as base      unit.
macros/latex/contrib/supported/eurofont	eurofont	<<<<eurofont>>>>	Provides a command that prints a euro symbol.
fonts/eurosym	eurosym	<<<<eurosym>>>>	No caption.
macros/latex/contrib/supported/ESIEEcv	esieecv	<<<<esieecv>>>>	Curriculum vit for French.
macros/latex/contrib/supported/bezos	esindex	<<<<esindex>>>>	Typset index entries in Spanish documents.
macros/latex/contrib/supported/ms/contrib	eso-pic	<<<<eso-pic>>>>	A package to add picture commands (or backgrounds) to every page.
support/et	et	<<<<et>>>>	No caption.
language/ethiopia/ethiop	ethiop	<<<<ethiop>>>>	No caption.
fonts/archaic/etruscan	etruscan	<<<<etruscan>>>>	Fonts for the Etruscan script.
macros/latex/required/graphics	epsfig	<<<<epsfig>>>>	Include Encapsulated PostScript in LaTeX documents.
macros/generic/TeX-PS	epsfx	<<<<epsfx>>>>	A TeX macro package for including EPS graphics (a replacement of epsf.tex/sty).
macros/latex/contrib/other/gene/eqname	eqname	<<<<eqname>>>>	Style for different equation numbering.
macros/latex/contrib/other/epic	epic	<<<<epic>>>>	A package enhancing LaTeX's picture mode.
macros/latex/contrib/supported/eqnarray	eqnarray	<<<<eqnarray>>>>	More generalised equation arrays with numbering.
macros/latex/required/tools	enumerate	<<<<enumerate>>>>	No caption.
macros/latex/contrib/other/envbig	envbig	<<<<envbig>>>>	Printing addresses on envelopes.
macros/eplain	eplain	<<<<eplain>>>>	No caption.
systems/msdos/emtex-contrib/emtexgi	emtexgi	<<<<emtexgi>>>>	A MS-Windows interface to   emTeX .
macros/latex/contrib/supported/emulateapj	emulateapj	<<<<emulateapj>>>>	No caption.
macros/latex/contrib/supported/endfloat	endfloat	<<<<endfloat>>>>	Move floats to the end with markers where they belong.
macros/latex/contrib/other/misc	endnotes	<<<<endnotes>>>>	No caption.
fonts/engwar	engwar	<<<<engwar>>>>	Font for typesetting Tolkien Engwar script.
macros/generic/eijkhout	eijkhout	<<<<eijkhout>>>>	No caption.
macros/latex/contrib/supported/elsevier	elsevier	<<<<elsevier>>>>	Preprint style for Elsevier Science journals.
fonts/elvish	elvish	<<<<elvish>>>>	Font for typesetting Tolkien Elvish script.
macros/latex/contrib/supported/emp	emp	<<<<emp>>>>	No caption.
systems/os2/emtex	emtex-os2	<<<<emtex-os2>>>>	A TeX system for os2.
systems/msdos/emtex	emtex	<<<<emtex>>>>	A TeX system for MS-DOS.
fonts/eco	eco	<<<<eco>>>>	Font metric files and virtual fonts for   ec  fonts.
macros/plain/contrib/edmac	edmac	<<<<edmac>>>>	Typeset scholarly edition.
macros/latex/contrib/supported/egplot	egplot	<<<<egplot>>>>	No caption.
fonts/eiad	eiad	<<<<eiad>>>>	Macros and EIAD fonts.
macros/latex/contrib/supported/easy	easytable	<<<<easytable>>>>	A simple package for writing tables.
macros/latex/contrib/supported/easy	easyvector	<<<<easyvector>>>>	Write vectors in a C-like fashion.
macros/ec-plain	ec-plain	<<<<ec-plain>>>>	No caption.
fonts/jknappen/ec	ec	<<<<ec>>>>	No caption.
fonts/ecc	ecc	<<<<ecc>>>>	Sources for the European Concrete fonts.
macros/generic/ean	ean	<<<<ean>>>>	Font for making EAN barcodes.
macros/latex/contrib/supported/easy	easybib	<<<<easybib>>>>	Simple syntax for custom bibliographies.
macros/latex/contrib/supported/easy	easybmat	<<<<easybmat>>>>	Block matricies.
macros/latex/contrib/supported/easy	easyeqn	<<<<easyeqn>>>>	A simple package for writing equations.
macros/latex/contrib/supported/easy	easymat	<<<<easymat>>>>	A simple package for writing matrices.
dviware/dvipdfm	dvipdfm	<<<<dvipdfm>>>>	A dvi driver to produce PDF directly.
systems/os2/dviware/dvips	dvips-os2	<<<<dvips-os2>>>>	No caption.
systems/win32/util	dvips-shell	<<<<dvips-shell>>>>	A   dvips  Shell for MS-Windows32.
dviware/dvipsk	dvipsk	<<<<dvipsk>>>>	No caption.
dviware/dviwin	dviwin	<<<<dviwin>>>>	MS-Windows DVI screen and printer driver.
dviware/dvibook/Dviconcat	dviconcat	<<<<dviconcat>>>>	Concatenates dvi files.
dviware/dvicopy	dvicopy	<<<<dvicopy>>>>	Copy and concatenate DVI files.
dviware/dviljk	dviljk	<<<<dviljk>>>>	No caption.
macros/latex/contrib/supported/cite	drftcite	<<<<drftcite>>>>	Print the tags instead of the numbers for \cite and \bibitem.
macros/latex209/contrib/dropcaps	dropcaps	<<<<dropcaps>>>>	Use dropped capitals to start a paragraph.
macros/latex/contrib/other/dropping	dropping	<<<<dropping>>>>	Drop first letter of paragraphs.
fonts/duerer	duerer	<<<<duerer>>>>	Computer Duerer fonts.
dviware/dvgtk	dvgtk	<<<<dvgtk>>>>	No caption.
macros/latex/contrib/other/dotseqn	dotseqn	<<<<dotseqn>>>>	Flush left equations with dotted letters to the numbers.
obsolete/macros/latex209/contrib/misc	doublespace	<<<<doublespace>>>>	No caption.
macros/latex/contrib/supported/draftcopy	draftcopy	<<<<draftcopy>>>>	Identify draft copies.
macros/latex209/contrib/misc	drafthead	<<<<drafthead>>>>	No caption.
biblio/bibtex/contrib/directory	directory	<<<<directory>>>>	Address book.
macros/latex/base	doc	<<<<doc>>>>	Format LaTeX documentation.
macros/latex/base	docstrip	<<<<docstrip>>>>	Remove comments from file.
macros/latex/contrib/supported/deleq	deleq	<<<<deleq>>>>	Flexible numbering of equations.
macros/latex/exptl/delimtxt	delimtxt	<<<<delimtxt>>>>	Read and parse text tables.
macros/latex/contrib/supported/dialogl	dialogl	<<<<dialogl>>>>	Macros for constructing interactive LaTeX scripts.
macros/generic/eijkhout	dbprocess	<<<<dbprocess>>>>	No caption.
macros/latex/required/tools	dcolumn	<<<<dcolumn>>>>	Align on the decimal point of numbers in tabulars.
macros/latex/contrib/supported/ncctools	dcounter	<<<<dcounter>>>>	Supports dynamic counters.
macros/generic	default	<<<<default>>>>	A style to help provide default parameters for TeX macros.
macros/latex/required/tools	delarray	<<<<delarray>>>>	Delimiters for arrays.
fonts/archaic/cypriot	cypriot	<<<<cypriot>>>>	A script which was used on Cyprus for writing Greek.
systems/msdos/emtex-contrib/cyrtug	cyrtug	<<<<cyrtug>>>>	No caption.
macros/latex/required/babel	czech	<<<<czech>>>>	Typeset Czech documents.
fonts/dancers	dancers	<<<<dancers>>>>	Font for the Sherlock Holmes `Dancing Men'.
systems/unix/dante-src	dante-src	<<<<dante-src>>>>	No caption.
macros/latex/contrib/supported/dates	dates	<<<<dates>>>>	Macros for parsing date strings.
macros/latex/contrib/supported/cursor	cursor	<<<<cursor>>>>	No caption.
web/c_cpp/cwebx	cwebx	<<<<cwebx>>>>	A system for Structured Software Documentation in C.
macros/latex/contrib/other/gene/crossword	cwpuzzle	<<<<cwpuzzle>>>>	Typeset crossword puzzles.
fonts/csx	csx	<<<<csx>>>>	Documentation for the CS/CSX documents on MS-DOS.
macros/latex/contrib/supported/ms	count1to	<<<<count1to>>>>	Set count1 to count9.
macros/latex/contrib/supported/covington	covington	<<<<covington>>>>	Linguistic support.
language/croatian	croatian	<<<<croatian>>>>	Fonts for typesetting Croatian scripts.
macros/latex/contrib/other/crosswrd	crosswrd	<<<<crosswrd>>>>	Macros for typesetting crossword puzzles..
fonts/concrete	concrete	<<<<concrete>>>>	Concrete Roman fonts.
support/consdiag	consdiag	<<<<consdiag>>>>	A utility for OO programming documentation.
fonts/psfonts/corelpak/contrib	corelpak	<<<<corelpak>>>>	No caption.
macros/latex/contrib/supported/carlisle	colortbl	<<<<colortbl>>>>	Add colour to LaTeX tables.
macros/latex/contrib/supported/carlisle	comma	<<<<comma>>>>	Formats a number by inserting a comma.
macros/latex/contrib/other/concmath	concmath	<<<<concmath>>>>	Concrete Math fonts.
macros/latex/contrib/supported/concprog	concprog	<<<<concprog>>>>	No caption.
macros/latex/contrib/supported/codepage	codepage	<<<<codepage>>>>	Support for variant code pages.
macros/generic/code128	code128	<<<<code128>>>>	A set of barcode macros for the Code 128 standard.
macros/latex/contrib/other/misc	boxedminipage	<<<<boxedminipage>>>>	A package for producing boxed minipages.
macros/generic/colortab	colortab	<<<<colortab>>>>	Shade cells of tables and halign.
macros/latex/base	cmextra	<<<<cmextra>>>>	No caption.
fonts/cmpica	cmpica	<<<<cmpica>>>>	A Computer Modern Pica variant.
fonts/cm/ps-type1/bluesky	cmps	<<<<cmps>>>>	versions of PostScript fonts, from Blue Sky and Y&amp;Y.
macros/latex/contrib/supported/cmsd	cmsd	<<<<cmsd>>>>	A package including additional fd files.
macros/latex/contrib/supported/mdwtools	cmtt	<<<<cmtt>>>>	A package for handling the `cmtt' font better.
fonts/CJK	cjk-fonts	<<<<cjk-fonts>>>>	No caption.
fonts/cm	cm	<<<<cm>>>>	Computer Modern fonts.
fonts/cyrillic/cmcyr	cmcyr	<<<<cmcyr>>>>	No caption.
fonts/cyrillic/cmcyralt	cmcyralt	<<<<cmcyralt>>>>	Alternative Russian encoding support.
macros/generic/diagrams/circ	circ	<<<<circ>>>>	Macros for typesetting circuit diagrams.
macros/latex/contrib/other/misc	circle	<<<<circle>>>>	No caption.
fonts/cirth	cirth	<<<<cirth>>>>	Fonts for Cirth.
macros/latex/contrib/supported/cite	cite	<<<<cite>>>>	Supports compressed, sorted lists of numerical citations.
macros/latex/contrib/supported/chemsym	chemsym	<<<<chemsym>>>>	Macros for typing chemical symbols.
fonts/cheq	cheq	<<<<cheq>>>>	Adobe chess font.
fonts/cherokee	cherokee	<<<<cherokee>>>>	Fonts for Cherokee scripts.
fonts/chess	chess	<<<<chess>>>>	Fonts for typesetting chess boards.
biblio/bibtex/contrib	chicago	<<<<chicago>>>>	A bibliography style.
macros/latex/contrib/supported/china2e	china2e	<<<<china2e>>>>	No caption.
macros/latex/contrib/other/cd-cover	cdcover	<<<<cdcover>>>>	Typeset CD covers.
macros/generic/eijkhout	cdlabeler	<<<<cdlabeler>>>>	Take user text and typeset it to fit a CD label.
macros/plain/contrib/cellular	cellular	<<<<cellular>>>>	Cellular table construction.
support/pstools/cep	cep	<<<<cep>>>>	Compression tools for PostScript.
macros/latex/contrib/supported/changebar	changebar	<<<<changebar>>>>	Generate changebars in LaTeX documents.
macros/latex/contrib/supported/cite	chapterbib	<<<<chapterbib>>>>	Separate bibliography for each \include file.
support/catdoc	catdoc	<<<<catdoc>>>>	No caption.
language/polish	cc-pl	<<<<cc-pl>>>>	Polish extension of Computer Concrete fonts (MetaFont sources).
macros/latex/contrib/supported/caption	caption	<<<<caption>>>>	No caption.
macros/latex/contrib/supported/caption	caption2	<<<<caption2>>>>	Newer version of the caption package.
macros/latex/contrib/supported/carlisle	carlisle	<<<<carlisle>>>>	Miscellaneous small packages by David Carlisle.
macros/latex/required/tools	calc	<<<<calc>>>>	No caption.
macros/latex/contrib/supported/calendar	calendar	<<<<calendar>>>>	A package for calendars and timetables.
fonts/calligra	calligra	<<<<calligra>>>>	Calligraphic font.
macros/latex/contrib/other/calrsfs	calrsfs	<<<<calrsfs>>>>	Nicer calligraphic letters.
macros/latex/contrib/supported/camel	camel	<<<<camel>>>>	No caption.
macros/latex/contrib/other/misc	capt-of	<<<<capt-of>>>>	Captions on more than floats.
macros/latex209/contrib/misc/bridge	bridge	<<<<bridge>>>>	Macros for typesetting bridge diagrams.
fonts/brushscr	brushscr	<<<<brushscr>>>>	No caption.
macros/generic/c_pascal	c-pascal	<<<<c-pascal>>>>	Typeset C and Pascal programs.
web/c_cpp/c2cweb	c2cweb	<<<<c2cweb>>>>	No caption.
biblio/bibtex/contrib/bids	bidstobibtex	<<<<bidstobibtex>>>>	No caption.
macros/latex/contrib/supported/braille	braille	<<<<braille>>>>	Support for braille.
macros/blu	blu	<<<<blu>>>>	BLUe's format system.
macros/blu	blue	<<<<blue>>>>	No caption.
fonts/cm/ps-type1/bluesky	bluesky	<<<<bluesky>>>>	Computer Modern family in  format.
macros/latex/required/tools	bm	<<<<bm>>>>	This is a package for accessing bold symbols in math mode.
macros/generic/diagrams/borceux	borceux	<<<<borceux>>>>	Diagram macros by Francois Borceux.
fonts/cm/ps-type1/bakoma	bakoma-fonts	<<<<bakoma-fonts>>>>	Computer Modern and AMS fonts in PostScript Type1 form.
fonts/psfonts/bitstrea	bitstrea	<<<<bitstrea>>>>	No caption.
macros/latex/contrib/supported/carlisle	blkarray	<<<<blkarray>>>>	Extended array and tabular.
macros/latex/contrib/other/misc	block	<<<<block>>>>	A block letter style for the letter class.
info/biblio	biblio	<<<<biblio>>>>	No caption.
systems/msdos	biblios	<<<<biblios>>>>	No caption.
macros/latex/contrib/supported/beton	beton	<<<<beton>>>>	No caption.
macros/latex/contrib/supported/bez123	bez123	<<<<bez123>>>>	Support for Bezier curves.
macros/latex/contrib/supported/bezos	bezos	<<<<bezos>>>>	Packages by Javier Bezos.
macros/latex/contrib/supported/bibarts	bibarts	<<<<bibarts>>>>	No caption.
support/bibdb	bibdb	<<<<bibdb>>>>	BibTeX bibliography manager fow MS-Windows and MS-DOS.
macros/plain/base	base	<<<<base>>>>	Definitive source of Plain TeX on CTAN.
fonts/bbding	bbding	<<<<bbding>>>>	Symbol font including many Zapf dingbats.
fonts/cm/bbm	bbm	<<<<bbm>>>>	No caption.
macros/latex/other/misc	beletter	<<<<beletter>>>>	Typeset Belgian letters.
macros/latex/contrib/other/bg	backgammon	<<<<backgammon>>>>	Style for typesetting backgammon boards.
macros/latex209/contrib/misc	bar	<<<<bar>>>>	Provides the barenv environment for bar charts.
fonts/psfonts/marvosym/mac	marvosym-mac	<<<<marvosym-mac>>>>	No caption.
fonts/barcodes	barcodes	<<<<barcodes>>>>	Fonts for making barcodes.
macros/generic/diagrams/barr	barr	<<<<barr>>>>	Diagram macros by Michael Barr.
fonts/bookhands/auncial	auncial	<<<<auncial>>>>	Artificial Uncial manuscript book-hand font.
indexing/authorindex	authorindex	<<<<authorindex>>>>	No caption.
macros/latex209/contrib/autotab	autotab	<<<<autotab>>>>	Generating tabular setups.
macros/latex/required/babel	babel	<<<<babel>>>>	Multilingual support for LaTeX.
macros/latex/contrib/other/asaetr	asaetr	<<<<asaetr>>>>	Transactions of the American Society of Agricultural Engineers.
fonts/ascii	ascii	<<<<ascii>>>>	Support for IBM extended ASCII font.
fonts/astro	astro	<<<<astro>>>>	Astronomical (planetary) symbols.
macros/latex/contrib/supported/mdwtools	at	<<<<at>>>>	No caption.
language/armenian	armtex	<<<<armtex>>>>	A sytem for writing Armenian with TeX and LaTeX.
language/bengali/arosgn	arosgn	<<<<arosgn>>>>	Support for the Bengali language.
macros/latex/required/tools	array	<<<<array>>>>	Arrays and tables with formatted columns.
macros/eplain	arrow	<<<<arrow>>>>	Eplain macros for arrow theoretic diagrams.
macros/latex/contrib/other/apa	apa	<<<<apa>>>>	American Psychological Association format.
biblio/bibtex/contrib	apasoft	<<<<apasoft>>>>	A more conforming apa-like style for BibTeX.
fonts/apl	apl	<<<<apl>>>>	Fonts for typesetting APL programs.
macros/latex/contrib/other/ar	ar	<<<<ar>>>>	Capital A and capital R ligature for Apsect Ratio.
language/arabtex	arabtex	<<<<arabtex>>>>	Macros and fonts for typesetting Arabic.
fonts/amsfonts/doc/latex	amssymb	<<<<amssymb>>>>	AMS symbol fonts for LaTeX.
macros/amstex	amstex	<<<<amstex>>>>	American Mathematical Society plain TeX macros.
macros/latex/required/amslatex/math	amstext	<<<<amstext>>>>	AMS-LaTeX -- text fragments in math.
macros/latex/contrib/supported/answers	answers	<<<<answers>>>>	Styles for setting questions (or exercises) and answers.
fonts/psfonts/anttvf	anttvf	<<<<anttvf>>>>	Virtual fonts for PostScript Antykwa Torunska font.
fonts/psfonts/polish/antyktor	antyktor	<<<<antyktor>>>>	Antykwa Toru\'nska: a Type 1 family of a Polish traditional type.
fonts/amsfonts	amsfonts	<<<<amsfonts>>>>	TeX fonts from the American Mathematical Society.
macros/latex209/contrib/amslatex	amsltx11	<<<<amsltx11>>>>	AMS-LaTeX, original version (obsolete).
macros/amstex	amsppt	<<<<amsppt>>>>	AMS-TeX article preprint document style.
macros/amstex	amsppt1	<<<<amsppt1>>>>	AMS-TeX v.2 compatibility for amsppt.sty v.1.
fonts/amsfonts/plaintex	amssym	<<<<amssym>>>>	AMS symbol fonts for Plain TeX.
macros/latex/contrib/supported/oberdiek	alphalph	<<<<alphalph>>>>	Convert numbers to letters.
macros/latex/contrib/supported/jura	alphanum	<<<<alphanum>>>>	Permits alphanumeric section numbering.
macros/latex/contrib/supported/altfont	altfont	<<<<altfont>>>>	No caption.
systems/amiga/amiweb2c	amiweb2c	<<<<amiweb2c>>>>	An Amiga port of the complete UNIX-TeX system.
macros/latex/required/amslatex/math	amsbsy	<<<<amsbsy>>>>	Produce bold math symbols (AMS-LaTeX).
macros/latex/required/amslatex/math	amscd	<<<<amscd>>>>	AMS-LaTeX -- commutative diagrams.
macros/latex/contrib/other/alg	alg	<<<<alg>>>>	LaTeX environments for typesetting algorithms.
macros/latex/contrib/supported/algorithms	algorithmic	<<<<algorithmic>>>>	Provides an environment for describing algorithms.
macros/latex/contrib/supported/algorithms	algorithms	<<<<algorithms>>>>	No caption.
macros/latex/base	alltt	<<<<alltt>>>>	No caption.
macros/latex/contrib/other/adrlist	adrlist	<<<<adrlist>>>>	Using address lists in LaTeX.
macros/latex/contrib/other/misc	advdate	<<<<advdate>>>>	No caption.
macros/latex/required/tools	afterpage	<<<<afterpage>>>>	Execute command after each page.
macros/latex/contrib/supported/afthesis	afthesis	<<<<afthesis>>>>	Air Force Institute of Technology thesis class.
macros/latex/contrib/supported/aiaa	aiaa	<<<<aiaa>>>>	American Institute of Aeronautics and Astronautics.
fonts/postscript/adobe	adobe	<<<<adobe>>>>	Font metrics and macro support for many Adobe fonts.
macros/latex/contrib/supported/bezos	accents	<<<<accents>>>>	Multiple accents.
macros/latex/contrib/supported/achemso	achemso	<<<<achemso>>>>	LaTeX and BibTeX style for American Chemical Society.
macros/latex209/contrib/aaai	aaai	<<<<aaai>>>>	AAAI style.
macros/latex/contrib/other/misc	abstbook	<<<<abstbook>>>>	Books of abstracts.
macros/latex/contrib/supported/a0poster	a0poster	<<<<a0poster>>>>	Provides fonts in sizes of 12pt up to 107pt.
fonts/utilities/a2ac	a2ac	<<<<a2ac>>>>	AFM to AFM plus Composites.
macros/latex/contrib/supported/ntgclass	a4	<<<<a4>>>>	Support for A4 paper sizes.
macros/latex/contrib/other/misc	a4wide	<<<<a4wide>>>>	Increases width of printed area of an a4 page.
obsolete/macros/latex209/contrib/misc	a5	<<<<a5>>>>	Obsolete support for a5 paper size.
macros/latex/contrib/other/misc	a5comb	<<<<a5comb>>>>	Support for a5 paper sizes.
support/lilypond	lilypond	<<<<lilypond>>>>	Support for music notation.
macros/latex/contrib/other/moresize	moresize	<<<<moresize>>>>	Allows font sizes up to 35.83pt.
fonts/archaic/linearb	linearb	<<<<linearb>>>>	Linear B script used in the Bronze Age for Mycenaean Greek.
macros/latex	latex	<<<<latex>>>>	Macro package for TeX (the most popular).
language/malayalam	malayalam	<<<<malayalam>>>>	Fonts for typesetting Malayalam, with a pre-processor.
language/polish	mex	<<<<mex>>>>	A Polish format for TeX.
macros/latex/contrib/supported/morehelp	morehelp	<<<<morehelp>>>>	No caption.
macros/latex/contrib/supported/carlisle	ltxtable	<<<<ltxtable>>>>	Longtable and tabularx merge.
graphics/MF-PS	mf-ps	<<<<mf-ps>>>>	A MetaFont-PostScript link.
macros/generic/insbox	insbox	<<<<insbox>>>>	A TeX macro for inserting pictures/boxes into paragraphs.
fonts/oca	oca	<<<<oca>>>>	OCR font.
fonts/ocr-a	ocr-a	<<<<ocr-a>>>>	Fonts for OCR-A.
fonts/ocr-b	ocr-b	<<<<ocr-b>>>>	Fonts for OCR-B.
fonts/ogham	ogham	<<<<ogham>>>>	Fonts for typesetting Ogham script.
macros/latex/contrib/other/ogonek	ogonek	<<<<ogonek>>>>	Support for Polish typography and the ogonek.
macros/latex/contrib/other/oldstyle	oldstyle	<<<<oldstyle>>>>	No caption.
systems/omega	omega	<<<<omega>>>>	Omega.
biblio/bibtex/contrib/norbib	norbib	<<<<norbib>>>>	No caption.
macros/latex/contrib/supported/nrc	nrc	<<<<nrc>>>>	Format of the NRC Canadian Journal of Physics.
macros/latex/contrib/supported/ntgclass	ntgclass	<<<<ntgclass>>>>	No caption.
macros/latex/contrib/supported/numline	numline	<<<<numline>>>>	Macros for numbering lines.
macros/latex/contrib/supported/objectz	objectz	<<<<objectz>>>>	Macros for typesetting Object Z.
macros/latex/contrib/supported/newalg	newalg	<<<<newalg>>>>	Format algorithms like Cormen, Leiserson and Rivest.
macros/plain/contrib/newsletr	newsletr	<<<<newsletr>>>>	Macros for making newsletters.
macros/latex/contrib/other/newthm	newthm	<<<<newthm>>>>	No caption.
macros/latex/contrib/supported/niceframe	niceframe	<<<<niceframe>>>>	Support for fancy framing of pages.
macros/latex/contrib/supported/carlisle	nopageno	<<<<nopageno>>>>	No page numbers in LaTeX documents.
macros/musixtex	musixtex	<<<<musixtex>>>>	Extended MusicTeX, with better slurs.
fonts/georgian/mxedruli	mxedruli	<<<<mxedruli>>>>	No caption.
macros/latex/contrib/supported/carlisle	mylatex	<<<<mylatex>>>>	MyLaTeX.
macros/latex/contrib/supported/akletter/myletter	myletter	<<<<myletter>>>>	Another letter package.
macros/latex/contrib/supported/nassflow	nassflow	<<<<nassflow>>>>	Drawing Nassi-Schneidermann diagrams.
macros/latex/contrib/supported/ncctools	nccfoots	<<<<nccfoots>>>>	No caption.
macros/latex/contrib/supported/mslapa	mslapa	<<<<mslapa>>>>	No caption.
fonts/mt11p	mt11p	<<<<mt11p>>>>	No caption.
macros/plain/contrib/mtbe	mtbe	<<<<mtbe>>>>	Examples from Mathematical TeX by Example by Arvind Borde.
macros/latex/contrib/supported/multenum	multenum	<<<<multenum>>>>	Multi-column enumerated lists.
macros/latex/required/tools	multicol	<<<<multicol>>>>	Intermix single and multiple columns.
macros/generic/multido	multido	<<<<multido>>>>	A loop facility for Generic TeX.
macros/latex/contrib/supported/ms	multitoc	<<<<multitoc>>>>	Set table of contents in multiple columns.
macros/musictex	musictex	<<<<musictex>>>>	Typesetting music with TeX.
fonts/morse	morse	<<<<morse>>>>	A package for printing Morse code signs.
graphics/metapost/macros/mpattern	mpattern	<<<<mpattern>>>>	Patterns in MetaPost.
macros/latex/contrib/other/mpfnmark	mpfnmark	<<<<mpfnmark>>>>	No caption.
macros/latex/contrib/supported/ms/contrib	ms	<<<<ms>>>>	Various LaTeX packages by Martin Schr\"oder.
macros/generic/TeX-PS	mirr	<<<<mirr>>>>	PostScript mirror header (for dvips).
macros/latex209/contrib/misc	mitpress	<<<<mitpress>>>>	Support for MIT Press.
biblio/bibtex/contrib/mla	mla	<<<<mla>>>>	No caption.
macros/latex/contrib/supported/mlbib	mlbib	<<<<mlbib>>>>	Support for multilingual bibliographies.
macros/latex/contrib/supported/mltex	mltex	<<<<mltex>>>>	No caption.
fonts/utilities/mmtools	mmtools	<<<<mmtools>>>>	Multiple master fonts tools.
nonfree/macros/latex/contrib/supported/mnras	mnras	<<<<mnras>>>>	Monthly Notices of the Royal Astronomical Society.
fonts/modes	modes	<<<<modes>>>>	A collection of MetaFont mode_def's.
fonts/psfonts/monotype	monotype	<<<<monotype>>>>	No caption.
macros/latex/contrib/supported/mfnfss	mfnfss	<<<<mfnfss>>>>	No caption.
graphics/mfpic	mfpic	<<<<mfpic>>>>	Macros which generate Metafont or Metapost for drawing pictures.
macros/generic/midnight	midnight	<<<<midnight>>>>	A set of useful macro tools.
systems/win32/miktex-AXP	miktex-axp	<<<<miktex-axp>>>>	A port of MiKTeX to MS-Windows-NT on the Alpha.
macros/plain/graphics	miniltx	<<<<miniltx>>>>	No caption.
macros/latex/contrib/supported/method	method	<<<<method>>>>	Typeset method and variable declarations.
fonts/utilities/mf2pt3	mf2pt3	<<<<mf2pt3>>>>	No caption.
graphics/mf2tex	mf2tex	<<<<mf2tex>>>>	No caption.
macros/latex/contrib/supported/mff	mff	<<<<mff>>>>	No caption.
fonts/psnfss	mathpple	<<<<mathpple>>>>	Use PostScript Palatino for typesetting maths.
macros/latex/required/psnfss	mathptm	<<<<mathptm>>>>	No caption.
macros/latex/contrib/supported/jknappen	mathrsfs	<<<<mathrsfs>>>>	No caption.
support/mathspad	mathspad	<<<<mathspad>>>>	No caption.
fonts/metrics/adobe/mathtime	mathtime	<<<<mathtime>>>>	No caption.
macros/latex/contrib/supported/mcite	mcite	<<<<mcite>>>>	No caption.
macros/latex/contrib/supported/mdwtools	mdwtools	<<<<mdwtools>>>>	Miscellaneous tools by Mark Wooding.
support/emacs-modes	meta-mode	<<<<meta-mode>>>>	No caption.
macros/latex/contrib/supported/margbib	margbib	<<<<margbib>>>>	A package for displaying bibliography tags in the margins.
macros/generic	letterspacing	<<<<letterspacing>>>>	Letter spacing.
fonts/psfonts/marvosym	marvosym	<<<<marvosym>>>>	A Type 1 font: Martin Vogels Symbole (marvosym) font.
macros/latex/contrib/supported/mathcomp	mathcomp	<<<<mathcomp>>>>	No caption.
fonts/psfonts/Mathematica3.0	mathematica	<<<<mathematica>>>>	No caption.
fonts/utilities/mathinst	mathinst	<<<<mathinst>>>>	No caption.
fonts/utilities/mathkit	mathkit	<<<<mathkit>>>>	No caption.
macros/latex/contrib/other/misc	magaz	<<<<magaz>>>>	Magazine layout.
macros/latex/contrib/supported/mailing	mailing	<<<<mailing>>>>	Macros for mail merging.
indexing/makeindex	makeindex	<<<<makeindex>>>>	No caption.
fonts/malvern	malvern	<<<<malvern>>>>	A new sans-serif font family.
macros/latex/contrib/supported/ncctools	manyfoot	<<<<manyfoot>>>>	No caption.
macros/latex/contrib/supported/mapcodes	mapcodes	<<<<mapcodes>>>>	Support for multiple character sets and encodings.
macros/latex/contrib/supported/maple	maple	<<<<maple>>>>	Styles and examples for the MAPLE newsletter.
support/ltxinput	ltxinput	<<<<ltxinput>>>>	No caption.
macros/latex/contrib/other/misc	ltxmisc	<<<<ltxmisc>>>>	Miscellaneous LaTeX styles.
macros/latex/base	ltxsrc	<<<<ltxsrc>>>>	The core source files for LaTeX2e.
fonts/lucida	lucida	<<<<lucida>>>>	Package to make Lucida Bright fonts usable with LaTeX.
macros/latex/contrib/supported/lucold	lucold	<<<<lucold>>>>	Use old-style digits with Lucida fonts.
fonts/psfonts	lw35nfsx	<<<<lw35nfsx>>>>	No caption.
macros/latex/contrib/supported/psnfssx/ly1	ly1	<<<<ly1>>>>	Support for LY1 LaTeX encoding, i.e.
macros/latex/contrib/supported/ltablex	ltablex	<<<<ltablex>>>>	No caption.
support/ltoh	ltoh	<<<<ltoh>>>>	A converter from LaTeX to HTML.
support/ltx2rtf	ltx2rtf	<<<<ltx2rtf>>>>	A conversion program from LaTeX to Rich Text Format.
macros/latex/base	ltxbase	<<<<ltxbase>>>>	The core LaTeX.
macros/latex209/contrib/springer/llncs	llncs	<<<<llncs>>>>	No caption.
macros/latex/contrib/supported/localloc	localloc	<<<<localloc>>>>	Macros for localizing TeX register allocations.
fonts/cm/utilityfonts/logo/ps-type1/hoekwater	logo-ps	<<<<logo-ps>>>>	PostScript fonts for the logo font.
macros/lollipop	lollipop	<<<<lollipop>>>>	A new generation format.
macros/latex/required/tools	longtable	<<<<longtable>>>>	Support for tables longer than a page.
macros/latex209/contrib/misc	losymbol	<<<<losymbol>>>>	Defines a lot of symbol macros.
macros/latex/required/graphics	lscape	<<<<lscape>>>>	Place selected parts of a document in landscape.
macros/latex/contrib/supported/lhcyr	lhcyr	<<<<lhcyr>>>>	No caption.
support/lintex	lintex	<<<<lintex>>>>	No caption.
macros/latex/required/tools	layout	<<<<layout>>>>	Produces an overview of the layout of the current document.
macros/latex/contrib/supported/layouts	layouts	<<<<layouts>>>>	Display various elements of a document's layout.
macros/latex/contrib/supported/leaflet	leaflet	<<<<leaflet>>>>	Creat small, single page handouts.
macros/latex/base	letter	<<<<letter>>>>	The standard LaTeX2e letter document class.
macros/latex/contrib/supported/levy	levy	<<<<levy>>>>	Macros for using Silvio Levy's Greek fonts.
macros/latex/contrib/other/lgreek	lgreek	<<<<lgreek>>>>	Macros for using Silvio Levy's Greek fonts.
macros/latex/contrib/supported/jknappen	latin2jk	<<<<latin2jk>>>>	No caption.
systems/knuth	knuth	<<<<knuth>>>>	No caption.
macros/latex/contrib/supported/koi8	koi8	<<<<koi8>>>>	No caption.
macros/generic/diagrams/kuvio	kuvio	<<<<kuvio>>>>	Drawing macros and fonts for diagrams.
macros/latex/contrib/supported/labels	labels	<<<<labels>>>>	No caption.
macros/lamstex	lamstex	<<<<lamstex>>>>	A merge of the best in AMS-TeX and LaTeX.
macros/latex/contrib/other/lastpage	lastpage	<<<<lastpage>>>>	Reference last page for Page N of M type footers.
systems/msdos/lated	lated	<<<<lated>>>>	No caption.
macros/latex209	latex209	<<<<latex209>>>>	The pre-1993 LaTeX, now no longer supported.
support/jspell	jspell	<<<<jspell>>>>	An ASCII file spelling checker.
macros/latex/contrib/supported/jura	jura	<<<<jura>>>>	A document class for German legal texts.
macros/latex/contrib/other/kalender	kalendar	<<<<kalendar>>>>	A calendar style.
macros/latex/contrib/other/kalender	kalender	<<<<kalender>>>>	Style file for creating a calendar; in German.
fonts/greek/kd	kdgreek	<<<<kdgreek>>>>	Greek fonts.
macros/latex/contrib/other/misc	kix	<<<<kix>>>>	No caption.
macros/latex/contrib/supported/kluwer	kluwer	<<<<kluwer>>>>	No caption.
macros/generic/knst	knst	<<<<knst>>>>	No caption.
language/italian	ithyph	<<<<ithyph>>>>	Italian hyphenation.
fonts/cyrillic/old_slavonic/izhitsa	izhitsa	<<<<izhitsa>>>>	Support for the old Russian font ``Izhitsa''.
macros/jadetex	jadetex	<<<<jadetex>>>>	Macros to implement Jade DSSSL output
systems/java/javatex	javatex	<<<<javatex>>>>	A Java implementation of TeX.
macros/plain/contrib/js-misc	jsmisc	<<<<jsmisc>>>>	Miscellaneous useful macros by Joachim Schrod.
macros/latex/base	ifthen	<<<<ifthen>>>>	Conditionals in LaTeX2e documents.
macros/latex/contrib/other/imac	imac	<<<<imac>>>>	International Modal Analysis Conference format.
macros/latex/required/tools	indentfirst	<<<<indentfirst>>>>	Indent first paragraph after section header.
macros/latex/contrib/supported/indxcite	indxcite	<<<<indxcite>>>>	No caption.
language/hyphenation	inhyph	<<<<inhyph>>>>	Hyphenation patterns for Bahasa Indonesia.
fonts/gothic/yinit	initials	<<<<initials>>>>	No caption.
macros/latex/base	inputenc	<<<<inputenc>>>>	Control input encoding.
macros/latex/contrib/supported/hyper	hyper	<<<<hyper>>>>	Hypertext cross referencing.
macros/latex/contrib/supported/hyphenat	hyphenat	<<<<hyphenat>>>>	Disable/enable hypenation.
systems/mac/textures/contrib/IdealFonts	idealfonts	<<<<idealfonts>>>>	No caption.
macros/latex/contrib/supported/ieeepes	ieeepes	<<<<ieeepes>>>>	IEEE Power Engineering Society Transactions.
macros/latex/contrib/supported/hilowres	hilowres	<<<<hilowres>>>>	No caption.
macros/latex/contrib/supported/histogr	histogr	<<<<histogr>>>>	Drawing histograms with the LaTeX picture environment.
support/html2latex	html2latex	<<<<html2latex>>>>	No caption.
language/hyphenation	huhyph	<<<<huhyph>>>>	Hyphenation patterns for the Hungarian language.
fonts/bookhands/huncial	huncial	<<<<huncial>>>>	Fonts based on the half Uncial manuscript book-hand.
macros/latex209/contrib/misc	hvdashln	<<<<hvdashln>>>>	No caption.
macros/latex/contrib/supported/hh	hh	<<<<hh>>>>	Fancy boxing effects.
macros/latex/required/tools	hhline	<<<<hhline>>>>	Better horizontal lines in tabulars and arrays.
support/latexdraw	latexdraw	<<<<latexdraw>>>>	X-Windows based and CAD orientated drawing program.
macros/latex/contrib/supported/misc	anonchap	<<<<anonchap>>>>	Make \chapter s be typeset like sections.
fonts/utilities/mmtools	mmpfb	<<<<mmpfb>>>>	Create instance of multiple-master font.
fonts/utilities/mmtools	mmafm	<<<<mmafm>>>>	Font metrics for multiple-master font.
systems/win32/texhelpers/labelmag	labelmag	<<<<labelmag>>>>	Manage a collection of labels.
biblio/bibtex/utils/fixbbl	fixbbl	<<<<fixbbl>>>>	Patch bibliographies inappropriately broken by bibtex.
language/greek/package-babel/hyphenation/filippou	hyphenation-greek	<<<<hyphenation-greek>>>>	Hyphenation patterns for ancient and modern Greek.
language/oriya	oryia	<<<<oryia>>>>	Typesetting the Oriya script using TeX.
macros/latex/contrib/supported/misc	fncylab	<<<<fncylab>>>>	Alter the format of \label references
biblio/bibtex/contrib	jtbnew	<<<<jtbnew>>>>	BibTeX style for Journal of Theoretical Biology.
macros/latex/contrib/supported/fltpoint	fltpoint	<<<<fltpoint>>>>	Float point.
macros/latex/contrib/supported/othello	othello	<<<<othello>>>>	Create othello boards in LaTeX.
macros/latex/contrib/supported/rccol	rccol	<<<<rccol>>>>	Right-centered optionally rounded numbers in tabular.
support/emacs-modes	u8tex	<<<<u8tex>>>>	Emacs Mule facility to input Unicode characters in TeX notation.
biblio/bibtex/utils/rfc2bib	rfc2bib	<<<<rfc2bib>>>>	Convert IETF RFCs to BibTeX.
graphics/xtexcad	xtexcad	<<<<xtexcad>>>>	Simple drawing program enforcing limited slopes and diameters.
macros/latex/contrib/other/misc	verbdef	<<<<verbdef>>>>	Define commands which expand to verbatim text
macros/latex/contrib/supported/was	fixmath	<<<<fixmath>>>>	Make maths comply with ISO31-0:1992 to ISO31-13:1992.
biblio/bibtex/contrib/economic	ecta	<<<<ecta>>>>	Bibliography style file for submission to Econometrica.
macros/latex/contrib/other/lcg	lcg	<<<<lcg>>>>	Generate random integers.
systems/win32/scientificviewer	scientificviewer	<<<<scientificviewer>>>>	GUI Equation Viewer
biblio/bibtex/contrib/chem-journal	chem-journal	<<<<chem-journal>>>>	Various BibTeX formats for journals in Chemistry.
macros/latex/contrib/supported/unicode	unicode	<<<<unicode>>>>	Map unicode to LaTeX macros and use UTF-8 input encoding.
macros/latex/contrib/supported/keystroke	keystroke	<<<<keystroke>>>>	Graphical representation of keys on keyboard.
support/ligatex	ligatex	<<<<LigaTeX>>>>	Remove unnecessary ligatures.
macros/latex/contrib/supported/prosper	prosper	<<<<prosper>>>>	LaTeX class for high quality slides.
macros/latex/contrib/supported/bophook	bophook	<<<<bophook>>>>	Provides AtBeginPage hook.
macros/latex/contrib/supported/mtgreek	mtgreek	<<<<mtgreek>>>>	Use italic and upright greek letters with	mathtime
macros/latex/contrib/other/misc	askinclude	<<<<askinclude>>>>	Interactive use of \includeonly
macros/latex/contrib/supported/misc	hypernat	<<<<hypernat>>>>	Allow hyperref and natbib to work together.
macros/latex/contrib/supported/pdfpages	pdfpages	<<<<pdfpages>>>>	Include PDF documents in LaTeX.
macros/latex/contrib/supported/genmpage	genmpage	<<<<genmpage>>>>	Generalization of LaTeX's minipages.
info/symbols/comprehensive	symbols	<<<<symbols>>>>	Comprehensive list of LaTeX symbols.
macros/latex/required/amslatex/classes	amsbook	<<<<amsbook>>>>	LaTeX document class for AMS books
macros/latex/required/amslatex/classes	amsart	<<<<amsart>>>>	LaTeX document class for AMS math journal articles
macros/latex/required/amslatex/classes	amsproc	<<<<amsproc>>>>	LaTeX document class for AMS conference proceedings
macros/latex/required/amslatex/classes	amsthm	<<<<amsthm>>>>	LaTeX package for theorem setup (AMS style)
macros/latex/contrib/supported/bundledoc	bundledoc	<<<<bundledoc>>>>	Bundle together all the files needed to build a LaTeX document.
graphics/metapost/yools/MPEdit	mpedit	<<<<MPEdit>>>>	MetaPost text editor for Win32.
macros/latex/contrib/supported/cv	cv	<<<<cv>>>>	A package for creating a curriculum vitae.
macros/latex/contrib/supported/numprint	numprint	<<<<numprint>>>>	Print numbers with a separator every three digits.
support/ttf2tex	ttf2tex	<<<<ttf2tex>>>>	Use TrueType fonts with teTeX.
macros/latex/contrib/supported/compactbib	compactbib	<<<<compactbib>>>>	Allows many thebibliography environments with continuous numbering.
macros/latex/contrib/supported/misc/chbibref	chbibref	<<<<chbibref>>>>	Change the Bibliography/References title.
macros/latex/contrib/supported/curve	curve	<<<<CurVe>>>>	A LaTeX2e class for making curriculum vitae.
macros/latex/contrib/supported/fink	fink	<<<<FiNK>>>>	The LaTeX2e File Name Keeper.
macros/latex/contrib/supported/fixme	fixme	<<<<FiXme>>>>	Insert "fixme" notes into draft documents.
macros/latex/contrib/supported/polynom	polynom	<<<<polynom>>>>	Macros for manipulating polynomials.
fonts/allrunes	allrunes	<<<<allrunes>>>>	Fonts and LaTeX package for almost all runes.
macros/latex/contrib/supported/pdftricks	pdftricks	<<<<pdftricks>>>>	Support for pstricks  in pdftex.
macros/latex/contrib/supported/IEEEtran	ieeetran	<<<<IEEEtran>>>>	Document class for IEEE Transactions.
biblio	Systems for maintaining and presenting bibliographies within documents typeset using TeX
digests	Collections of TeX mailing list digests, TeX-related `electronic magazines', and indexes, etc., of printed publications
dviware	Printer drivers and previewers, etc., for .dvi files
fonts	Fonts written in Metafont, and support for using fonts from other sources (e.g., those in Adobe Type 1 format)
graphics	Systems and TeX macros for producing graphics
help	FAQs and similar direct assistance	
indexing	Systems for maintaining and presenting indexes of documents typeset using TeX
info	Manuals and extended how-to information; errata for TeX-related publications, collections of project (e.g., LaTeX and NTS) documents, etc. 
language	Support for various languages; hyphenation pattern
macros	TeX macros; several directories have significant sub-trees
macros/contex	The Context distribution
macros/generic	Macros that work in several environments
macros/latex	The LaTeX distribution and contributed matter
macros/plain	Donald Knuth's example macro set and contributed material
support	TeX support environments and the like
systems	TeX systems; organised by operating environment, but also including
systems/knuth	Donald Knuth's current distribution
systems/generic	Complete systems that can potentially operate in more than one operating environment
tds	The TeX Directory Structure standard (the output of the TUG TDS working group)
tools	Tools of use for the archive maintainers (including mirrors of the source of the compression tools the archives use)
usergrps	Information supplied by TeX User Groups
web	`Literate Programming' tools and systems
nonfree/systems	Material which is not freely-usable (shareware, or of restricted usage, such as no-commercial or no-military use, or may not be included in commercial distributions).  Users of the archive should check that they are entitled to use material downloaded from the nonfree/ tree.
obsolete/macros	Material which is now obsolete, but which needs to remain on the archive for some reason (such as the 1992 LaTeX 2.09 distribution). 
macros/latex/contrib	Packages pertaining to LaTeX contributed to CTAN by the TeX community 
macros/latex/contrib/supported	Packages pertaining to LaTeX contributed to CTAN, and for which the contributer is willing to make updates, etc.  Most people looking for a LaTeX package will want to look here.          




