package Apache::FTPBrowsing;
# File: Apache/FTPBrowsing.pm

use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
	  );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL $mirror);
$this_mods_URL = FTPBROWSING_PAGE(); # URL from perl.conf for this module  
$mirror = "";

use vars qw($r);  # request object

sub handler {
    $r = shift;
    # blank out cross-process data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data);
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Browsing CTAN under FTP",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Browsing CTAN by Command Line FTP")
	      );

    $r->print(
	      p(
		" Besides using a web browser, you can also access 
                 the Comprehensive TeX Archive Network using
                 an FTP client program. "
		)
	      );

    $r->print(
	      p(
		"From a command line, use FTP to connect to the 
                CTAN nearest to you: either ",
		pre("   ftp tug.ctan.org"),
		" to connect to the Vermont, USA, or ",
		pre("   ftp cam.ctan.org"),
		" to connect to Cambridge, England, or ",
		pre("   ftp dante.ctan.org"),
		" to connect to Heidelburg, Germany. ",
		"Give ",
		i("ftp"),
		" as your username, and your email address as your password. "
		),
	      p(
		"You are now in the remote machine. ",
                "You can move around in the natural way. ",
		dl(
		   dt(tt("dir")),
		   dd(" shows you what is in the directory, "),
		   dt(tt("pwd")),
		   dd(" prints your working (that is, current) directory, "),
		   dt(tt("cd")),
		   dd(" moves you to the directory above the one 
                         that you are in, and "),
		   dt(tt("cd &lt;dir name&gt;")),
		   dd(" moves you into a desired subdirectory "),
		   ),
                "For instance, the command ",
		tt("cd /tex-archive/macros/latex/contrib/supported"),
		" will put you into that directory."
		),
	      p(
		i("Note: "),
		"Users often want to get a package by getting a 
                whole directory.
                Rather than download the files one at a time 
                use the ",
		tt("binary"),
		" and ",
		tt("get &lt;dirname&gt;.zip"),
		"commands . For instance, 
                 if you follow the command in the prior paragraph
                 so that you are in the directory just above the `answers' 
                 package, the two ",
		tt("binary"),
		" and ",
		tt("get answers.zip"),
                " will bring to your machine a file `answers.zip'. 
                 This file is an archive; 
                 it contains everything from the `answers' directory,
                 compressed to save space and download time.
                 Unpack this bundling with the programs from ",
		a({-href=>WEBFTP_ROOT()."archive-tools/zip/info-zip/Info-ZIP.html$URL_str"},
                  "Info-ZIP"),
		". "
		)
	      );

    $r->print(
	      end_CTAN_page(", revised 2001-Mar-02 JH.",$URL_str)
	      );

    return OK;
}

1;





