package Apache::FTPRootIndex;
# File: Apache/FTPRootIndex.pm
#  JH: All this writing is Robin Fairbairns's 
use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
	  );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL $mirror);
$this_mods_URL = FTPROOTINDEX_PAGE(); # URL from perl.conf for this module  
$mirror = "";

use vars qw($r);  # request object

sub handler {
    $r = shift;

    # blank out cross-session data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data);
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $param_data{PARAM_ACTION_KEY()} = "";
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    #$filetoget = $param_data{PARAM_FILENAME_KEY()};
    #$mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "The CTAN archive.",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("The CTAN root directory")
	      );

    $r->print(
	      p(
		"This is the root of the Comprehensive TeX Archive Network
                 directory tree.  
                 Most information in CTAN is contained in subdirectories: "
		),
	      dl(
		 dt(
		    a({-href=>"biblio/$URL_str"},
		      "biblio/")
		    ),
		 dd(
		    "Systems for maintaining and presenting bibliographies 
                    within documents typeset using TeX "
		    ),
		 dt(
		    a({-href=>"digests/$URL_str"},
		      "digests/")
		    ),
		 dd(
		    "Collections of TeX mailing list digests, 
                     TeX-related `electronic magazines', and indexes, 
                     etc., of printed publications "
		    ),
		 dt(
		    a({-href=>"dviware/$URL_str"},
		      "dviware/")
		    ),
		 dd(
		    "Printer drivers and previewers, etc., for .dvi files "
		    ),
		 dt(
		    a({-href=>"fonts/$URL_str"},
		      "fonts/")
		    ),
		 dd(
		    "Fonts written in Metafont, 
                     and support for using fonts from
                     other sources (e.g., those in Adobe Type 1 format) "
		    ),
		 dt(
		    a({-href=>"graphics/$URL_str"},
		      "graphics/")
		    ),
		 dd(
		    "Systems and TeX macros for producing graphics "
		    ),
		 dt(
		    a({-href=>"help/$URL_str"},
		      "help/")
		    ),
		 dd(
		    "FAQs and similar direct assistance; the ",
		    a({-href=>"help/Catalogue/catalogue.html$URL_str"},
		      "catalogue"
		      )
		    ),
		 dt(
		    a({-href=>"indexing/$URL_str"},
		      "indexing/")
		    ),
		 dd(
		    "Systems for maintaining and presenting indexes of 
                     documents typeset using TeX "
		    ),
		 dt(
		    a({-href=>"info/$URL_str"},
		      "info/")
		    ),
		 dd(
		    "Manuals and extended how-to information; 
                    errata for TeX-related publications, 
                    collections of project (e.g., LaTeX and NTS) documents, 
                    etc. "
		    ),
		 dt(
		    a({-href=>"language/$URL_str"},
		      "language/")
		    ),
		 dd(
		    "Support for various languages; hyphenation patterns "
		    ),
		 dt(
		    a({-href=>"macros/$URL_str"},
		      "macros/")
		    ),
		 dd(
		    "TeX macros; 
                     several directories have significant sub-trees: ",
		    dl(
		       dt(
			  a({-href=>"macros/context/$URL_str"},
			    "context/"
			    )
			  ),
		       dd(
			  "The Context distribution "
			  ),
		       dt(
			  a({-href=>"macros/generic/$URL_str"},
			    "generic/"
			    )
			  ),
		       dd(
			  "Macros that work in several environments "
			  ),
		       dt(
			  a({-href=>"macros/latex/$URL_str"},
			    "latex/"
			    )
			  ),
		       dd(
			  "The LaTeX distribution and contributed matter "
			  ),
		       dt(
			  a({-href=>"macros/plain/$URL_str"},
			    "plain/"
			    )
			  ),
		       dd(
			  "Donald Knuth's example macro set 
                           and contributed material "
			  )
		       )
		    ),
		 dt(
		    a({-href=>"support/$URL_str"},
		      "support/")
		    ),
		 dd(
		    "TeX support environments and the like "
		    ),
		 dt(
		    a({-href=>"systems/$URL_str"},
		      "systems/")
		    ),
		 dd(
		    "TeX systems; organised by operating environment, 
                    but also including: ",
		    dl(
		       dt(
			  a({-href=>"systems/knuth/$URL_str"},
			    "knuth/"
			    )
			  ),
		       dd(
			  "Donald Knuth's current distribution "
			  ),
		       dt(
			  a({-href=>"systems/generic/$URL_str"},
			    "generic/"
			    )
			  ),
		       dd(
			  "Complete systems that can potentially operate 
                           in more than one operating environment "
			  )
		       )
		    ),
		 dt(
		    a({-href=>"tds/$URL_str"},
		      "tds/")
		    ),
		 dd(
		    "The TeX Directory Structure standard 
                     (the output of the TUG TDS working group) "
		    ),
		 dt(
		    a({-href=>"tools/$URL_str"},
		      "tools/")
		    ),
		 dd(
		    "Tools of use for the archive maintainers 
                     (including mirrors of the source of the compression 
                     tools the archives use) "
		    ),
		 dt(
		    a({-href=>"usergrps/$URL_str"},
		      "usergrps/")
		    ),
		 dd(
		    "Information supplied by TeX User Groups "
		    ),
		 dt(
		    a({-href=>"web/$URL_str"},
		      "web/")
		    ),
		 dd(
		    "`Literate Programming' tools and systems "
		    ),
		 )
	      );

	$r->print(
		  p(
		    "In addition, there are two `shadow hierarchies'.  
                    Each of these maintains the same structure as the main 
                    tree -- for example, ",
		    a({-href=>"nonfree/systems/$URL_str"},
		      "nonfree/systems/"
		      ),
                   " has the same basic structure as ",
		    a({-href=>"systems/$URL_str"},
		      "systems/"),
		    ", ",
		    a({-href=>"obsolete/macros/$URL_str"},
		      "obsolete/macros/"),
                    " has the same basic structure as ",
		    a({-href=>"macros/$URL_str"},
		      "macros/"),
		    "."
		    ),
		  dl(
		     dt(
			a({-href=>"nonfree/$URL_str"},
			  "nonfree/"),
			),
		     dd(
			"Material which is not freely-usable 
                        (shareware, or of restricted usage, 
                        such as no-commercial or no-military use, 
                        or may not be included in commercial 
                        distributions -- see ",
			a({-href=>"#licence"},
			  "licensing"),
			", below).  
                        Users of the archive should check that they are 
                        entitled to use material downloaded from the
                        nonfree/ tree. "
			),
		     dt(
			a({-href=>"obsolete/$URL_str"},
			  "obsolete/"),
			),
		     dd(
			"Material which is now obsolete,  
                         but which needs to remain on the
                         archive for some reason 
                         (such as the 1992 LaTeX 2.09 distribution)."
			)
		     ),
		  p(
		    "The nonfree/ shadow hierarchy is mirrored 
                    (by Un*x-style `soft links') 
                    in the main (or occasionally the obsolete) hierarchy; 
                    the ",
		    a({-href=>"#FILES"},"FILES.* files"),
		    " only list instances of such items 
                    in the nonfree/ hierarchy."
		    ),
		  );

    $r->print(
	      h3("Searching CTAN"),
	      p(
		"Searching is a topic which is under active development: 
                 the CTAN team hope to be able shortly to provide significant 
                 new tools.  
                 In the interim, we can offer Jim Hefferon's ",
		a({-href=>SEARCH_PAGE()."$URL_str"},
		  "CTAN Search page"),
		" (note: this page sets a cookie to record what you believe 
                 to be your best CTAN mirror)."
		),
	      a({-name=>"FILES"},),
	      p(
		"In addition, CTAN archives maintain lists of their contents 
                 as plain text files, in a number of ways: ",
		ol(
		   li(
		      a({-href=>"FILES.byname$URL_str"},
			"Sorted by name"),
		      "(These are <em>big</em> files...around 4M bytes)"
		      ),
		   li(
		      a({-href=>"FILES.bydate$URL_str"},
			"Sorted by date")
		      ),
		   li(
		      a({-href=>"FILES.bysize$URL_str"},
			"Sorted by size")
		      ),
		   li(
		      a({-href=>"FILES.last07days$URL_str"},
			"New or changed in the last 7 days"),
		      " (This is usually a more manageable size...)"
		      )
		   )
		)
	      );

    $r->print(
	      a({-name=>"licence"},
		h3("Licence terms for the nonfree/ tree")),
	      p(
		"Details of the licensing categories employed on CTAN 
                 (and used in the Catalogue) 
                 are given in Graham Williams's ",
		a({-href=>"help/Catalogue/licenses.html$URL_str"},
		  "licensing page"),
		". ",
		),
	      p(
		"CTAN's ",
		a({-href=>"nonfree/$URL_str"},
		  "nonfree/"),
		"tree is for distributions whose licences are ",
		a({-href=>"help/Catalogue/licenses.nosell.html$URL_str"},
		  "nosell"),
		", ",
		a({-href=>"help/Catalogue/licenses.nocommercial.html$URL_str"},
		  "nocommercial"),
		", ",
		a({-href=>"help/Catalogue/licenses.shareware.html$URL_str"},
		  "shareware"),
		", ",
		a({-href=>"help/Catalogue/licenses.other.html$URL_str"},
		  "`other'"),
		" (said to be \"probably commercial\"), or ",
		a({-href=>"help/Catalogue/licenses.unknown.html$URL_str"},
		  "unknown"),
		". "
		),
	      p(
		"Note that distributions whose licences are the 
                 non-`Debian'-free category ",
		a({-href=>"help/Catalogue/licenses.nosource.html$URL_str"},
		  "nosource"),
                " is <em>not</em> moved to the nonfree/ tree; 
                 CTAN is concerned with distributability, 
                 rather than the broader modifiability,
                 etc., that the free software movement seeks."
		),
	      p(
		"The process of populating the ",
		a({-href=>"nonfree/$URL_str"},"nonfree/"),
		" tree is still `work in progress';  
                the CTAN team moves distributions
                there as they come to the team's attention.  
                Comments about classification should be sent to ",
		a({-href=>"mailto:ctan\@dante.de"},"the CTAN team"),
                " as a whole."
		)
	      );

    $r->print(
	      end_CTAN_page("  This is an experimental page;  
                             comments will be most welcome. 
                             Page by 
                             <a href=\"mailto:rf10\@cam.ac.uk\">Robin Fairbairns</a>.
                             Last revised 2000-Mar-13 JH",$URL_str)
	      );

    return OK;
}

1;





