package Apache::GetFile;
# File: Apache/GetFile.pm

use strict;
use File::Basename;
use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;
use Apache::MirrorCapabilities;
use Apache::DirInfo;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
          );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL
	    $basename $CTANpath $suffix $CTAN_dir_path $filetoget $service  
	    $mirror $mirror_full_path 
	    $scratch_str $scratch_flag @scratch_array );
$this_mods_URL = GETFILE_PAGE(); # URL from perl.conf for this module  

$basename = "";  # for File::Basename
$CTANpath = "";  # for File::Basename
$suffix = "";    # for File::Basename
$CTAN_dir_path = ""; # path to a directory
$filetoget = "";
$mirror = "";  # key for lookup in MirrorCapabilities 
$scratch_str = "";
$scratch_flag = 0;
@scratch_array = ();
$mirror_full_path = ""; # path to mirror: joshua.smcvt.edu/pub/tex-archive/
$service = ""; # zip or tar.gz

use vars qw($r);  # request object


sub handler {
    $r = shift;

    # blank out cross-session data
    %cookie_data = ();
    %param_data = ();
    %except = (
		  PARAM_FILENAME_KEY() => 1
		  );

    $basename = "";  # e.g. `shadethm'
    $CTANpath = "";  # e.g. `macros/latex/contrib/supported/'
    $CTAN_dir_path = ""; # concatenation: $CTANpath$basename (no `tex-archive')
    $suffix = "";   # e.g. `.zip'
    $service = "";  # e.g. `zip'
    $filetoget = "";
    $mirror = "";
    $mirror_full_path = ""; 
    $scratch_str = "";
    $scratch_flag = 0;
    @scratch_array = ();

    # Start to process the request; handle header info first
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,1,\%cookie_data,\%param_data); 
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    $filetoget = $param_data{PARAM_FILENAME_KEY()};
    $mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Get a File from CTAN",
			 -meta=>{'keywords'=>META_KEYWORDS()})
	      );

    # handle error case first
    #  first error; no file given
    unless ($filetoget) {
	$r->print(
		  "<P>This web address is for getting a file from the ",
                  a({href => TOPINDEX_PAGE()."$URL_str"} ,
		    "Comprehensive TeX Archive Network"),
		  ".  ",
		  "But you have not specified a file, so you seem to 
                   be in the wrong place.
                   Perhaps you want to ", 
		  a({href => SEARCH_PAGE()."$URL_str"},
		    "search"),
		  " or ",
		  a({href => FTPROOTINDEX()."$URL_str"},
		    "browse"),
		  " the archive? ",
		  "Good luck. ",
		  "</P>\n"
		  );
	$r->print(
		  end_CTAN_page(" last revised 2001-Mar-02 JH ",$URL_str)
		  );
	return OK;
    }

    # since the no-filename error case is past, we must have a filename
    $mirror_full_path = "$mirror".mirror_FTP_path($mirror);
    ($basename, $CTANpath, $suffix) = fileparse($filetoget,'\..*');

    # the second error case is that there is no file there to get
    # (and no virtual file; no .zip or .tar.gz). 
    unless ((-e INTERNAL_FTP_PATH()."/$filetoget") 
	    || (-d INTERNAL_FTP_PATH()."/$CTANpath/$basename")) {
	$r->print(
		  "<P>You have asked to download
                  <b>$filetoget</b>
                  from the Comprehensive TeX Archive Network. 
		  But this program cannot find that file.</P>\n",
                  "<P>You may find helpful going to the ",
		  a({href => SEARCH_PAGE()."$URL_str"},"search page"),
		  ".\n",
                  "If, however, you are insistent, you can click to 
                  try to fetch your file via FTP 
                  from your preferred CTAN mirror site: ", 
		  "<i>$mirror</i>.\n",
		  center(a({href => "ftp://$mirror_full_path/$filetoget"},
			   b($filetoget))),
		  "(It sometimes takes material a few days to 
                   work its way through the propagation routines
                   from one CTAN site to another, so it is possible that 
                   your mirror has something that this CTAN does not.)",
		  "</P>\n"
		  );
	$r->print(
		  end_CTAN_page(" last revised 2001-Mar-02 JH ",$URL_str)
		  );
	return OK;
    }

    # now error cases out of the way -- get down to business
    $r->print(
	      h2("Get <i>$filetoget</i> from CTAN")
	      );

    # next, a regular file; it is not a virtual file and not a directory.
    #   just let the person get it.
    if ((-e INTERNAL_FTP_PATH()."/$filetoget")
	&& (!(-d INTERNAL_FTP_PATH()."/$filetoget"))) {
	    $r->print(
		      "<P>Clicking on the link below will bring it to 
                      you via FTP from your preferred CTAN mirror site ", 
		      "<i>$mirror</i>",
                      " (you may want to use 
                       <i>&lt;shift&gt;-&lt;click&gt;</i> 
                       instead of just 
                       <i>&lt;click&gt;</i>). \n",
		      p(
			center(a({href => "ftp://$mirror_full_path/$filetoget"},
			       b($filetoget)))
			),
		      "</P>"
		      );
	    if (any_info("$CTANpath")) {
		$r->print(
			  hr(),
			  "<P>This file is in the directory ",
			  a({-href=>WEBFTP_ROOT()."$CTANpath$URL_str"},
			    b("$CTANpath")),
			  ".
                           About that directory we have this information:
                           </P>\n",
			  display_info("$CTANpath",$URL_str)
			  );
	    }
	# from here on it is a directory of some kind
	# can we get it?
	} else {
	    $CTAN_dir_path = "$CTANpath$basename";
	    $r->print(
		      "<P>Your request is about the directory ",
		      a({-href => WEBFTP_ROOT."$CTAN_dir_path$URL_str"},
			b("$CTAN_dir_path")),
		      ".</P>\n"
		      );
	    $CTAN_dir_path =~ s!/\s*$!!; # strip trailing spaces
	    $service = substr($suffix,1); # strip the . in .zip 
	    if (-e INTERNAL_FTP_PATH()."/$CTAN_dir_path/.notar") {
		$r->print(
			  "<P>Ordinarily you would be allowed to   
                           request an archive of this directory,
                           a .zip or .tar.gz collection of the contents. 
                           However, this particular directory has the 
                           archiving function turned off.
                           This is usually done because the archive
                           would be a quite large file.
                           (The directory archives are produced on the fly,
                           to ensure consistency with the directory,
                           and producing such a very large file would slow this
                           machine down for other users.)</P>\n ", 
                           "<P>If you did not simply ask for this directory  
                           in error, perhaps you need the ",
		           a({href=>"http://www.tug.org/texlive.html"},
                              "TeXLive CD-ROM"),
		           ". ",
		           "</P>\n"
			  );
	    } elsif ($service eq "") { # just asked for a dir; no extension
		$scratch_flag = 0;
		@scratch_array = mirror_services($mirror);
		if (@scratch_array) {
		    $filetoget =~ s!/$!!; # if filename ends in /, kill that.
		    foreach $service (@scratch_array) {
			if ($scratch_flag == 0) {
			    $r->print(
				      " You can get the directory's contents 
                                      as a "
				      );
			} else {
			    $r->print(
				      " or as a ",
				      );
			}
			$r->print(
				  a({href => "ftp://$mirror_full_path/$CTAN_dir_path.$service"},
				    b(".$service")),
				  " archive"
				  );
			$scratch_flag=1; # second time thru loop differs
		    }
		    $r->print(".
                               (You can get software to unzip from ",
			      a({-href=> WEBFTP_ROOT()."tools/zip/info-zip$URL_str"},
				"Info-ZIP"),
			      ".)\n");
		} else {
		    $r->print(
	    		      "Ordinarily you would be allowed to   
                               request an archive of this directory,
                               a .zip or .tar.gz collection of the contents. 
			       However, your preferred mirror <i>$mirror</i> 
                               is not on our list of ones that 
                               support getting directory archives.
                               See the ",
			       a({-href=>"#notes"},
				 "notes"),
			      " below. "
			      );
		}
	    } elsif (!(mirror_offers($mirror,$service))) {
		$r->print(
			  "The .$service file would be an archive of 
                          the directory that would be
                          generated by the FTP site. 
                          (A directory's archive must be produced on the fly,
                          to ensure consistency with the directory.)
                          However, your preferred CTAN mirror site ", 
		          "<i>$mirror</i> ",
		          "is not on our list of ones that offer on-the-fly 
                          .$service service. ",
		          "You can try to get it anyway </P>",
			  p(
			    center(a({href => "ftp://$mirror_full_path/$filetoget"},
				     b($filetoget)))
			    ),
			  "<P>and if that does not work, you can ",
			  a({href=>GETMIRROR_PAGE()."$URL_str"},
			    "change your CTAN mirror"),
			  ". ",
			  "</P>\n"
			  );
	    } else {
		$r->print(
			  "The .$service file will be an archive of 
                          the directory,
                          generated on the fly when you
		          click on the link below. 
                          It will come to you via FTP 
                          from your preferred CTAN mirror site ", 
		          "<i>$mirror</i>\n",
                          " (you may want to use 
                          <i>&lt;shift&gt;-&lt;click&gt;</i> 
                          instead of just 
                          <i>&lt;click&gt;</i>). \n"
			  );
		if ($service eq "zip") {
		    $r->print(
                              " You can get software to unzip from ",
			      a({-href=> WEBFTP_ROOT()."tools/zip/info-zip$URL_str"},
				"Info-ZIP"),
			      ". \n");
		    }
		$r->print(
			  center(a({href => "ftp://$mirror_full_path/$filetoget"},
				   b($filetoget))),
			  "</P>\n"
			  );
	    }
	} # ends the directory if .. else ..
	
    if (any_info("$CTAN_dir_path")) {
	$r->print(
		  hr(),
		  h3("Information on the directory"),
		  display_info("$CTAN_dir_path",$URL_str)
		  );
    }
    $r->print(hr(),
	      small(a({-name=>'notes'},
		      h3("A few notes")),
	            ul({-type=>"circle"},
		       li([installation_advice($URL_str),
			   mirror_explanation($URL_str)])
		       )
		    )
	      );

    $r->print(
	      end_CTAN_page(" last revised 2001-Mar-02 JH ",$URL_str)
	      );
    
    return OK;
}

1;
