package Apache::GetMirror;
# file: Apache/GetMirror.pm

use strict;
use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;
use Apache::MirrorCapabilities;

# all variables global to stop memory/GC buildup
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
          );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($form_action $this_mods_URL $mirror);
$form_action = "";
$this_mods_URL = GETMIRROR_PAGE(); # URL from perl.conf for this module  
$mirror = "";

use vars qw($r);  # request object

sub handler {
    $r = shift;

    # blank out cross-session data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       "preferredCTAN" => 1
	       );
    # handle http headers
    $param_data{PARAM_GOTO_GETMIRROR()}=0; # after this, not at GetMirror page
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data); 
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    #$param_data{PARAM_ACTION_KEY()} = "ctan/getmirror/";
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0; # now reset it to false 
    $mirror = $param_data{PARAM_MIRROR_KEY()};
    # done with the header & state stuff

    $form_action = "http://".THIS_SITE_WEB().determine_action($param_data{PARAM_ACTION_KEY()},WEB_ROOT())."$URL_str";

    $r->print(
	      start_html(-title => "Select a CTAN mirror",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Select a CTAN mirror site")
	      );

#    $r->print(
#	      "<P>debug: cookie data: ".debug_info(%cookie_data)."</P>",
#	      "<P>debug: param data: ".debug_info(%param_data)."</P>"
#	      );

    $r->print(
	      "<P>Please
	       select the site that you would like to use for your downloads
               from among the mirrors of the Comprehensive TeX Archive Network 
               listed here.
               Picking one that is near you is likely to minimize network 
               overhead.\n"
	      );
    if (exists $param_data{PARAM_MIRROR_KEY()}) {
	$r->print(
		  "(Your default mirror now is 
                   <i>$param_data{PARAM_MIRROR_KEY()}</i>.)\n"
	          );
	delete($param_data{PARAM_MIRROR_KEY()});
    } else {
	$r->print(
		  "(You do not currently have a default mirror.)\n"
	          );
    }
    $r->print(
	      "</P>"
	      );

    $param_data{PARAM_NEWMIRRORFLAG_KEY()}=1; # this is a new mirror, of course
    $r->print(
	      start_form(-method => "POST", 
			 -action => $form_action), 
	      params_as_hiddenfields(%param_data)
	      );

    $r->print(
	      center(popup_menu(-name => COOKIE_MIRROR_KEY(),
				-value => [@mirrors],
				-labels => $mirror_popup_labels,
				-default => "ctan.tug.org")),
	      "</P>\n"
	      );

    $r->print(
	      p(i("Note: ").
		"Some of the sites on the list
                 are described with a `zip' or `tar.gz', or both.
                 These sites allow you to
                 download a package's directory
                 as a single archive file, 
                 a .zip file or a .tar.gz file.\n")
	      );

    $r->print(
	      center(submit(
			    -name => "submit"
			    )
		     ),
	      end_form()
	      );

    $r->print(
	      p("Next, click on the submit button.
                 After you have submitted your selection, 
                 you will be offered a cookie, if your browser allows that.
                 If you accept the cookie, or if you have set your browser to
                 accept it automatically for you, then 
                 you won't have to see this page again
                 the next time you return to CTAN.\n")
	      );

    $r->print(
	      end_CTAN_page(" revised 2001-Mar-02 JH",$URL_str)
	      );

    return OK;
}


1;





