package Apache::Index;
# File: Apache/Index.pm

use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
	  );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($form_action $this_mods_URL $mirror);
$form_action = "";
$this_mods_URL = TOPINDEX_PAGE(); # URL from perl.conf for this module  
$mirror = "";

use vars qw($r);  # request object

sub handler {
    $r = shift;

    # blank out cross-session data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data); 
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    #$mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Welcome to ctan.org",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Welcome to CTAN: the Comprehensive TeX Archive Network")
	      );

#    $r->print(
#	      "<P>debug: cookie data: ".debug_info(%cookie_data)."</P>",
#	      "<P>debug: param data: ".debug_info(%param_data)."</P>"
#	      );

    $r->print(
	      p(
		"CTAN provides the most complete and up-to-date TeX-related software. "
		)
	      );

    $r->print(
	      hr(),
	      p(
		"These links give TeX users access to the resources of this archive"
		),
	      p(
		ul(
		   li(
		      a({-href=>SEARCH_PAGE()."$URL_str"},
			"Search"),
		      " the archive. ",
		      " This page allows you to search by filename, 
                       or to search ",
		      a({-href=>CATALOGUEINDEX_PAGE."$URL_str"},
			"Graham Williams's catalogue"),
		      " of information on TeX-related material, 
                       and also contains links to a few FAQ-type documents. ",
		      " We also have an outline of how to ",
		      a({-href=>INSTALLATIONADVICE_PAGE."$URL_str"},
			"install"),
		      "the packages that you find. "
		      ),
		   li(
		      a({-href=>FTPROOTINDEX_PAGE."$URL_str"},
			"Look through"),
		      "the archive with your browser.
                      You may prefer to work via an ",
		      a({-href=>FTPBROWSING_PAGE."$URL_str"},
			"ftp command line"),
                      ", which is faster if you have a slow connection. ",
		      "You may also find better network access by using a ",
		      a({-href=>WEBFTP_ROOT()."CTAN.sites$URL_str"},
			"CTAN mirror"),
                      " that is close to you. "
		      ),
		   li(
		      "View the new additions, the files changed in the ",
		      a({-href=>WEBFTP_ROOT()."FILES.last07days$URL_str"},
			"last seven days"),
		      ". "
		      ),
		   li(
		      "Upload material for placing into the archive.
                      You can do this either
                      via an ",
		      a({-href=>WEBFTP_ROOT()."README.uploads$URL_str"},
			"ftp command line"),
                      " or ",
		      a({-href=>UPLOAD_PAGE()."$URL_str"},
			"from a browser"),
		      ". "
		      ),
		   )
		)
	      );

    $r->print(
	      hr(),
	      h3("Other links of interest. "),
	      p(
		"You may find these handy. "
		),
	      ul(
		 li(    
		    "The ",
		    a({-href=>"http://www.tug.org"},
		      "TeX Users Group"),
		    " has been a resource for TeX users for many years
                    (the machine on which this page lives is provided by 
                    <i>TUG</i>).
                    There you will find ",
		    a({-href=>"http://www.tug.org/interest.html"},
		      "links to more TeX resources"),	
                    " including information about TeX implementations 
                    for almost any platform.
                    You will also find there a list of ",
		    a({-href=>"http://www.tug.org/lugs.html"},
		      "other TeX users groups"),
		    ". "
		    ),
		 li(    
		    "The other two primary CTAN nodes have web interfaces at ",
		    a({-href=>"http://www.tex.ac.uk"},
		      "www.tex.ac.uk"),
		    " in England ",
                    " and ",
                    a({-href=>"http://dante.ctan.org"},
		      "dante.ctan.org"),
                    " in Germany. "
		    ),
		 li(
		    "If you are a beginner, or maybe a bit lost, try our ",
		    a({-href=>STARTER_PAGE()."$URL_str"},
		      "starter page"),
                    ". "
		    )
		 )
	      );

    $r->print(
	      end_CTAN_page(", revised 2001-Mar-13 JH.",$URL_str)
	      );

    return OK;
}

1;





