package Apache::InstallationAdvice;
# File: Apache/InstallationAdvice.pm

use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
          );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL $mirror);
$this_mods_URL = INSTALLATIONADVICE_PAGE(); # URL from perl.conf for this  
$mirror = "";

use vars qw($r);  # request object

sub handler {
    $r = shift;

    # blank out cross-process data 
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data);
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    # $mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Installing a file from CTAN",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Installing a file from the Comprehensive TeX Archive Network")
	      );

    $r->print(
	      p(
		"Once you have found the material that you want on the ",
		a({-href=>TOPINDEX_PAGE()."$URL_str"},
		  "Comprehensive TeX Archive Network"), 
		" you need to install it. This page
                gives you some ",
		a({-href=>"#guidelines$URL_str"},
		  "guidelines"),
		" and an ",
		a({-href=>"#example$URL_str"},
		  "example"),
		". "
		)
	      );

    $r->print(
	      hr,
	      a({-name=>"guidelines"},
		h3("Guidelines")),
	      p(
		"Assuming that you have one of the modern ",
		a({-href=>WEBFTP_ROOT()."tds/standard/tds/$URL_str"},
		  "TeX Directory Structure"),
		"-compliant distributions such as ",
                a({-href=>"http://www.tug.org/tetex/"},
		  "teTeX"),
                " for unix-like systems, ",
		a({-href=>WEBFTP_ROOT()."systems/win32/miktex/2.0/$URL_str"},
		  "mikTeX"),
		" for win32's such as Windows 98 and NT, ",
		"or, also for win32's, ",
		a({-href=>WEBFTP_ROOT()."systems/win32/fptex/$URL_str"},
		  "fpTeX"),
		" (which comes with the ",
		a({-href=>"http://www.tug.org/texlive"},
		  "TeX Live CD-ROM"),
		"), there are some general rules that you can follow. " 
		)
	      );

    $r->print(
	      ol(
		 li(   
		    p(
		      b("When you download a TeX package from CTAN"),
		       "if the package has its own separate directory then
                       you should fetch the 
                       entire contents of that directory." 
		      )
		    ),
		 
		 li(
		    p(
		      b("Put new files in a local texmf tree. "),
		      "The default TeX local root directory is as follows: ",
		      center(
			     table({-border=>"1", -cellpadding=>"4"},
				   Tr(td(["teTeX","/usr/share/texmf.local/"])),
				   Tr(td(["mikTeX","c:\\localtexmf\\"])),
				   Tr(td(["fpTeX","c:\\fptex\\texmf.local\\"]))
				   )
			     ),
		      "We will write \$TEXMF for your 
                      system's local texmf root."
		      ),
		    p(
		      "In your local texmf tree, 
                       imitate the directory structure in your main tree. 
                       Here's some examples of where files of 
                       given extensions should go.
                       (Note that these are unix-style directory separators; 
                       on a win32 system change the /'s to \\'s.)",
		      center(
			     table({-border=>"1", -cellpadding=>"4"},
				   Tr(td([".sty, .cls or .fd",
					  "\$TEXMF/tex/latex/<i>&lt;packagename&gt;</i>/"])),
				   Tr(td([".dvi, .ps or .pdf",
					  "\$TEXMF/doc/latex/<i>&lt;packagename&gt;</i>/"])),
				   Tr(td([".tfm",
					  "\$TEXMF/fonts/tfm/<i>&lt;supplier&gt;</i>/<i>&lt;fontname&gt;</i>/"])),
				   Tr(td([".vf",
					  "\$TEXMF/fonts/vf/<i>&lt;supplier&gt;</i>/<i>&lt;fontname&gt;</i>/"])),
				   Tr(td([".afm",
					  "\$TEXMF/fonts/afm/<i>&lt;supplier&gt;</i>/<i>&lt;fontname&gt;</i>/"])),
				   Tr(td([".pfb",
					  "\$TEXMF/fonts/type1/<i>&lt;supplier&gt;</i>/<i>&lt;fontname&gt;</i>/"])),
				   Tr(td([".ttf",
					  "\$TEXMF/fonts/truetype/<i>&lt;supplier&gt;</i>/<i>&lt;fontname&gt;</i>/"]))
				   )
			     ),
		       "Where of course <i>&lt;packagename&gt;</i>, 
                       <i>&lt;fontname&gt;</i> and <i>&lt;supplier&gt;</i> 
                       depend upon what's appropriate for the individual file."
		      )
		    ),

		 li(
		    p(
		      b("If it is a LaTeX2e package, 
                         you may need to extract the style file 
                         for LaTeX to read. "),
		      "Many LaTeX2e packages are written in a 
                      literate programming style, 
                      with source and documentation in the same file. 
                      The documented sources conventionally have the 
                      suffix .dtx.
                      So, if you find the package that you want but 
                      there is no .sty, 
                      instead you see a .dtx and a .ins, 
                      then do this. ",
		      ul({-type=>"circle"},
			 li(
			    i("Extract a .sty or a .cls."),
			    "From the command line in the directory where 
                            you put the package, type ",
			    pre("    latex &lt;package_name&gt;.ins"),
			    "(the `ins' means `install') and it will extract 
                            from the .dtx file
                            the desired LaTeX2e-readable file."
			    ),
			 li(
			    i("Extract the documentation (this is optional)."),
			    "Type ",
			    pre("    latex &lt;package_name&gt;.dtx"),
			    "to get from the .dtx file a .dvi file that 
                            contains, typically,
                            both usage and TeX-code documentation.
                            (If LaTeX complains about not finding a .ind file
                            then you can make the index with  
                            `makeindex -s gind.ist <i>&lt;package_name&gt;</i>'
                            and then try LaTeX again.)
                            Read the resulting .dvi in the way that you 
                            normally do.
                            For instance, you could read it with your .dvi 
                            reader, 
                            or use 
                            `dvips -o<i>&lt;package_name&gt;</i>.ps <i>&lt;package_name&gt;</i>.dvi' 
                            to convert it to PostScript. "
			    ),
			 li(
			    i("Run any extra documention or test files (also optional)."),
                            " Naturally, test files or extra documentation are
                             likely to use the package that they test or
                             discuss, so this step needs to come after
                             you've produced the .sty file."
			    )
			 ),
		      "Often there will also be a `README' file in the 
                      directory. 
                      Read it; many packages need to do something slightly 
                      different than is sketched here."
		      )
		    ),

		 li(
		    p(
		      b("Finally, remember to update 
                        your filename database. "),
		      "This is the most-often forgotten step. ",
		      center(
			     table({-border=>"1", -cellpadding=>"4"},
				   Tr(td(""),
				      th(["from a command line",
					  "using menus"])),
				   Tr(td(["teTeX",
					  "texhash",
					  "(launch menu with:) texconfig  -> REHASH"])),
				   Tr(td(["mikTeX",
					  "initexmf -update-fndb",
					  "Start-> Miktex-> Maintenance -> Refresh file name database"])),
				   Tr(td(["fpTeX",
					  "texhash",
					  "Start-> TeXLive-> Maintenance"]))
				   )
			     ),
		      "(On older systems, the updater program might be 
                      called `mktexlsr').
                      If you try to use your new package and get a 
                      `... not found' error 
                      then probably you forgot this step."
		      )
		    )
		 )
	      );

    $r->print(
	      hr,
	      a({-name=>"example"},
		h3("Example: the SI Units package")),
	      p(
		"Suppose that you want to process a LaTeX file that calls 
                for the SI units package, which you do not have installed.
                These are the steps you can go through.
                (This example assumes that you have Linux. 
                For other systems just make the small adjustments.) "
		),
	      p(
		ol(
		   li(
		      "Go to a CTAN and get the entire directory.
                      For instance, you might use the ",
		      a({-href=>SEARCH_PAGE()."$URL_str"},
			"search page"),
		      ", do a file search for <i>SIunits</i>,
                      and select to get the entire directory as a .zip file. "
		      ),

		   li(
		      "Put the package in a good place. ",
                      "The command ",
                      pre("    cd /usr/share/texmf.local"),
                      " will (in this teTeX example) put you at the top
                      of \$TEXMF, the TeX local root directory.   
                      Then ",
                      pre("    cd tex/latex"),
                      " will bring you down into the directory for 
                      LaTeX styles and ",
		      pre("    unzip &lt;path to the file you fetched&gt;/SIunits"), 
                      " will make a subdirectory for the material that
                      you have fetched. 
                      (Of course, you need permission to write to 
                      these directories.) "
		      ),

		   li(
		      "Now move into that directory and extract the 
                      .sty file. ",
                      " After cd-ing into the directory, ", 
                      pre("    latex SIunits.ins"),
                      " extracts a collection of LaTeX-usable material. ", 
                      " For the documentation,
                       this package asks you to `run the SIunits.drv' file ",
                      pre("    latex SIunits.drv"),
                      " (I had to run the prior command three times before 
                      LaTeX's `reference undefined' warnings stopped). "
		      ),

		   li(
		      "Refresh the database that TeX searches for files. ", 
                      pre("    texhash")
		      )
		   ),

		p(
		  "Now you should be able to run LaTeX on that file. "
		  )
		)
	      );


    $r->print(
	      end_CTAN_page(", revised 2001-Mar-02 JH.  
                   Adapted from a post by A. Goreham to the usenet group
                   comp.text.tex on 2000-Nov-02.
                   Corrections, additional information, or pointers to 
                   similar pages for
                   other TeX implementations would be very welcome. ",
		   $URL_str)
	      );

    return OK;
}

1;
