package Apache::RegexExplain;
# File: Apache/RegexExplain.pm

use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
	  );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL $mirror);
$this_mods_URL = REGEXEXPLAIN_PAGE(); # URL from perl.conf for this module
$mirror = "";  

use vars qw($r);  # request object

sub handler {
    $r = shift;

    # blank out cross-process data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = REGEXEXPLAIN_PAGE();
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data); 
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    # $mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Regular Expression primer",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Primer on Regular Expressions")
	      );

    $r->print(
	      p(
		"This document describes regular expressions briefly 
                 and gives a few examples.
                 You should be able to put together a straightforward search 
                 by mimicing the examples below."
		)
	      );

    $r->print(
	      hr,
	      h3("Contents"),
	      p(
		ul(
		   li(
		      a({-href=>"#examples"},
			"Some examples"),
		      " to get you started. "
		      ),
		   li(
		      a({-href=>"#errors"},
			"Some common errors"),
		      " to suggest what you might be doing wrong."),
		   li(
		      a({-href=>"#summary"},
			"A summary"),
		      " of regular expressions in case you 
                      just need a prompt.")
		   )
		)
	      );

    $r->print(
	      hr(),
	      h3(
		 a({-name=>"examples"},
		   "Some Examples")
		 ),
	      p(
		"Here are a few examples to get you started.  
                The special characters that appear, 
                like *, are further described below."
		),
	      ul(
		 li(
		    b("ulem"),
		    p(
		      "Submitting this in the 
                       <i>Search CTAN files for:</i> 
                       box will match any filename containing those 
                       four letters in sequence. 
                       For instance, you will be shown all of the places where
                       <i>ulem.sty</i>
                       is found."
		      ),
		    p(
		      " Note that you do not need to give the entire file name.
                      You might be having trouble finding a file because
                      you are being too specific.
                      For instance, if you want 
                      <i>etruscan.sty</i> 
                      and searching for that entire string doesn't work, 
                      the next step is to search for 
                      <i>etruscan</i> alone.",
		      " You will then get hits for <i>etruscan.dtx</i>,
                       which you should download and turn into 
                       <i>etruscan.sty</i>, by following the directions
                       on the ",
		      a({-href=>INSTALLATIONADVICE_PAGE()."$URL_str"},
			"installation advice"),
		      " page. "
		      )
		    ),

		 li(
		    b("pdf.*exe"),
		    p(
		      "Submitting this in the 
                       <i>Search CTAN files for:</i> 
                       box will match any filename containing the three 
                       letters <b>pdf</b>
                       followed by any number of things 
                       (this is what the 
                       <b>.*</b>
                       does), followed by the three letters 
                       <b>exe</b>. 
                       For instance, this search will show you all 
                       of the places where
                       <i>pdftex.exe</i>
                       and 
                       <i>pdflatex.exe</i>
                       are."
		      ),
		    p(
		      "But you'll get lots of other hits also.
                      For instance, the filename
                      <i>tex-archive/support/pdftexenc/cmr.enc</i>
                      matches your request, because it has in it 
                      <b>pdf</b>,
                      followed by some stuff (a 
                      <b>t</b>),
                      followed by 
                      <b>exe</b>.
                      Not what you expected, maybe, 
                      but nonetheless what you asked for."
		      ),
		    p(
		      "By the way, `some stuff' might mean `no stuff'.
                      That is, 
                      <b>.*</b>
                      means `zero or more characters'."
		      )
		    ),

		 li(
		    b("jtex|javatex"),
		    p(
		      "This will match any filename containing the 
                      four letters  <b>jtex</b>, 
                      and will also match any filename containing 
                      the seven letters <b>javatex</b>.
                      The vertical bar symbol | means `or'.
                      Use it if you can't remember quite how the name goes." 
		      ),
		    p(
		      "By the way, the same results could have been 
                      gotten from the query string <b>(j|java)tex</b>."
		      )
		    )
		 ),
	      p(
		"The examples may give you an idea of how to proceed.
                A more full description of regular expressions is below, 
                but for the whole story, you need formal documentation such as
                the Perl or egrep documentation."
		)
	      );

    $r->print(
	      hr(),
	      h2(
		 a({-name=>"errors"},
		   "Some common errors")
		 ),
	      ul(
		 li(
		    b("Misunderstanding the *"),
		    p(
		      "Many people are used to, for instance, using 
                       <i>s*.sty</i>
                       to search through a directory for all filenames 
                       beginning with <i>s</i>, 
                       containing any number of characters,
                       and ending in 
                       <i>.sty</i>. 
                       But that string does not do the same thing here.
                       Instead, 
                       <i>s*.sty</i>
                       searches for all filenames whose full path name contains
                       a string with any number of 
                       <i>s</i>'s,   
                       followed by any character (that's what the
                       <i>.</i>
                       does here), followed by 
                       <i>sty</i>."
		      ),
		    p(
		      "Because &quot;any number of 
                       <i>s</i>'s&quot;
                       includes zero of them, 
                       this will return the names of all 
                       style files on CTAN.
                       Not what you wanted."
		      ),
		    p(
		      "Instead, you meant to use the query string
                      <i>s.*sty</i>."
		      )
		    ),

		 li(
		    b("Asking for a .sty when CTAN has a .dtx"),
		    p(
		      "Some LaTeX style files are distributed not in .sty 
                      form but instead
                      as .dtx files (they are in a format that combines 
                      TeX code and documentation).
                      To find them, proceed as described in the ",
		      a({-href=>"#examples"},
			"`ulem' example"),
		      " above -- don't submit a search string ending in  
                      <i>.sty</i>,
                      instead just leave that off and search only for the 
                      first part of the  name."
		      )
		    )
		 )
	      );

    $r->print(
	      hr(),
	      h2(
		 a({-name=>"summary"},
		   "A summary of Perl regular expressions")
		 ),
	      p(
		"This table might prompt you on
                Perl regular expressions (egrep expressions are very similar)
                in case you have just forgotten something.",
		center(
		       table({-border=>"1", -cellpadding=>"4"},
			     Tr(th(["Regular expression",
				    "Description"])),
			     Tr(td([".",
				    "Matches any character except newline"])),
			     Tr(td(["[a-z0-9]",
				    "Matches any single character of the set"])),
			     Tr(td(["\\d",
				    "Matches a digit, i.e., [0-9]"])),
			     Tr(td(["\\w",
				    "Matches an alphanumeric character, i.e., [a-zA-Z0-9_]"])),
			     Tr(td(["\\W",
				    "Matches a non-word character, i.e., [^a-zA-Z0-9_]"])),
			     Tr(td(["\\metachar",
				    "Matches the character itself, i.e., \|, \*, \+"])),
			     Tr(td(["x?",
				    "Matches 0 or 1 x's, where x is any of the above"])),
			     Tr(td(["x*",
				    "Matches 0 or more x's"])),
			     Tr(td(["x+",
				    "Matches 1 or more x's"])),
			     Tr(td(["x{m,n}",
				    "Matches at least m x's but no more than n"])),
			     Tr(td(["foo|bar",
				    "Matches one of foo or bar"])),
			     Tr(td(["(x)",
				    "Brackets a regular expression"])),
			     Tr(td(["\\b",
				    "Matches a word boundary"]))
			     )
		       )
		),
	      "However, if you've never done regular expressions before, 
              and the ",
	      a({-href=>"#examples"},
		"examples"), 
              " above don't suffice,
              then you need more help than this page can provide.
              You might try 
              <i>Programming Perl</i> 
              by Larry Wall and Randal L Schwartz."
	      );

    $r->print(
	      end_CTAN_page(", revised 2001-Mar-02 JH.",$URL_str)
	      );

    return OK;
}

1;





