package Apache::Search;
# File: Apache/Search.pm

use strict;

use Apache::Constants qw(:common REDIRECT);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
	     );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($filetoget $catstringtoget $this_mods_URL $mirror $tmp_URL_str);
$filetoget = "";
$catstringtoget = "";
$this_mods_URL = SEARCH_PAGE(); # URL from perl.conf for this module  
$mirror = ""; 
$tmp_URL_str = "";

# For the widely_referenced_links subroutine
use vars qw($URL_suffix); 
$URL_suffix = "";

use vars qw($r);  # request object


sub handler {
    $r = shift;

    # blank out cross-session data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );

    $filetoget = "";
    $tmp_URL_str = "";

    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data); 
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    $filetoget = $param_data{PARAM_FILENAME_KEY()};
    $mirror = $param_data{PARAM_MIRROR_KEY()};
    #$param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Search CTAN",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Search the Comprehensive TeX Archive Network")
	      );

#    $r->print(
#	      "<P>header: $header</P>",
#	      "<P>debug: cookie data: ".debug_info(%cookie_data)."</P>",
#	      "<P>debug: param data: ".debug_info(%param_data)."</P>"
#	      );

    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;

    $r->print(
	      p(
		"Here you can find information on existing TeX solutions. 
                 For instance, you can find style files to format your
                 paper according to the requirements of various journals. 
                 You can also find explanatory documents like the one 
                 outlining techniques for
                 putting graphics into your document."
		)
	      );

    $r->print(
	      hr,
	      h3("Search CTAN For a File"),
	      p(
		"If you know the name of a file that you need, type it into the
                 search box below and you will get a link to all the files 
                 of that name on CTAN.",  
		i(
		  "(More instructions are ",
                  a({href => "#instructions"},"below"),
                  ".)"
		  )
		)
	      );

    # the look-for-a-file form
    #  Note that the filename key is temp  removed from params for this form
    delete($param_data{PARAM_FILENAME_KEY()}); # want new file-to-get
    $tmp_URL_str = params_as_URLfields(%cookie_data,%param_data);
    $r->print(
	      start_form(-method => "POST",
			 -action => CGI()."filesearch$tmp_URL_str"),
	      params_as_hiddenfields(%param_data),
	      center(
		     "Search CTAN files for ",
		     textfield(
			       -name => PARAM_FILENAME_KEY(),
			       -size => 40,
			       -maxLength => 80,
			       -value => $filetoget
			       ),
		     submit(
			    -name => "SUBMIT",
			    -value => "Submit Query"
			    )
		     ),
	      end_form
	      );
    if ($filetoget) { # restore for catalogue search portion
	$param_data{PARAM_FILENAME_KEY()} = $filetoget; 
    }

    $r->print(
	      hr,
	      h3("Search the Catalogue For a Keyword"),
	      p(
		"Graham Williams has compiled an amazing ",
		a({href => CATALOGUEINDEX_PAGE()."$URL_str"},
		  "catalogue of information"),
		"about TeX, LaTeX, and associated topics,
                 including TeX-related home pages and a wealth of 
                 other information.
                 You can do a keyword search on this document. ", 

		"If you know the name of a file that you need, type it into the
                 search box below and you will get a link to all the files 
                 of that name on CTAN.",  
		i(
		  "(More instructions are ",
                  a({href => "#instructions"},"below"),
                  ".)"
		  )
		)
	      );

    # the look-for-a-catalogue-entry form
    $catstringtoget = $param_data{PARAM_CATSTRING_KEY()};
    delete($param_data{PARAM_CATSTRING_KEY()});
    $tmp_URL_str = params_as_URLfields(%cookie_data,%param_data);
    $r->print(    
	      start_form(-method => "POST",
			 -action => CGI()."cataloguesearch$tmp_URL_str"),
	      params_as_hiddenfields(%param_data),
	      center(
		     "Search the Catalogue for ",
		     textfield(
			       -name => PARAM_CATSTRING_KEY(),
			       -size => 40,
			       -maxLength => 80,
			       -value => $catstringtoget
			       ),
		     submit(
			    -name => "SUBMIT",
			    -value => "Submit Query"
			    )
		     ),
	      end_form
	      );

    $r->print(
	      widely_referenced_links($URL_str)
	      );

    $r->print(
	      hr,
	      h4(
		 a({name => "instructions"},
		   "Instructions for this page"
		   )
		 ),
	      p(
		small(
		      "(1) ",
		      regex_explanation($URL_str),
		      " ",
		      "(2) ",
		      mirror_explanation($URL_str) 
		  )
		)
	      );

    $r->print(
	      end_CTAN_page(", revised 2001-Mar-02 JH.",$URL_str)
	      );

    return OK;
}



# widely_referenced_links
#  Just broke it off to make the handler() routine easier to understand.
sub widely_referenced_links {
    $URL_suffix = shift();

    return
      hr().
      h3("Widely-Referenced Links").
      p(
        "These may help you find what you are searching for.
         They are the links given most often as answers to
         ``Where can I find information on ...'' questions. "
       ).
      ul({-type=>"circle"},
         li("The TeX User's Group's ",
            a({-href=>"http://tug.org/tex-ptr-faq"},
	      "meta-FAQ"),
            ". "
	    ),
	 li("The ",
	    a({-href=>"http://www.tex.ac.uk/cgi-bin/texfaq2html?introduction=yes"},
	      "UK TeX User's Group's FAQ"),
	    "is the best English-language document of its type."
	    ),
	 li("The ",
	    a({-href=>"/ctan/tex-archive/info/lshort/english/lshort.pdf$URL_suffix"},
	      "(Not So) Short Introduction to LaTeX2e"),
	    "is a good beginner's tutorial. "
	    ),
	 li(
	   a({-href=>"/tex-archive/info/gentle/gentle.pdf$URL_suffix"},
	     "A Gentle Introduction to TeX"),
	    " is a classic tutorial on Plain TeX."
	    ),
	 li(
	    a({-href=>"../tex-archive/info/epslatex.pdf$URL_suffix"},
	      "Using Imported Graphics in LaTeX2e"),
	    "shows you how to do (almost) anything with 
            graphics: side-by-side, rotated, etc."
	    ),
	 li( 
	     "With some loss, you can convert back and forth to various ",
	     a({-href=>"http://www.kfa-juelich.de/isr/1/texconv/texcnv.html"},
	       "word processors"),
	     ". "
	     ),
	 li("There is a word processor-like interface for LaTeX, called ",
	    a({-href=>"http://www.lyx.org"},
	      "LyX"),
	    ". "
	    ),
	 li("Are you looking for a way to get TeX, LaTeX, and friends?
             The TeX User's group has a list of ",
	    a({-href=>"http://www.tug.org/interest.html"},
	      "implementations"),
	    " both free and commercial.
            One of the simplest ways to get TeX on most systems, 
            whether to try it,
            to run it once in a while, 
            or to install it to your hard drive,
            is the ",
	    a({-href=>"http://www.tug.org/texlive.html"},
	      "TeX Live"),
	    " CD-ROM."
	    )
	 ).
       p(
	 "If you can't find what you need in any of these, try a search
         of past postings to the news group comp.text.tex.
         One place where you can do that is ",
	 a({-href=>"http://www.deja.com"},
	   "Deja"),
	 ". ",
	 "If you are still puzzled, try posting to comp.text.tex.
        It's a friendly group."
       );
}



1;
