package Apache::Upload;
# File: Apache/Upload.pm

use strict;

use Apache::Constants qw(:common);
use CGI qw(:all);
use Apache::CTAN;

# all variables global to stop memory/GC buildup?
use vars qw(%cookie_data %param_data %except);
%cookie_data = ();
%param_data = ();
%except = (    # Do not include in the lists of params (e.g. in URL_str) 
		  );
use vars qw($header $redirect_flag $URL_str);
$header = "";  # http header that will be sent
$redirect_flag = 0; # should redirect to another page?
$URL_str = "";  # params as URL fields for a GET link

# Variable needed here, but not other modules
use vars qw($this_mods_URL $mirror);
$this_mods_URL = UPLOAD_PAGE(); # URL from perl.conf for this module  
$mirror = "";

use vars qw($r); # request object

sub handler {
    $r = shift;
    # blank out cross-process data
    %cookie_data = ();
    %param_data = ();
    %except = (
	       );
    # handle http headers
    $param_data{PARAM_ACTION_KEY()} = $this_mods_URL;
    ($header,$redirect_flag) = CTAN_header($this_mods_URL,0,\%cookie_data,\%param_data); 
    $r->print(
	      $header
	      );
    if ($redirect_flag) {
	return OK;
    }
    $URL_str = params_as_URLfields(%cookie_data,%param_data);
    #$mirror = $param_data{PARAM_MIRROR_KEY()};
    $param_data{PARAM_NEWMIRRORFLAG_KEY()} = 0;
    # done with the header & state stuff

    $r->print(
	      start_html(-title => "Upload to CTAN",
			 -meta=>{'keywords'=>META_KEYWORDS()}),
	      h2("Upload to the Comprehensive TeX Archive Network")
	      );

    $r->print(
	      p(
		"Hey, got something new for CTAN? 
                 Great!
                 This page allows you to upload it."
		)
	      );

    $r->print(
	      start_form(-method => "POST",
		          -action => "http://".THIS_SITE_WEB().CGI()."upload",
		          -enctype => "multipart/form-data"
			 ),
	      ol(
		 li(
		    p(
		      b("Please add a few bits of information
                         that will help us to categorize  it. "),
                      "We need at least your name, your email, and a caption 
                      (typically one sentence). "
		      ),
		    p(
		      "In addition, your suggesting a CTAN directory is a help
                      (if you are not sure, just leave it blank).
                      And, a short text will, besides being in the 
                      announcement made when
                      the package is installed, be the basis for what 
                      might go into the ",
		      a({-href=>CATALOGUEINDEX_PAGE()."$URL_str"},
			"Catalogue"),
                     " You can help to bring your work to the largest audience 
                      by making sure that this short text is clear to a 
                      non-TeXpert and  that it includes keywords that a 
                      person might use in a ",
		      a({-href=>SEARCH_PAGE()."$URL_str"},
			"search"),
                      ". "
		      ),
		    p(
		      table({-border=>"0"},
			    Tr(td(["Name of your contribution",
				   textfield(-name=>"contribution",
					     -size=>"60",
					     -align=>"TOP"
					     )
				   ])),
			    Tr(td(["Your name",
				   textfield(-name=>"name",
					     -size=>"60",
					     -align=>"TOP"
					     )
				   ])),
			    Tr(td(["Your email",
				   textfield(-name=>"email",
					     -size=>"60",
					     -align=>"TOP"
					     )
				   ])),
			    Tr(td(["Summary description",
				   textfield(-name=>"summary",
					     -size=>"60",
					     -align=>"TOP"
					     )
				   ])),
			    Tr(td(
				  table({-border=>"0"},
					Tr(td("Suggested CTAN directory")),
					Tr(td("(you can",
					      a({-href=>WEBFTP_ROOT()."$URL_str"},
						"browse here"),
					      "). "))
					)
				  ),
			       td(textfield(-name=>"directory",
					     -size=>"60",
					     -align=>"TOP"
					     )
				  )),
			    Tr(td("Short text for announcement:"),
			       td(textarea(-name=>"announce",
					   -rows=>"6",
					   -cols=>"60",
					   -wrap=>"PHYSICAL"
					   )
				  )
			       )
			    ),  # ends the table(
		      )
		    ),  # ends the li(
		 li(
		    b("Indicate the license. "),
		    "For more information, see the ",
		    a({-href=>WEBFTP_ROOT."help/Catalogue/licenses.html$URL_str"},
		      "Catalogue License Definitions"),
		    ".",
		    center(
			   table({border=>"0"},
				 Tr(td(
				       "License type ",
				       popup_menu(
						  -name=>"license",
						  -values=>[
							    "free",
							    "unknown",
							    "nocommercial",
							    "nosell",
							    "nosource",
							    "shareware",
							    "other"
							    ],
						  -default=>"free",
						  -labels=>{
							    "free"=>"Free",
							    "unknown"=>"Unknown",
							    "nocommercial"=>"Nocommercial",
							    "nosell"=>"Nosell",
							    "nosource"=>"Nosource",
							    "shareware"=>"Shareware",
							    "other"=>"Other"
							    },
						  
						  )
				       ),
				    td(),
				    td(
				       " If you selected\"Free\" you may 
                                       refine your choice ",
				       popup_menu(
						  -name=>"freeversion",
						  -values=>[
							    "dfsg",
							    "lppl",
							    "gpl",
							    "lgpl",
							    "artistic",
							    "bsd",
							    "pd"
							    ],
						  -default=>"lppl",
						  -labels=>{
							    "dfsg"=>"Generic DFSG",
							    "lppl"=>"LaTeX Project",
							    "gpl"=>"GNU Project",
							    "lgpl"=>"GNU Library",
							    "artistic"=>"Perl Artistic",
							    "bsd"=>"BSD Style",
							    "pd"=>"Public Domain"
							    }
						  )
				       )
				    ),
				 ) # ends the inner table(
			   ), # ends the center(
		    "If you don't know what to pick, you might note that the ",
		    a({-href=>WEBFTP_ROOT()."help/Catalogue/licenses.lppl.html$URL_str"},
		      "LaTeX Project Public License"),
		    " was developed to suit this purpose. "
		    ),
		 li(
		    p(
		      b(
			"Input your file's name on your computer 
                        (the button pops up a file selection
                        box, or just type it in). "
			),
		      " It will be uploaded when you submit this form 
                      in step (4). "
		      ),
		    center(
			   filefield(-name=>"file",
				     -size=>"40"
				     )
			   ),
		    p(
		      " We prefer that you package your contribution as an 
                       archive,
                       especially if you are uploading more than a file or two.
                       Of the available archive types, 
                       we have had the best experience with ",
		      a({-href=>WEBFTP_ROOT()."tools/zip/info-zip/Info-ZIP.html$URL_str"},
			"ZIP archives"),
		      " or a gzipped tar archives.  
                       (If these formats are a problem for you, 
                       please, just let us know.) "
		      )
		    ),
		 li(
		    p(
		      b(
			" Thanks for providing the information - and 
                         thanks for your contribution. "
			),
		      " You keep TeX going! "
		      ),
		    center(
			   submit(
				  -name=>"SUBMIT",
				  -value=>"Submit"
				  ),
			   submit(
				  -name=>"RESET",
				  -value=>"Reset"
				  )
			   )
		    )

		 ),  # ends the ol(
	      end_form()
	      ); # ends the $r-> print(


    $r->print(
	      end_CTAN_page(", revised 2001-Mar-13 JH.",$URL_str)
	      );

    return OK;
}

1;





